(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    629873,      10450]
NotebookOptionsPosition[    627050,      10356]
NotebookOutlinePosition[    627395,      10371]
CellTagsIndexPosition[    627352,      10368]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Methoden der Bioinformatik",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox[" \n\n",
  FontSize->12],
 "Eine Einf\[UDoubleDot]hrung zur Anwendung in Biologie und Medizin\n\n2. \
Auflage",
 StyleBox["\n",
  FontSize->18,
  FontWeight->"Bold"],
 StyleBox["\n",
  FontSize->12],
 "Marc-Thorsten H\[UDoubleDot]tt",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "und",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "Manuel Dehnert\n",
 StyleBox["\n",
  FontSize->12],
 "Springer Spektrum",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "2006",
 StyleBox[", ",
  FontSize->12,
  FontWeight->"Bold"],
 "2016, ISBN 978-3-662-46149-5"
}], "Subsubtitle",
 CellChangeTimes->{{3.669868691792925*^9, 3.669868786167323*^9}, {
  3.6698688284727426`*^9, 3.669868879042635*^9}, {3.6698691142260866`*^9, 
  3.6698691148331213`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs: ",
 "STRING-Datenbank"
}], "Subtitle",
 CellChangeTimes->{
  3.670321495640956*^9, 3.670402706588908*^9, {3.670427551024929*^9, 
   3.670427553031043*^9}, 3.6704885618448496`*^9},
 Background->RGBColor[
  0.8705882352941177, 0.00392156862745098, 0.2196078431372549]],

Cell[TextData[{
 "Die Anwendung der verschiedenen graphentheoretischen Methoden auf \
biologische Netzwerke basiert auf der elektronischen \
Verf\[UDoubleDot]gbarkeit der entsprechenden Netzwerkdaten. Der folgende ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs f\[UDoubleDot]hrt anhand eines unserer Beispielnetzwerke die ersten \
Prozessierungsschritte der Daten vor. Wir verwenden die STRING-Datenbank als \
Weg zum Protein-Interaktionsnetz von ",
 StyleBox["E. coli",
  FontSlant->"Italic"],
 ". In Abb. 5.43 ist ein Screenshot der Datenbankseite gezeigt, von der die \
Datei ",
 StyleBox["511145.protein.links.v9.1.txt",
  FontWeight->"Bold"],
 " heruntergeladen wurde, die wir nun in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " importieren."
}], "Text",
 CellChangeTimes->{{3.6761919946992764`*^9, 3.6761920040606937`*^9}, 
   3.6761920413397636`*^9, 3.6761920902302537`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"network1", " ", "=", " ", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<511145.protein.links.v9.1.txt\>\"", ",", "\"\<Data\>\""}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.618033197124413*^9, 3.618033222820593*^9}, {
  3.6180333011073523`*^9, 3.618033303305056*^9}, {3.622896093100572*^9, 
  3.622896101656365*^9}, {3.677551095596428*^9, 3.6775511002608356`*^9}, {
  3.6775541530882072`*^9, 3.6775541590474176`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", "network1", "]"}]], "Input",
 CellChangeTimes->{{3.6180332248443947`*^9, 3.618033228644094*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"817651", ",", "3"}], "}"}]], "Output",
 CellChangeTimes->{3.6775727060593233`*^9}]
}, Open  ]],

Cell["\<\
Der erste Eintrag enth\[ADoubleDot]lt die Spalten\[UDoubleDot]berschriften. \
In den folgenden Eintr\[ADoubleDot]gen sehen wir zudem, dass jeder \
Protein-Identifikationsnummer (Protein-ID) auch noch die ID f\[UDoubleDot]r \
die Spezies (511145) beigef\[UDoubleDot]gt ist.\
\>", "Text",
 CellChangeTimes->{{3.6761921182315054`*^9, 3.6761921299409275`*^9}, {
  3.6761921601391835`*^9, 3.676192164902192*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Take", "[", 
  RowBox[{"network1", ",", "5"}], "]"}]], "Input",
 CellChangeTimes->{{3.618033239828248*^9, 3.618033254915988*^9}, {
  3.619840249289051*^9, 3.6198402549966927`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"protein1\"\>", ",", "\<\"protein2\"\>", 
     ",", "\<\"combined_score\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"511145.b0001\"\>", ",", "\<\"511145.b0002\"\>", ",", "639"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"511145.b0001\"\>", ",", "\<\"511145.b0003\"\>", ",", "632"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"511145.b0001\"\>", ",", "\<\"511145.b0004\"\>", ",", "615"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"511145.b0001\"\>", ",", "\<\"511145.b0005\"\>", ",", "569"}],
     "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.677572706074923*^9}]
}, Open  ]],

Cell[TextData[{
 "F\[UDoubleDot]r die Datenprozessierung lassen wir das erste Element weg und \
entfernen zudem die Spezies-ID und die dritte Spalte, die den \
Signifikanz-Score enth\[ADoubleDot]lt. F\[UDoubleDot]r eine genauere Analyse \
(so wie sie f\[UDoubleDot]r die Netzwerke in Abb. 5.37 \
durchgef\[UDoubleDot]hrt worden ist) kann man eine Schwelle auf diesen Score \
setzen, also nur Verbindungen in dem Protein-Interaktionsnetz zulassen, deren \
Score h\[ODoubleDot]her ist als dieser Schwellenwert. Die verbleibenden \
Wertepaare werden dann mit einer einfachen \[CapitalUDoubleDot]bersetzung in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-lesbare Netzwerkverbindungen \[UDoubleDot]berf\[UDoubleDot]hrt."
}], "Text",
 CellChangeTimes->{{3.676192223459501*^9, 3.6761922465397434`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"network2", " ", "=", " ", 
   RowBox[{
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"StringReplace", "[", 
        RowBox[{"#", ",", 
         RowBox[{"\"\<511145.\>\"", "\[Rule]", " ", "\"\<\>\""}]}], "]"}], 
       "&"}], ",", 
      RowBox[{
       RowBox[{"Drop", "[", 
        RowBox[{"network1", ",", "1"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], ",", "2"}], "]"}], 
    " ", "/.", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n1_", ",", "n2_"}], "}"}], "\[Rule]", " ", 
     RowBox[{"(", 
      RowBox[{"n1", "\[UndirectedEdge]", "n2"}], ")"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.618033337754861*^9, 3.61803343619128*^9}, {
  3.618033959261984*^9, 3.618034046142497*^9}, {3.6180340772545223`*^9, 
  3.618034109901198*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", "network2", "]"}]], "Input",
 CellChangeTimes->{{3.61803339197017*^9, 3.618033396449374*^9}}],

Cell[BoxData[
 RowBox[{"{", "817650", "}"}]], "Output",
 CellChangeTimes->{3.6775727183053446`*^9}]
}, Open  ]],

Cell["\<\
Von den so prozessierten mehr als 800 000 Verbindungen betrachten wir zuerst \
das durch die ersten 100 Eintr\[ADoubleDot]ge aufgespannte Subnetzwerk.

Da die urspr\[UDoubleDot]ngliche Liste nach dem ersten Element sortiert war, \
entsteht aus diesen ersten 100 Eintr\[ADoubleDot]gen ein grafisch gut \
darstellbarer, zusammenh\[ADoubleDot]ngender Graph.\
\>", "Text",
 CellChangeTimes->{{3.6761922702177877`*^9, 3.6761923080318575`*^9}, 
   3.6761927206256237`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{
   RowBox[{"Take", "[", 
    RowBox[{"network2", ",", "100"}], "]"}], ",", 
   RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
   RowBox[{"ImagePadding", "\[Rule]", "20"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "600"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.618033443767666*^9, 3.6180335415626163`*^9}, {
  3.618035141448142*^9, 3.618035156930851*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "b0001", "b0002", "b0003", "b0004", "b0005", "b0006", "b0007", "b0073", 
       "b0075", "b0243", "b0273", "b0294", "b0343", "b0411", "b0423", "b0855",
        "b1265", "b1597", "b1715", "b2011", "b2018", "b2247", "b2598", 
       "b3342", "b3523", "b3672", "b3766", "b4246", "b4254", "b4314", "b4349",
        "b4350", "b4558", "b4605", "b0025", "b0031", "b0033", "b0053", 
       "b0054", "b0071", "b0072", "b0074", "b0077", "b0078", "b0088", "b0091",
        "b0099", "b0126", "b0149", "b0166", "b0175", "b0179", "b0181", 
       "b0185", "b0188", "b0191", "b0222", "b0242", "b0261", "b0268", "b0296",
        "b0306", "b0352", "b0386", "b0388", "b0393", "b0405", "b0413", 
       "b0414", "b0415", "b0416", "b0428", "b0431", "b0436", "b0442", "b0443",
        "b0452", "b0470", "b0472", "b0473", "b0526", "b0529", "b0565", 
       "b0577", "b0600", "b0604", "b0605", "b0606", "b0628", "b0640", "b0674",
        "b0723"}, {
      Null, {{1, 2}, {1, 3}, {1, 4}, {1, 5}, {1, 6}, {1, 7}, {1, 8}, {1, 9}, {
       1, 10}, {1, 11}, {1, 12}, {1, 13}, {1, 14}, {1, 15}, {1, 16}, {1, 
       17}, {1, 18}, {1, 19}, {1, 20}, {1, 21}, {1, 22}, {1, 23}, {1, 24}, {1,
        25}, {1, 26}, {1, 27}, {1, 28}, {1, 29}, {1, 30}, {1, 31}, {1, 32}, {
       1, 33}, {1, 34}, {2, 1}, {2, 3}, {2, 4}, {2, 5}, {2, 6}, {2, 7}, {2, 
       35}, {2, 36}, {2, 37}, {2, 38}, {2, 39}, {2, 40}, {2, 41}, {2, 8}, {2, 
       42}, {2, 43}, {2, 44}, {2, 45}, {2, 46}, {2, 47}, {2, 48}, {2, 49}, {2,
        50}, {2, 51}, {2, 52}, {2, 53}, {2, 54}, {2, 55}, {2, 56}, {2, 57}, {
       2, 58}, {2, 10}, {2, 59}, {2, 60}, {2, 11}, {2, 61}, {2, 62}, {2, 
       63}, {2, 64}, {2, 65}, {2, 66}, {2, 67}, {2, 68}, {2, 69}, {2, 70}, {2,
        71}, {2, 72}, {2, 73}, {2, 74}, {2, 75}, {2, 76}, {2, 77}, {2, 78}, {
       2, 79}, {2, 80}, {2, 81}, {2, 82}, {2, 83}, {2, 84}, {2, 85}, {2, 
       86}, {2, 87}, {2, 88}, {2, 89}, {2, 90}, {2, 91}, {2, 92}}}, {
      ImagePadding -> 20, ImageSize -> 600, VertexLabels -> {"Name"}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{1.0949546208351042`, 
          1.1225160481424257`}, {2.2557458224306646`, 1.5038996014620387`}, {
          3.416311950401767, 1.1218316872759266`}}], 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{1.0949546208351042`, 
          1.1225160481424257`}, {2.255520748806207, 0.7404481339562624}, {
          3.416311950401767, 1.1218316872759266`}}], 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          2.0711389773642113`, 1.2037620633150274`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          2.072550282090292, 1.0363414336392656`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          2.2171010970874594`, 1.208643057993136}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          2.191836776670801, 1.3531124865225375`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          2.221877138526875, 1.0462538665004264`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          2.175541306185316, 0.9110400306680744}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.684252527229618, 1.6649167644986491`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          2.1239279558903346`, 0.796999070795237}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          2.096090802022171, 1.4304125518764177`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.36732927770745905`, 1.2897270066595432`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.12781817999146616`, 1.5582124639903465`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.8460425963427867, 0.5084601131599155}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.290107724942267, 1.0017811649868076`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.9431613558170271, 0.2906241370069952}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.3871156542833898, 1.5791786414552247`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.7041298728531082, 0.24746903843607826`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.5137046255105804, 0.3486891942121616}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.12352150895423453`, 1.179232123319753}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.044288518247914244`, 1.3608628118516541`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.12328697201290684`, 0.808437643725676}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.2500477763142941, 1.7632883689984138`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.3190074881517644, 0.42774689294197765`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.394766362835957, 0.6771915125532246}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.8451790927260363, 2.0060867969667857`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.5425455414151905, 0.9678692263199912}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.15616053069051183`, 0.5973907539862777}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {0., 
          0.9976001778498215}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.4387061585173715, 1.871431891657605}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.9423282739402967, 1.7973832239491039`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.6143794088942331, 1.3656110986254721`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.6189962579245876, 1.9717050629225161`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.6477691695151471, 0.6670732645245393}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.0711389773642113`, 1.2037620633150274`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.072550282090292, 1.0363414336392656`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.2171010970874594`, 1.208643057993136}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.191836776670801, 1.3531124865225375`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.221877138526875, 1.0462538665004264`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.175541306185316, 0.9110400306680744}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.1239279558903346`, 0.796999070795237}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.096090802022171, 1.4304125518764177`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.590905487227156, 1.0792000049151969`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.014119307682726, 0.12531173988351496`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.996604848139021, 0.1450345498712754}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.929016743262579, 0.4721678200222219}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.1067037977021967`, 1.9415755275231983`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.9933207360568845`, 1.247103494309129}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.8303663711703386`, 1.4949913301738462`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.3244692472708226`, 1.6020584949756453`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.826680256966454, 0.29541844637443637`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.872772849445458, 0.9623977573491631}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.173703101687753, 1.3184935152238881`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.6100473023197637`, 0.4334428773620701}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.9700477125306213`, 0.3801785278316072}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.8894236862855767`, 1.6322035405387525`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.350035922080192, 1.8491282925283792`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.9040426502331615`, 1.9174546110490085`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.883679308540083, 2.032465196020128}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.7490285090858375`, 0.26964166627044606`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.818446385571276, 0.0345539651192972}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.5578496688605545`, 0.8838372528991891}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.0952041199887437`, 2.1808664432363765`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.997506635140303, 1.7001485406169852`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.564021447969479, 1.4977955276090147`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.8584184566149373`, 0.9668709027958297}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.3999862739340614`, 0.}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.3626449916158307`, 2.2662856657905723`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.418093762427094, 0.5177616360907961}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.64987882131408, 2.002054964549215}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.602108386826861, 0.694768762865711}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.178203896246221, 1.995799845815145}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.012989555913835, 2.128420157824752}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.180913213641553, 0.236591443823445}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.328767531933005, 2.070650083362428}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.0327481292443754`, 0.7087103166277062}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.172708526234244, 1.5617234142238423`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.746136425070943, 0.6187253578171831}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.6075320771017694`, 2.238340621013826}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.51317402184503, 0.6901460217452287}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.8058284647341676`, 1.3536139180146558`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {4.1457099529502,
           0.5877573547540184}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.8178052029502876`, 2.193452531349382}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.298673346175474, 0.8160336542276176}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.109613153399747, 1.7643802043707484`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.215064254300674, 0.2896227615712551}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.7595286775598966`, 1.7993244436884628`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.425777055014457, 1.6623119730392077`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.6089283726621737`, 0.013255856571747993`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.266315206738794, 0.5373198774776022}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.280095356125587, 0.39579303022068535`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.4251733249582306`, 1.8871236543224157`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.2142871672257947`, 0.07088642504398424}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.4731893448331843`, 0.2336728732565041}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.3627870935773245`, 1.0935836975189934`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.124646224794956, 1.0471438393106296`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.38485796596837, 1.3975012097810688`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.575944090157276, 1.2749104207835669`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.629867671955528, 1.7096426609765614`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.965750606749431, 0.7182813188369249}}, 0.04065604207530167]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {
         DiskBox[{1.0949546208351042`, 1.1225160481424257`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0001\"\>", 
          Offset[{2, 2}, {1.135610662910406, 1.1631720902177274`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.416311950401767, 1.1218316872759266`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0002\"\>", 
          Offset[{2, 2}, {3.4569679924770687`, 1.1624877293512283`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.0711389773642113`, 1.2037620633150274`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0003\"\>", 
          Offset[{2, 2}, {2.111795019439513, 1.2444181053903292`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.072550282090292, 1.0363414336392656`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0004\"\>", 
          Offset[{2, 2}, {2.113206324165594, 1.0769974757145673`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.2171010970874594`, 1.208643057993136}, 
          0.04065604207530167], 
         InsetBox["\<\"b0005\"\>", 
          Offset[{2, 2}, {2.257757139162761, 1.2492991000684377`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.191836776670801, 1.3531124865225375`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0006\"\>", 
          Offset[{2, 2}, {2.2324928187461026`, 1.3937685285978392`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.221877138526875, 1.0462538665004264`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0007\"\>", 
          Offset[{2, 2}, {2.2625331806021767`, 1.0869099085757281`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.175541306185316, 0.9110400306680744}, 
          0.04065604207530167], 
         InsetBox["\<\"b0073\"\>", 
          Offset[{2, 2}, {2.216197348260618, 0.9516960727433761}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.684252527229618, 1.6649167644986491`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0075\"\>", 
          Offset[{2, 2}, {0.7249085693049198, 1.7055728065739508`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.1239279558903346`, 0.796999070795237}, 
          0.04065604207530167], 
         InsetBox["\<\"b0243\"\>", 
          Offset[{2, 2}, {2.1645839979656363`, 0.8376551128705387}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.096090802022171, 1.4304125518764177`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0273\"\>", 
          Offset[{2, 2}, {2.136746844097473, 1.4710685939517194`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.36732927770745905`, 1.2897270066595432`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0294\"\>", 
          Offset[{2, 2}, {0.4079853197827607, 1.330383048734845}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.12781817999146616`, 1.5582124639903465`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0343\"\>", 
          Offset[{2, 2}, {0.16847422206676782`, 1.5988685060656482`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.8460425963427867, 0.5084601131599155}, 
          0.04065604207530167], 
         InsetBox["\<\"b0411\"\>", 
          Offset[{2, 2}, {0.8866986384180884, 0.5491161552352172}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.290107724942267, 1.0017811649868076`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0423\"\>", 
          Offset[{2, 2}, {0.33076376701756866`, 1.0424372070621093`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.9431613558170271, 0.2906241370069952}, 
          0.04065604207530167], 
         InsetBox["\<\"b0855\"\>", 
          Offset[{2, 2}, {0.9838173978923288, 0.33128017908229684`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.3871156542833898, 1.5791786414552247`}, 
          0.04065604207530167], 
         InsetBox["\<\"b1265\"\>", 
          Offset[{2, 2}, {0.42777169635869144`, 1.6198346835305264`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.7041298728531082, 0.24746903843607826`}, 
          0.04065604207530167], 
         InsetBox["\<\"b1597\"\>", 
          Offset[{2, 2}, {0.74478591492841, 0.2881250805113799}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.5137046255105804, 0.3486891942121616}, 
          0.04065604207530167], 
         InsetBox["\<\"b1715\"\>", 
          Offset[{2, 2}, {0.5543606675858821, 0.38934523628746326`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.12352150895423453`, 1.179232123319753}, 
          0.04065604207530167], 
         InsetBox["\<\"b2011\"\>", 
          Offset[{2, 2}, {0.16417755102953618`, 1.2198881653950546`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.044288518247914244`, 1.3608628118516541`}, 
          0.04065604207530167], 
         InsetBox["\<\"b2018\"\>", 
          Offset[{2, 2}, {0.08494456032321591, 1.4015188539269559`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.12328697201290684`, 0.808437643725676}, 
          0.04065604207530167], 
         InsetBox["\<\"b2247\"\>", 
          Offset[{2, 2}, {0.1639430140882085, 0.8490936858009777}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.2500477763142941, 1.7632883689984138`}, 
          0.04065604207530167], 
         InsetBox["\<\"b2598\"\>", 
          Offset[{2, 2}, {0.29070381838959575`, 1.8039444110737155`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.3190074881517644, 0.42774689294197765`}, 
          0.04065604207530167], 
         InsetBox["\<\"b3342\"\>", 
          Offset[{2, 2}, {0.35966353022706604`, 0.4684029350172793}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.394766362835957, 0.6771915125532246}, 
          0.04065604207530167], 
         InsetBox["\<\"b3523\"\>", 
          Offset[{2, 2}, {0.43542240491125866`, 0.7178475546285263}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.8451790927260363, 2.0060867969667857`}, 
          0.04065604207530167], 
         InsetBox["\<\"b3672\"\>", 
          Offset[{2, 2}, {0.885835134801338, 2.0467428390420874`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.5425455414151905, 0.9678692263199912}, 
          0.04065604207530167], 
         InsetBox["\<\"b3766\"\>", 
          Offset[{2, 2}, {0.5832015834904922, 1.0085252683952928`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.15616053069051183`, 0.5973907539862777}, 
          0.04065604207530167], 
         InsetBox["\<\"b4246\"\>", 
          Offset[{2, 2}, {0.1968165727658135, 0.6380467960615794}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0., 0.9976001778498215}, 0.04065604207530167], 
         InsetBox["\<\"b4254\"\>", 
          Offset[{2, 2}, {0.04065604207530167, 1.038256219925123}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.4387061585173715, 1.871431891657605}, 
          0.04065604207530167], 
         InsetBox["\<\"b4314\"\>", 
          Offset[{2, 2}, {0.47936220059267315`, 1.9120879337329066`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.9423282739402967, 1.7973832239491039`}, 
          0.04065604207530167], 
         InsetBox["\<\"b4349\"\>", 
          Offset[{2, 2}, {0.9829843160155984, 1.8380392660244056`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.6143794088942331, 1.3656110986254721`}, 
          0.04065604207530167], 
         InsetBox["\<\"b4350\"\>", 
          Offset[{2, 2}, {0.6550354509695349, 1.4062671407007739`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.6189962579245876, 1.9717050629225161`}, 
          0.04065604207530167], 
         InsetBox["\<\"b4558\"\>", 
          Offset[{2, 2}, {0.6596522999998893, 2.012361104997818}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.6477691695151471, 0.6670732645245393}, 
          0.04065604207530167], 
         InsetBox["\<\"b4605\"\>", 
          Offset[{2, 2}, {0.6884252115904488, 0.707729306599841}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.590905487227156, 1.0792000049151969`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0025\"\>", 
          Offset[{2, 2}, {4.6315615293024575`, 1.1198560469904986`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.014119307682726, 0.12531173988351496`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0031\"\>", 
          Offset[{2, 2}, {4.054775349758028, 0.16596778195881662`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.996604848139021, 0.1450345498712754}, 
          0.04065604207530167], 
         InsetBox["\<\"b0033\"\>", 
          Offset[{2, 2}, {3.0372608902143226`, 0.18569059194657705`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.929016743262579, 0.4721678200222219}, 
          0.04065604207530167], 
         InsetBox["\<\"b0053\"\>", 
          Offset[{2, 2}, {2.9696727853378806`, 0.5128238620975236}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.1067037977021967`, 1.9415755275231983`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0054\"\>", 
          Offset[{2, 2}, {3.1473598397774984`, 1.9822315695985}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.9933207360568845`, 1.247103494309129}, 
          0.04065604207530167], 
         InsetBox["\<\"b0071\"\>", 
          Offset[{2, 2}, {3.0339767781321862`, 1.2877595363844307`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.8303663711703386`, 1.4949913301738462`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0072\"\>", 
          Offset[{2, 2}, {2.8710224132456403`, 1.535647372249148}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.3244692472708226`, 1.6020584949756453`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0074\"\>", 
          Offset[{2, 2}, {3.3651252893461243`, 1.642714537050947}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.826680256966454, 0.29541844637443637`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0077\"\>", 
          Offset[{2, 2}, {2.8673362990417557`, 0.33607448844973803`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.872772849445458, 0.9623977573491631}, 
          0.04065604207530167], 
         InsetBox["\<\"b0078\"\>", 
          Offset[{2, 2}, {3.9134288915207596`, 1.0030537994244648`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.173703101687753, 1.3184935152238881`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0088\"\>", 
          Offset[{2, 2}, {4.214359143763055, 1.3591495572991898`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.6100473023197637`, 0.4334428773620701}, 
          0.04065604207530167], 
         InsetBox["\<\"b0091\"\>", 
          Offset[{2, 2}, {3.6507033443950654`, 0.47409891943737176`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.9700477125306213`, 0.3801785278316072}, 
          0.04065604207530167], 
         InsetBox["\<\"b0099\"\>", 
          Offset[{2, 2}, {4.010703754605923, 0.4208345699069089}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.8894236862855767`, 1.6322035405387525`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0126\"\>", 
          Offset[{2, 2}, {3.9300797283608784`, 1.6728595826140542`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.350035922080192, 1.8491282925283792`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0149\"\>", 
          Offset[{2, 2}, {4.390691964155494, 1.889784334603681}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.9040426502331615`, 1.9174546110490085`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0166\"\>", 
          Offset[{2, 2}, {3.9446986923084633`, 1.9581106531243102`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.883679308540083, 2.032465196020128}, 0.04065604207530167],
          InsetBox["\<\"b0175\"\>", 
          Offset[{2, 2}, {2.924335350615385, 2.0731212380954296`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.7490285090858375`, 0.26964166627044606`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0179\"\>", 
          Offset[{2, 2}, {3.7896845511611392`, 0.3102977083457477}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.818446385571276, 0.0345539651192972}, 
          0.04065604207530167], 
         InsetBox["\<\"b0181\"\>", 
          Offset[{2, 2}, {3.8591024276465777`, 0.07521000719459887}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.5578496688605545`, 0.8838372528991891}, 
          0.04065604207530167], 
         InsetBox["\<\"b0185\"\>", 
          Offset[{2, 2}, {4.598505710935856, 0.9244932949744908}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.0952041199887437`, 2.1808664432363765`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0188\"\>", 
          Offset[{2, 2}, {3.1358601620640454`, 2.221522485311678}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.997506635140303, 1.7001485406169852`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0191\"\>", 
          Offset[{2, 2}, {3.0381626772156047`, 1.7408045826922869`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.564021447969479, 1.4977955276090147`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0222\"\>", 
          Offset[{2, 2}, {4.60467749004478, 1.5384515696843164`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.8584184566149373`, 0.9668709027958297}, 
          0.04065604207530167], 
         InsetBox["\<\"b0242\"\>", 
          Offset[{2, 2}, {2.899074498690239, 1.0075269448711313`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.3999862739340614`, 0.}, 0.04065604207530167], 
         InsetBox["\<\"b0261\"\>", 
          Offset[{2, 2}, {3.440642316009363, 0.04065604207530167}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.3626449916158307`, 2.2662856657905723`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0268\"\>", 
          Offset[{2, 2}, {3.4033010336911325`, 2.306941707865874}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.418093762427094, 0.5177616360907961}, 
          0.04065604207530167], 
         InsetBox["\<\"b0296\"\>", 
          Offset[{2, 2}, {4.458749804502395, 0.5584176781660978}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.64987882131408, 2.002054964549215}, 0.04065604207530167], 
         InsetBox["\<\"b0306\"\>", 
          Offset[{2, 2}, {3.6905348633893817`, 2.0427110066245167`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.602108386826861, 0.694768762865711}, 0.04065604207530167],
          InsetBox["\<\"b0352\"\>", 
          Offset[{2, 2}, {3.642764428902163, 0.7354248049410127}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.178203896246221, 1.995799845815145}, 0.04065604207530167],
          InsetBox["\<\"b0386\"\>", 
          Offset[{2, 2}, {4.218859938321523, 2.0364558878904466`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.012989555913835, 2.128420157824752}, 0.04065604207530167],
          InsetBox["\<\"b0388\"\>", 
          Offset[{2, 2}, {4.053645597989137, 2.169076199900054}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.180913213641553, 0.236591443823445}, 0.04065604207530167],
          InsetBox["\<\"b0393\"\>", 
          Offset[{2, 2}, {4.2215692557168545`, 0.27724748589874665`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.328767531933005, 2.070650083362428}, 0.04065604207530167],
          InsetBox["\<\"b0405\"\>", 
          Offset[{2, 2}, {3.3694235740083065`, 2.11130612543773}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.0327481292443754`, 0.7087103166277062}, 
          0.04065604207530167], 
         InsetBox["\<\"b0413\"\>", 
          Offset[{2, 2}, {3.073404171319677, 0.7493663587030079}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.172708526234244, 1.5617234142238423`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0414\"\>", 
          Offset[{2, 2}, {4.2133645683095455`, 1.602379456299144}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.746136425070943, 0.6187253578171831}, 
          0.04065604207530167], 
         InsetBox["\<\"b0415\"\>", 
          Offset[{2, 2}, {2.7867924671462445`, 0.6593813998924848}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.6075320771017694`, 2.238340621013826}, 
          0.04065604207530167], 
         InsetBox["\<\"b0416\"\>", 
          Offset[{2, 2}, {3.648188119177071, 2.278996663089128}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.51317402184503, 0.6901460217452287}, 0.04065604207530167],
          InsetBox["\<\"b0428\"\>", 
          Offset[{2, 2}, {4.553830063920332, 0.7308020638205304}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.8058284647341676`, 1.3536139180146558`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0431\"\>", 
          Offset[{2, 2}, {3.8464845068094693`, 1.3942699600899575`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.1457099529502, 0.5877573547540184}, 0.04065604207530167], 
         InsetBox["\<\"b0436\"\>", 
          Offset[{2, 2}, {4.186365995025501, 0.6284133968293201}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.8178052029502876`, 2.193452531349382}, 
          0.04065604207530167], 
         InsetBox["\<\"b0442\"\>", 
          Offset[{2, 2}, {3.8584612450255893`, 2.2341085734246837`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.298673346175474, 0.8160336542276176}, 
          0.04065604207530167], 
         InsetBox["\<\"b0443\"\>", 
          Offset[{2, 2}, {4.339329388250776, 0.8566896963029194}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.109613153399747, 1.7643802043707484`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0452\"\>", 
          Offset[{2, 2}, {4.150269195475048, 1.80503624644605}], ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.215064254300674, 0.2896227615712551}, 
          0.04065604207530167], 
         InsetBox["\<\"b0470\"\>", 
          Offset[{2, 2}, {3.255720296375976, 0.33027880364655676`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.7595286775598966`, 1.7993244436884628`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0472\"\>", 
          Offset[{2, 2}, {2.8001847196351983`, 1.8399804857637645`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.425777055014457, 1.6623119730392077`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0473\"\>", 
          Offset[{2, 2}, {4.466433097089759, 1.7029680151145095`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.6089283726621737`, 0.013255856571747993`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0526\"\>", 
          Offset[{2, 2}, {3.6495844147374754`, 0.053911898647049664`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.266315206738794, 0.5373198774776022}, 
          0.04065604207530167], 
         InsetBox["\<\"b0529\"\>", 
          Offset[{2, 2}, {3.306971248814096, 0.577975919552904}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.280095356125587, 0.39579303022068535`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0565\"\>", 
          Offset[{2, 2}, {4.320751398200889, 0.436449072295987}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.4251733249582306`, 1.8871236543224157`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0577\"\>", 
          Offset[{2, 2}, {3.4658293670335323`, 1.9277796963977174`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.2142871672257947`, 0.07088642504398424}, 
          0.04065604207530167], 
         InsetBox["\<\"b0600\"\>", 
          Offset[{2, 2}, {3.2549432093010964`, 0.1115424671192859}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.4731893448331843`, 0.2336728732565041}, 
          0.04065604207530167], 
         InsetBox["\<\"b0604\"\>", 
          Offset[{2, 2}, {3.513845386908486, 0.27432891533180576`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.3627870935773245`, 1.0935836975189934`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0605\"\>", 
          Offset[{2, 2}, {4.403443135652626, 1.1342397395942951`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.124646224794956, 1.0471438393106296`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0606\"\>", 
          Offset[{2, 2}, {4.165302266870258, 1.0877998813859313`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.38485796596837, 1.3975012097810688`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0628\"\>", 
          Offset[{2, 2}, {4.425514008043672, 1.4381572518563706`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.575944090157276, 1.2749104207835669`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0640\"\>", 
          Offset[{2, 2}, {4.616600132232578, 1.3155664628588686`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.629867671955528, 1.7096426609765614`}, 
          0.04065604207530167], 
         InsetBox["\<\"b0674\"\>", 
          Offset[{2, 2}, {3.6705237140308298`, 1.750298703051863}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.965750606749431, 0.7182813188369249}, 
          0.04065604207530167], 
         InsetBox["\<\"b0723\"\>", 
          Offset[{2, 2}, {4.006406648824733, 0.7589373609122266}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None,
  ImagePadding->20,
  ImageSize->600]], "Output",
 CellChangeTimes->{3.6775727184457445`*^9}]
}, Open  ]],

Cell[TextData[{
 "Die Protein-IDs sind die f\[UDoubleDot]r ",
 StyleBox["E. coli",
  FontSlant->"Italic"],
 " h\[ADoubleDot]ufig verwendeten Blattner-Nummern. Eine h\[ADoubleDot]ufige \
Aufgabe bioinformatischer Datenverarbeitung besteht darin, diese Nomenklatur \
in andere Schemata zu \[UDoubleDot]berf\[UDoubleDot]hren. In der \
STRING-Datenbank ist auch eine lange \
\[OpenCurlyQuote]\[CapitalUDoubleDot]bersetzungstafel\[CloseCurlyQuote] verf\
\[UDoubleDot]gbar (die Datei ",
 StyleBox["511145.protein.aliases.v9.1.txt",
  FontWeight->"Bold"],
 "), die diese Proteinbezeichnungen im b",
 StyleBox["xxxx",
  FontSlant->"Italic"],
 "-Format (die Blattner-Nummern) auf etwa 20 andere Nomenklaturen abbildet. \
Wir w\[ADoubleDot]hlen hier die bekannten KEGGNamen der Proteine aus, um den \
gerade gezeigten Subgraphen neu zu beschriften."
}], "Text",
 CellChangeTimes->{{3.676192360230954*^9, 3.676192365826765*^9}, {
   3.676192401670632*^9, 3.676192405545439*^9}, {3.6761924828627825`*^9, 
   3.676192483426384*^9}, 3.6761927154716144`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ref1", " ", "=", " ", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<511145.protein.aliases.v9.1.txt\>\"", ",", "\"\<Data\>\""}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.618033197124413*^9, 3.618033222820593*^9}, {
  3.6180333011073523`*^9, 3.618033303305056*^9}, {3.6180351748085613`*^9, 
  3.618035190932568*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", "ref1", "]"}]], "Input",
 CellChangeTimes->{{3.6180351946642647`*^9, 3.61803519795262*^9}}],

Cell[BoxData[
 RowBox[{"{", "136510", "}"}]], "Output",
 CellChangeTimes->{3.6775727208013487`*^9}]
}, Open  ]],

Cell["Eine Zeile aus dieser Datei gibt Aufschluss \[UDoubleDot]ber das \
Format.", "Text",
 CellChangeTimes->{{3.676192490086996*^9, 3.6761925083272305`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ref1", "[", 
  RowBox[{"[", "2", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.618035210440444*^9, 3.618035223712469*^9}, {
  3.622805018653324*^9, 3.622805028052981*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "511145", ",", "\<\"b0180\"\>", 
   ",", "\<\"(3R)-hydroxymyristol acyl carrier protein dehydratase\"\>", 
   ",", "\<\"BLAST_UniProt_DE\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.6775727208013487`*^9}]
}, Open  ]],

Cell[TextData[{
 "In der ersten Spalte steht der Speziesname. Die zweite Spalte enth\
\[ADoubleDot]lt die Blattner-Nummer, w\[ADoubleDot]hrend die dritte Spalte \
die Bezeichnung in der neuen Nomenklatur (oder eine n\[ADoubleDot]here \
Charakterisierung des Proteins) enth\[ADoubleDot]lt. In der vierten Spalte \
ist die Bezeichnung der neuen Nomenklatur angegeben. Wir w\[ADoubleDot]hlen \
nun alle Zeilen mit der Bezeichnung ",
 StyleBox["BLAST_KEGG_NAME",
  FontWeight->"Bold"],
 " aus."
}], "Text",
 CellChangeTimes->{{3.676192527894467*^9, 3.6761925362614822`*^9}, {
  3.6761925725633497`*^9, 3.676192580205764*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringJoin", "[", 
  RowBox[{"Map", "[", 
   RowBox[{"ToString", ",", 
    RowBox[{"ref1", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.618035468638241*^9, 3.618035489824513*^9}}],

Cell[BoxData["\<\"511145b0180(3R)-hydroxymyristol acyl carrier protein \
dehydrataseBLAST_UniProt_DE\"\>"], "Output",
 CellChangeTimes->{3.677572720816949*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ref2", " ", "=", " ", 
   RowBox[{"Cases", "[", 
    RowBox[{"ref1", ",", 
     RowBox[{"n1__", " ", "/;", 
      RowBox[{"StringMatchQ", " ", "[", 
       RowBox[{
        RowBox[{"StringJoin", "[", 
         RowBox[{"Map", "[", 
          RowBox[{"ToString", ",", "n1"}], "]"}], "]"}], ",", 
        RowBox[{"__", "~~", "\"\<BLAST_KEGG_NAME\>\"", "~~", "__"}]}], 
       "]"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.618035201154874*^9, 3.618035247950041*^9}, {
  3.618035292040361*^9, 3.6180353295505943`*^9}, {3.6180353746821127`*^9, 
  3.618035432491434*^9}, {3.618035495090077*^9, 3.61803550384552*^9}, {
  3.6731510698823977`*^9, 3.6731510748056793`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", "ref2", "]"}]], "Input",
 CellChangeTimes->{{3.618035509926868*^9, 3.618035515240213*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4363", ",", "4"}], "}"}]], "Output",
 CellChangeTimes->{3.6775727222521515`*^9}]
}, Open  ]],

Cell["\<\
Aus dieser Liste mit 4263 Zeilen fertigen wir (aus dem zweiten und dritten \
Eintrag jeder Zeile) eine \[CapitalUDoubleDot]bersetzungstabelle an, die sich \
sofort auf das oben diskutierte Teilnetzwerk anwenden l\[ADoubleDot]sst.\
\>", "Text",
 CellChangeTimes->{{3.6761926083992167`*^9, 3.6761926389150724`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ref3", " ", "=", " ", 
   RowBox[{
    RowBox[{"ref2", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3"}], "}"}]}], "]"}], "]"}], " ", "/.", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n1_", ",", "n2_"}], "}"}], "\[Rule]", 
     RowBox[{"(", " ", 
      RowBox[{"n1", "\[Rule]", " ", "n2"}], ")"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6180355210999603`*^9, 3.618035539664056*^9}, {
  3.618035573483849*^9, 3.618035616374834*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Take", "[", 
     RowBox[{"network2", ",", "100"}], "]"}], " ", "/.", " ", "ref3"}], ",", 
   RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
   RowBox[{"ImagePadding", "\[Rule]", "20"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "600"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.618033443767666*^9, 3.6180335415626163`*^9}, {
   3.618035141448142*^9, 3.618035156930851*^9}, {3.6180356775163107`*^9, 
   3.618035677530545*^9}, 3.6180357183107853`*^9}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "thrL", "thrA", "thrB", "thrC", "yaaX", "yaaA", "yaaJ", "leuB", "leuL", 
       "proA", "argF", "matA", "lacY", "tsx", "thiI", "potG", "b1265", "asr", 
       "b1715", "sbcB", "b2018", "yfaW", "b2598", "rpsL", "yhjE", "ivbL", 
       "ilvL", "pyrL", "argI", "fimA", "hsdM", "hsdR", "yifL", "b4605", 
       "ribF", "dapB", "carB", "surA", "lptD", "leuD", "leuC", "leuA", "ilvI",
        "ilvH", "murD", "murC", "mutT", "can", "mrcB", "dapD", "cdsA", "lpxD",
        "lpxA", "accA", "tilS", "yaeJ", "gmhA", "proB", "mmuM", "yagE", 
       "ykgM", "ykgE", "mhpE", "proC", "aroL", "rdgC", "queA", "nrdR", "ribD",
        "ribE", "nusB", "cyoE", "cyoB", "tig", "ybaV", "tesC", "tesB", "dnaX",
        "recR", "htpG", "cysS", "folD", "ompT", "ybdG", "ybdL", "dsbG", 
       "ahpC", "ahpF", "lipA", "holA", "asnB", "sdhA"}, {
      Null, {{1, 2}, {1, 3}, {1, 4}, {1, 5}, {1, 6}, {1, 7}, {1, 8}, {1, 9}, {
       1, 10}, {1, 11}, {1, 12}, {1, 13}, {1, 14}, {1, 15}, {1, 16}, {1, 
       17}, {1, 18}, {1, 19}, {1, 20}, {1, 21}, {1, 22}, {1, 23}, {1, 24}, {1,
        25}, {1, 26}, {1, 27}, {1, 28}, {1, 29}, {1, 30}, {1, 31}, {1, 32}, {
       1, 33}, {1, 34}, {2, 1}, {2, 3}, {2, 4}, {2, 5}, {2, 6}, {2, 7}, {2, 
       35}, {2, 36}, {2, 37}, {2, 38}, {2, 39}, {2, 40}, {2, 41}, {2, 8}, {2, 
       42}, {2, 43}, {2, 44}, {2, 45}, {2, 46}, {2, 47}, {2, 48}, {2, 49}, {2,
        50}, {2, 51}, {2, 52}, {2, 53}, {2, 54}, {2, 55}, {2, 56}, {2, 57}, {
       2, 58}, {2, 10}, {2, 59}, {2, 60}, {2, 11}, {2, 61}, {2, 62}, {2, 
       63}, {2, 64}, {2, 65}, {2, 66}, {2, 67}, {2, 68}, {2, 69}, {2, 70}, {2,
        71}, {2, 72}, {2, 73}, {2, 74}, {2, 75}, {2, 76}, {2, 77}, {2, 78}, {
       2, 79}, {2, 80}, {2, 81}, {2, 82}, {2, 83}, {2, 84}, {2, 85}, {2, 
       86}, {2, 87}, {2, 88}, {2, 89}, {2, 90}, {2, 91}, {2, 92}}}, {
      ImagePadding -> 20, ImageSize -> 600, VertexLabels -> {"Name"}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{1.0949546208351042`, 
          1.1225160481424257`}, {2.2557458224306646`, 1.5038996014620387`}, {
          3.416311950401767, 1.1218316872759266`}}], 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{1.0949546208351042`, 
          1.1225160481424257`}, {2.255520748806207, 0.7404481339562624}, {
          3.416311950401767, 1.1218316872759266`}}], 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          2.0711389773642113`, 1.2037620633150274`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          2.072550282090292, 1.0363414336392656`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          2.2171010970874594`, 1.208643057993136}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          2.191836776670801, 1.3531124865225375`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          2.221877138526875, 1.0462538665004264`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          2.175541306185316, 0.9110400306680744}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.684252527229618, 1.6649167644986491`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          2.1239279558903346`, 0.796999070795237}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          2.096090802022171, 1.4304125518764177`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.36732927770745905`, 1.2897270066595432`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.12781817999146616`, 1.5582124639903465`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.8460425963427867, 0.5084601131599155}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.290107724942267, 1.0017811649868076`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.9431613558170271, 0.2906241370069952}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.3871156542833898, 1.5791786414552247`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.7041298728531082, 0.24746903843607826`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.5137046255105804, 0.3486891942121616}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.12352150895423453`, 1.179232123319753}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.044288518247914244`, 1.3608628118516541`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.12328697201290684`, 0.808437643725676}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.2500477763142941, 1.7632883689984138`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.3190074881517644, 0.42774689294197765`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.394766362835957, 0.6771915125532246}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.8451790927260363, 2.0060867969667857`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.5425455414151905, 0.9678692263199912}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.15616053069051183`, 0.5973907539862777}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {0., 
          0.9976001778498215}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.4387061585173715, 1.871431891657605}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.9423282739402967, 1.7973832239491039`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.6143794088942331, 1.3656110986254721`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.6189962579245876, 1.9717050629225161`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.0949546208351042`, 1.1225160481424257`}, {
          0.6477691695151471, 0.6670732645245393}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.0711389773642113`, 1.2037620633150274`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.072550282090292, 1.0363414336392656`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.2171010970874594`, 1.208643057993136}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.191836776670801, 1.3531124865225375`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.221877138526875, 1.0462538665004264`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.175541306185316, 0.9110400306680744}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.1239279558903346`, 0.796999070795237}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.096090802022171, 1.4304125518764177`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.590905487227156, 1.0792000049151969`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.014119307682726, 0.12531173988351496`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.996604848139021, 0.1450345498712754}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.929016743262579, 0.4721678200222219}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.1067037977021967`, 1.9415755275231983`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.9933207360568845`, 1.247103494309129}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.8303663711703386`, 1.4949913301738462`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.3244692472708226`, 1.6020584949756453`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.826680256966454, 0.29541844637443637`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.872772849445458, 0.9623977573491631}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.173703101687753, 1.3184935152238881`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.6100473023197637`, 0.4334428773620701}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.9700477125306213`, 0.3801785278316072}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.8894236862855767`, 1.6322035405387525`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.350035922080192, 1.8491282925283792`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.9040426502331615`, 1.9174546110490085`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.883679308540083, 2.032465196020128}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.7490285090858375`, 0.26964166627044606`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.818446385571276, 0.0345539651192972}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.5578496688605545`, 0.8838372528991891}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.0952041199887437`, 2.1808664432363765`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.997506635140303, 1.7001485406169852`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.564021447969479, 1.4977955276090147`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.8584184566149373`, 0.9668709027958297}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.3999862739340614`, 0.}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.3626449916158307`, 2.2662856657905723`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.418093762427094, 0.5177616360907961}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.64987882131408, 2.002054964549215}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.602108386826861, 0.694768762865711}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.178203896246221, 1.995799845815145}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.012989555913835, 2.128420157824752}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.180913213641553, 0.236591443823445}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.328767531933005, 2.070650083362428}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.0327481292443754`, 0.7087103166277062}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.172708526234244, 1.5617234142238423`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.746136425070943, 0.6187253578171831}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.6075320771017694`, 2.238340621013826}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.51317402184503, 0.6901460217452287}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.8058284647341676`, 1.3536139180146558`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {4.1457099529502,
           0.5877573547540184}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.8178052029502876`, 2.193452531349382}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.298673346175474, 0.8160336542276176}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.109613153399747, 1.7643802043707484`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.215064254300674, 0.2896227615712551}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          2.7595286775598966`, 1.7993244436884628`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.425777055014457, 1.6623119730392077`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.6089283726621737`, 0.013255856571747993`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.266315206738794, 0.5373198774776022}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.280095356125587, 0.39579303022068535`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.4251733249582306`, 1.8871236543224157`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.2142871672257947`, 0.07088642504398424}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.4731893448331843`, 0.2336728732565041}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.3627870935773245`, 1.0935836975189934`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.124646224794956, 1.0471438393106296`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.38485796596837, 1.3975012097810688`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          4.575944090157276, 1.2749104207835669`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.629867671955528, 1.7096426609765614`}}, 0.04065604207530167]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.416311950401767, 1.1218316872759266`}, {
          3.965750606749431, 0.7182813188369249}}, 0.04065604207530167]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {
         DiskBox[{1.0949546208351042`, 1.1225160481424257`}, 
          0.04065604207530167], 
         InsetBox["\<\"thrL\"\>", 
          Offset[{2, 2}, {1.135610662910406, 1.1631720902177274`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.416311950401767, 1.1218316872759266`}, 
          0.04065604207530167], 
         InsetBox["\<\"thrA\"\>", 
          Offset[{2, 2}, {3.4569679924770687`, 1.1624877293512283`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.0711389773642113`, 1.2037620633150274`}, 
          0.04065604207530167], 
         InsetBox["\<\"thrB\"\>", 
          Offset[{2, 2}, {2.111795019439513, 1.2444181053903292`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.072550282090292, 1.0363414336392656`}, 
          0.04065604207530167], 
         InsetBox["\<\"thrC\"\>", 
          Offset[{2, 2}, {2.113206324165594, 1.0769974757145673`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.2171010970874594`, 1.208643057993136}, 
          0.04065604207530167], 
         InsetBox["\<\"yaaX\"\>", 
          Offset[{2, 2}, {2.257757139162761, 1.2492991000684377`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.191836776670801, 1.3531124865225375`}, 
          0.04065604207530167], 
         InsetBox["\<\"yaaA\"\>", 
          Offset[{2, 2}, {2.2324928187461026`, 1.3937685285978392`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.221877138526875, 1.0462538665004264`}, 
          0.04065604207530167], 
         InsetBox["\<\"yaaJ\"\>", 
          Offset[{2, 2}, {2.2625331806021767`, 1.0869099085757281`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.175541306185316, 0.9110400306680744}, 
          0.04065604207530167], 
         InsetBox["\<\"leuB\"\>", 
          Offset[{2, 2}, {2.216197348260618, 0.9516960727433761}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.684252527229618, 1.6649167644986491`}, 
          0.04065604207530167], 
         InsetBox["\<\"leuL\"\>", 
          Offset[{2, 2}, {0.7249085693049198, 1.7055728065739508`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.1239279558903346`, 0.796999070795237}, 
          0.04065604207530167], 
         InsetBox["\<\"proA\"\>", 
          Offset[{2, 2}, {2.1645839979656363`, 0.8376551128705387}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.096090802022171, 1.4304125518764177`}, 
          0.04065604207530167], 
         InsetBox["\<\"argF\"\>", 
          Offset[{2, 2}, {2.136746844097473, 1.4710685939517194`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.36732927770745905`, 1.2897270066595432`}, 
          0.04065604207530167], 
         InsetBox["\<\"matA\"\>", 
          Offset[{2, 2}, {0.4079853197827607, 1.330383048734845}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.12781817999146616`, 1.5582124639903465`}, 
          0.04065604207530167], 
         InsetBox["\<\"lacY\"\>", 
          Offset[{2, 2}, {0.16847422206676782`, 1.5988685060656482`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.8460425963427867, 0.5084601131599155}, 
          0.04065604207530167], 
         InsetBox["\<\"tsx\"\>", 
          Offset[{2, 2}, {0.8866986384180884, 0.5491161552352172}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.290107724942267, 1.0017811649868076`}, 
          0.04065604207530167], 
         InsetBox["\<\"thiI\"\>", 
          Offset[{2, 2}, {0.33076376701756866`, 1.0424372070621093`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.9431613558170271, 0.2906241370069952}, 
          0.04065604207530167], 
         InsetBox["\<\"potG\"\>", 
          Offset[{2, 2}, {0.9838173978923288, 0.33128017908229684`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.3871156542833898, 1.5791786414552247`}, 
          0.04065604207530167], 
         InsetBox["\<\"b1265\"\>", 
          Offset[{2, 2}, {0.42777169635869144`, 1.6198346835305264`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.7041298728531082, 0.24746903843607826`}, 
          0.04065604207530167], 
         InsetBox["\<\"asr\"\>", 
          Offset[{2, 2}, {0.74478591492841, 0.2881250805113799}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.5137046255105804, 0.3486891942121616}, 
          0.04065604207530167], 
         InsetBox["\<\"b1715\"\>", 
          Offset[{2, 2}, {0.5543606675858821, 0.38934523628746326`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.12352150895423453`, 1.179232123319753}, 
          0.04065604207530167], 
         InsetBox["\<\"sbcB\"\>", 
          Offset[{2, 2}, {0.16417755102953618`, 1.2198881653950546`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.044288518247914244`, 1.3608628118516541`}, 
          0.04065604207530167], 
         InsetBox["\<\"b2018\"\>", 
          Offset[{2, 2}, {0.08494456032321591, 1.4015188539269559`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.12328697201290684`, 0.808437643725676}, 
          0.04065604207530167], 
         InsetBox["\<\"yfaW\"\>", 
          Offset[{2, 2}, {0.1639430140882085, 0.8490936858009777}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.2500477763142941, 1.7632883689984138`}, 
          0.04065604207530167], 
         InsetBox["\<\"b2598\"\>", 
          Offset[{2, 2}, {0.29070381838959575`, 1.8039444110737155`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.3190074881517644, 0.42774689294197765`}, 
          0.04065604207530167], 
         InsetBox["\<\"rpsL\"\>", 
          Offset[{2, 2}, {0.35966353022706604`, 0.4684029350172793}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.394766362835957, 0.6771915125532246}, 
          0.04065604207530167], 
         InsetBox["\<\"yhjE\"\>", 
          Offset[{2, 2}, {0.43542240491125866`, 0.7178475546285263}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.8451790927260363, 2.0060867969667857`}, 
          0.04065604207530167], 
         InsetBox["\<\"ivbL\"\>", 
          Offset[{2, 2}, {0.885835134801338, 2.0467428390420874`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.5425455414151905, 0.9678692263199912}, 
          0.04065604207530167], 
         InsetBox["\<\"ilvL\"\>", 
          Offset[{2, 2}, {0.5832015834904922, 1.0085252683952928`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.15616053069051183`, 0.5973907539862777}, 
          0.04065604207530167], 
         InsetBox["\<\"pyrL\"\>", 
          Offset[{2, 2}, {0.1968165727658135, 0.6380467960615794}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0., 0.9976001778498215}, 0.04065604207530167], 
         InsetBox["\<\"argI\"\>", 
          Offset[{2, 2}, {0.04065604207530167, 1.038256219925123}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.4387061585173715, 1.871431891657605}, 
          0.04065604207530167], 
         InsetBox["\<\"fimA\"\>", 
          Offset[{2, 2}, {0.47936220059267315`, 1.9120879337329066`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.9423282739402967, 1.7973832239491039`}, 
          0.04065604207530167], 
         InsetBox["\<\"hsdM\"\>", 
          Offset[{2, 2}, {0.9829843160155984, 1.8380392660244056`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.6143794088942331, 1.3656110986254721`}, 
          0.04065604207530167], 
         InsetBox["\<\"hsdR\"\>", 
          Offset[{2, 2}, {0.6550354509695349, 1.4062671407007739`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.6189962579245876, 1.9717050629225161`}, 
          0.04065604207530167], 
         InsetBox["\<\"yifL\"\>", 
          Offset[{2, 2}, {0.6596522999998893, 2.012361104997818}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.6477691695151471, 0.6670732645245393}, 
          0.04065604207530167], 
         InsetBox["\<\"b4605\"\>", 
          Offset[{2, 2}, {0.6884252115904488, 0.707729306599841}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.590905487227156, 1.0792000049151969`}, 
          0.04065604207530167], 
         InsetBox["\<\"ribF\"\>", 
          Offset[{2, 2}, {4.6315615293024575`, 1.1198560469904986`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.014119307682726, 0.12531173988351496`}, 
          0.04065604207530167], 
         InsetBox["\<\"dapB\"\>", 
          Offset[{2, 2}, {4.054775349758028, 0.16596778195881662`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.996604848139021, 0.1450345498712754}, 
          0.04065604207530167], 
         InsetBox["\<\"carB\"\>", 
          Offset[{2, 2}, {3.0372608902143226`, 0.18569059194657705`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.929016743262579, 0.4721678200222219}, 
          0.04065604207530167], 
         InsetBox["\<\"surA\"\>", 
          Offset[{2, 2}, {2.9696727853378806`, 0.5128238620975236}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.1067037977021967`, 1.9415755275231983`}, 
          0.04065604207530167], 
         InsetBox["\<\"lptD\"\>", 
          Offset[{2, 2}, {3.1473598397774984`, 1.9822315695985}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.9933207360568845`, 1.247103494309129}, 
          0.04065604207530167], 
         InsetBox["\<\"leuD\"\>", 
          Offset[{2, 2}, {3.0339767781321862`, 1.2877595363844307`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.8303663711703386`, 1.4949913301738462`}, 
          0.04065604207530167], 
         InsetBox["\<\"leuC\"\>", 
          Offset[{2, 2}, {2.8710224132456403`, 1.535647372249148}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.3244692472708226`, 1.6020584949756453`}, 
          0.04065604207530167], 
         InsetBox["\<\"leuA\"\>", 
          Offset[{2, 2}, {3.3651252893461243`, 1.642714537050947}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.826680256966454, 0.29541844637443637`}, 
          0.04065604207530167], 
         InsetBox["\<\"ilvI\"\>", 
          Offset[{2, 2}, {2.8673362990417557`, 0.33607448844973803`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.872772849445458, 0.9623977573491631}, 
          0.04065604207530167], 
         InsetBox["\<\"ilvH\"\>", 
          Offset[{2, 2}, {3.9134288915207596`, 1.0030537994244648`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.173703101687753, 1.3184935152238881`}, 
          0.04065604207530167], 
         InsetBox["\<\"murD\"\>", 
          Offset[{2, 2}, {4.214359143763055, 1.3591495572991898`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.6100473023197637`, 0.4334428773620701}, 
          0.04065604207530167], 
         InsetBox["\<\"murC\"\>", 
          Offset[{2, 2}, {3.6507033443950654`, 0.47409891943737176`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.9700477125306213`, 0.3801785278316072}, 
          0.04065604207530167], 
         InsetBox["\<\"mutT\"\>", 
          Offset[{2, 2}, {4.010703754605923, 0.4208345699069089}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.8894236862855767`, 1.6322035405387525`}, 
          0.04065604207530167], 
         InsetBox["\<\"can\"\>", 
          Offset[{2, 2}, {3.9300797283608784`, 1.6728595826140542`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.350035922080192, 1.8491282925283792`}, 
          0.04065604207530167], 
         InsetBox["\<\"mrcB\"\>", 
          Offset[{2, 2}, {4.390691964155494, 1.889784334603681}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.9040426502331615`, 1.9174546110490085`}, 
          0.04065604207530167], 
         InsetBox["\<\"dapD\"\>", 
          Offset[{2, 2}, {3.9446986923084633`, 1.9581106531243102`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.883679308540083, 2.032465196020128}, 0.04065604207530167],
          InsetBox["\<\"cdsA\"\>", 
          Offset[{2, 2}, {2.924335350615385, 2.0731212380954296`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.7490285090858375`, 0.26964166627044606`}, 
          0.04065604207530167], 
         InsetBox["\<\"lpxD\"\>", 
          Offset[{2, 2}, {3.7896845511611392`, 0.3102977083457477}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.818446385571276, 0.0345539651192972}, 
          0.04065604207530167], 
         InsetBox["\<\"lpxA\"\>", 
          Offset[{2, 2}, {3.8591024276465777`, 0.07521000719459887}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.5578496688605545`, 0.8838372528991891}, 
          0.04065604207530167], 
         InsetBox["\<\"accA\"\>", 
          Offset[{2, 2}, {4.598505710935856, 0.9244932949744908}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.0952041199887437`, 2.1808664432363765`}, 
          0.04065604207530167], 
         InsetBox["\<\"tilS\"\>", 
          Offset[{2, 2}, {3.1358601620640454`, 2.221522485311678}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.997506635140303, 1.7001485406169852`}, 
          0.04065604207530167], 
         InsetBox["\<\"yaeJ\"\>", 
          Offset[{2, 2}, {3.0381626772156047`, 1.7408045826922869`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.564021447969479, 1.4977955276090147`}, 
          0.04065604207530167], 
         InsetBox["\<\"gmhA\"\>", 
          Offset[{2, 2}, {4.60467749004478, 1.5384515696843164`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.8584184566149373`, 0.9668709027958297}, 
          0.04065604207530167], 
         InsetBox["\<\"proB\"\>", 
          Offset[{2, 2}, {2.899074498690239, 1.0075269448711313`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.3999862739340614`, 0.}, 0.04065604207530167], 
         InsetBox["\<\"mmuM\"\>", 
          Offset[{2, 2}, {3.440642316009363, 0.04065604207530167}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.3626449916158307`, 2.2662856657905723`}, 
          0.04065604207530167], 
         InsetBox["\<\"yagE\"\>", 
          Offset[{2, 2}, {3.4033010336911325`, 2.306941707865874}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.418093762427094, 0.5177616360907961}, 
          0.04065604207530167], 
         InsetBox["\<\"ykgM\"\>", 
          Offset[{2, 2}, {4.458749804502395, 0.5584176781660978}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.64987882131408, 2.002054964549215}, 0.04065604207530167], 
         InsetBox["\<\"ykgE\"\>", 
          Offset[{2, 2}, {3.6905348633893817`, 2.0427110066245167`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.602108386826861, 0.694768762865711}, 0.04065604207530167],
          InsetBox["\<\"mhpE\"\>", 
          Offset[{2, 2}, {3.642764428902163, 0.7354248049410127}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.178203896246221, 1.995799845815145}, 0.04065604207530167],
          InsetBox["\<\"proC\"\>", 
          Offset[{2, 2}, {4.218859938321523, 2.0364558878904466`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.012989555913835, 2.128420157824752}, 0.04065604207530167],
          InsetBox["\<\"aroL\"\>", 
          Offset[{2, 2}, {4.053645597989137, 2.169076199900054}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.180913213641553, 0.236591443823445}, 0.04065604207530167],
          InsetBox["\<\"rdgC\"\>", 
          Offset[{2, 2}, {4.2215692557168545`, 0.27724748589874665`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.328767531933005, 2.070650083362428}, 0.04065604207530167],
          InsetBox["\<\"queA\"\>", 
          Offset[{2, 2}, {3.3694235740083065`, 2.11130612543773}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.0327481292443754`, 0.7087103166277062}, 
          0.04065604207530167], 
         InsetBox["\<\"nrdR\"\>", 
          Offset[{2, 2}, {3.073404171319677, 0.7493663587030079}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.172708526234244, 1.5617234142238423`}, 
          0.04065604207530167], 
         InsetBox["\<\"ribD\"\>", 
          Offset[{2, 2}, {4.2133645683095455`, 1.602379456299144}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.746136425070943, 0.6187253578171831}, 
          0.04065604207530167], 
         InsetBox["\<\"ribE\"\>", 
          Offset[{2, 2}, {2.7867924671462445`, 0.6593813998924848}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.6075320771017694`, 2.238340621013826}, 
          0.04065604207530167], 
         InsetBox["\<\"nusB\"\>", 
          Offset[{2, 2}, {3.648188119177071, 2.278996663089128}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.51317402184503, 0.6901460217452287}, 0.04065604207530167],
          InsetBox["\<\"cyoE\"\>", 
          Offset[{2, 2}, {4.553830063920332, 0.7308020638205304}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.8058284647341676`, 1.3536139180146558`}, 
          0.04065604207530167], 
         InsetBox["\<\"cyoB\"\>", 
          Offset[{2, 2}, {3.8464845068094693`, 1.3942699600899575`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.1457099529502, 0.5877573547540184}, 0.04065604207530167], 
         InsetBox["\<\"tig\"\>", 
          Offset[{2, 2}, {4.186365995025501, 0.6284133968293201}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.8178052029502876`, 2.193452531349382}, 
          0.04065604207530167], 
         InsetBox["\<\"ybaV\"\>", 
          Offset[{2, 2}, {3.8584612450255893`, 2.2341085734246837`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.298673346175474, 0.8160336542276176}, 
          0.04065604207530167], 
         InsetBox["\<\"tesC\"\>", 
          Offset[{2, 2}, {4.339329388250776, 0.8566896963029194}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.109613153399747, 1.7643802043707484`}, 
          0.04065604207530167], 
         InsetBox["\<\"tesB\"\>", 
          Offset[{2, 2}, {4.150269195475048, 1.80503624644605}], ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.215064254300674, 0.2896227615712551}, 
          0.04065604207530167], 
         InsetBox["\<\"dnaX\"\>", 
          Offset[{2, 2}, {3.255720296375976, 0.33027880364655676`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.7595286775598966`, 1.7993244436884628`}, 
          0.04065604207530167], 
         InsetBox["\<\"recR\"\>", 
          Offset[{2, 2}, {2.8001847196351983`, 1.8399804857637645`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.425777055014457, 1.6623119730392077`}, 
          0.04065604207530167], 
         InsetBox["\<\"htpG\"\>", 
          Offset[{2, 2}, {4.466433097089759, 1.7029680151145095`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.6089283726621737`, 0.013255856571747993`}, 
          0.04065604207530167], 
         InsetBox["\<\"cysS\"\>", 
          Offset[{2, 2}, {3.6495844147374754`, 0.053911898647049664`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.266315206738794, 0.5373198774776022}, 
          0.04065604207530167], 
         InsetBox["\<\"folD\"\>", 
          Offset[{2, 2}, {3.306971248814096, 0.577975919552904}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.280095356125587, 0.39579303022068535`}, 
          0.04065604207530167], 
         InsetBox["\<\"ompT\"\>", 
          Offset[{2, 2}, {4.320751398200889, 0.436449072295987}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.4251733249582306`, 1.8871236543224157`}, 
          0.04065604207530167], 
         InsetBox["\<\"ybdG\"\>", 
          Offset[{2, 2}, {3.4658293670335323`, 1.9277796963977174`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.2142871672257947`, 0.07088642504398424}, 
          0.04065604207530167], 
         InsetBox["\<\"ybdL\"\>", 
          Offset[{2, 2}, {3.2549432093010964`, 0.1115424671192859}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.4731893448331843`, 0.2336728732565041}, 
          0.04065604207530167], 
         InsetBox["\<\"dsbG\"\>", 
          Offset[{2, 2}, {3.513845386908486, 0.27432891533180576`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.3627870935773245`, 1.0935836975189934`}, 
          0.04065604207530167], 
         InsetBox["\<\"ahpC\"\>", 
          Offset[{2, 2}, {4.403443135652626, 1.1342397395942951`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.124646224794956, 1.0471438393106296`}, 
          0.04065604207530167], 
         InsetBox["\<\"ahpF\"\>", 
          Offset[{2, 2}, {4.165302266870258, 1.0877998813859313`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.38485796596837, 1.3975012097810688`}, 
          0.04065604207530167], 
         InsetBox["\<\"lipA\"\>", 
          Offset[{2, 2}, {4.425514008043672, 1.4381572518563706`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.575944090157276, 1.2749104207835669`}, 
          0.04065604207530167], 
         InsetBox["\<\"holA\"\>", 
          Offset[{2, 2}, {4.616600132232578, 1.3155664628588686`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.629867671955528, 1.7096426609765614`}, 
          0.04065604207530167], 
         InsetBox["\<\"asnB\"\>", 
          Offset[{2, 2}, {3.6705237140308298`, 1.750298703051863}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.965750606749431, 0.7182813188369249}, 
          0.04065604207530167], 
         InsetBox["\<\"sdhA\"\>", 
          Offset[{2, 2}, {4.006406648824733, 0.7589373609122266}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None,
  ImagePadding->20,
  ImageSize->600]], "Output",
 CellChangeTimes->{3.6775727224705515`*^9}]
}, Open  ]],

Cell["\<\
Der n\[ADoubleDot]chste Analyseschritt wendet sich dem Gesamtnetzwerk zu. Es \
ist sinnvoll, nun eine Schwelle im Score anzuwenden. Ein Histogramm der \
Scores bietet eine erste Orientierung f\[UDoubleDot]r die Wahl der Schwelle.\
\>", "Text",
 CellChangeTimes->{{3.676192656703906*^9, 3.6761927088598022`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{"Drop", "[", 
   RowBox[{
    RowBox[{"network1", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "3"}], "]"}], "]"}], ",", "1"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.621912877556988*^9, 3.6219128896818027`*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
    Opacity[0.5599999999999999], Thickness[Small]}], {}, 
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.5599999999999999], Thickness[Small]}], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{150., 0}, {200., 306518}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{62.01666666666668, 
          78.15392156862747}, {-90.68966716860221, 78.3325234953971}}],
        StatusArea[#, 306518]& ,
        TagBoxNote->"306518"],
       StyleBox["306518", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[306518, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{200., 0}, {250., 154812}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{77.65392156862747, 
          93.79117647058825}, {-7.282404114319334, 78.3325234953971}}],
        StatusArea[#, 154812]& ,
        TagBoxNote->"154812"],
       StyleBox["154812", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[154812, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{250., 0}, {300., 80300}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{93.29117647058825, 109.42843137254904`}, {
          33.68395176284258, 78.3325234953971}}],
        StatusArea[#, 80300]& ,
        TagBoxNote->"80300"],
       StyleBox["80300", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[80300, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{300., 0}, {350., 57158}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{108.92843137254904`, 125.06568627450983`}, {
          46.407317230274415`, 78.3325234953971}}],
        StatusArea[#, 57158]& ,
        TagBoxNote->"57158"],
       StyleBox["57158", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[57158, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{350., 0}, {400., 46100}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{124.56568627450983`, 140.7029411764706}, {
          52.486954916682734`, 78.3325234953971}}],
        StatusArea[#, 46100]& ,
        TagBoxNote->"46100"],
       StyleBox["46100", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[46100, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{400., 0}, {450., 32142}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{140.2029411764706, 156.34019607843138`}, {
          60.160999303270486`, 78.3325234953971}}],
        StatusArea[#, 32142]& ,
        TagBoxNote->"32142"],
       StyleBox["32142", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[32142, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{450., 0}, {500., 22864}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{155.84019607843138`, 171.97745098039218`}, {
          65.26200115301694, 78.3325234953971}}],
        StatusArea[#, 22864]& ,
        TagBoxNote->"22864"],
       StyleBox["22864", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[22864, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{500., 0}, {550., 21978}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{171.47745098039218`, 187.61470588235295`}, {
          65.74911988969245, 78.3325234953971}}],
        StatusArea[#, 21978]& ,
        TagBoxNote->"21978"],
       StyleBox["21978", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[21978, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{550., 0}, {600., 14252}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{187.11470588235295`, 203.25196078431375`}, {
          69.99683925713599, 78.3325234953971}}],
        StatusArea[#, 14252]& ,
        TagBoxNote->"14252"],
       StyleBox["14252", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[14252, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{600., 0}, {650., 12430}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{202.75196078431375`, 218.88921568627453`}, {
          70.99856650117975, 78.3325234953971}}],
        StatusArea[#, 12430]& ,
        TagBoxNote->"12430"],
       StyleBox["12430", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[12430, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{650., 0}, {700., 10002}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{218.38921568627453`, 234.52647058823533`}, {
          72.33346976601963, 78.3325234953971}}],
        StatusArea[#, 10002]& ,
        TagBoxNote->"10002"],
       StyleBox["10002", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[10002, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{700., 0}, {750., 12438}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{234.02647058823533`, 250.1637254901961}, {
          70.99416813786891, 78.3325234953971}}],
        StatusArea[#, 12438]& ,
        TagBoxNote->"12438"],
       StyleBox["12438", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[12438, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{750., 0}, {800., 10858}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{249.6637254901961, 265.80098039215693`}, {
          71.86284489175978, 78.3325234953971}}],
        StatusArea[#, 10858]& ,
        TagBoxNote->"10858"],
       StyleBox["10858", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[10858, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{800., 0}, {850., 7278}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{265.30098039215693`, 281.4382352941177}, {
          73.83111247336059, 78.3325234953971}}],
        StatusArea[#, 7278]& ,
        TagBoxNote->"7278"],
       StyleBox["7278", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[7278, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{850., 0}, {900., 6806}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{280.9382352941177, 297.0754901960785}, {
          74.09061590870013, 78.3325234953971}}],
        StatusArea[#, 6806]& ,
        TagBoxNote->"6806"],
       StyleBox["6806", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[6806, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{900., 0}, {950., 7940}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{296.5754901960785, 312.7127450980393}, {
          73.46714790938859, 78.3325234953971}}],
        StatusArea[#, 7940]& ,
        TagBoxNote->"7940"],
       StyleBox["7940", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[7940, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{950., 0}, {1000., 13774}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{312.2127450980393, 328.3500000000001}, {
          70.25964146495866, 78.3325234953971}}],
        StatusArea[#, 13774]& ,
        TagBoxNote->"13774"],
       StyleBox["13774", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[13774, {}], 
       "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{82., 0},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{100., 1000.}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6775727256841574`*^9}]
}, Open  ]],

Cell[TextData[{
 "Wir wenden eine Schwelle von ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "S"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " = 950 an. Die resultierende Liste hat knapp 14 000 Eintr\[ADoubleDot]ge."
}], "Text",
 CellChangeTimes->{{3.6761927518036814`*^9, 3.676192809947389*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"network1b", " ", "=", " ", 
   RowBox[{"Cases", "[", 
    RowBox[{"network1", " ", ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"n1_", ",", "n2_", ",", "n3_"}], "}"}], " ", "/;", " ", 
      RowBox[{"n3", " ", "\[GreaterEqual]", " ", "950"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.618041057369958*^9, 3.618041089263694*^9}, {
   3.6180413340668173`*^9, 3.618041336929213*^9}, {3.618041705455701*^9, 
   3.6180417287010527`*^9}, 3.62191281732408*^9, 3.621912911317337*^9, {
   3.621913570051446*^9, 3.62191357045455*^9}, {3.621913749116596*^9, 
   3.6219137494396267`*^9}, 3.621913968925776*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Dimensions", "[", "network1b", "]"}], " "}]], "Input",
 CellChangeTimes->{{3.6180332248443947`*^9, 3.618033228644094*^9}, 
   3.619750150334152*^9, 3.6219128202570257`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"13774", ",", "3"}], "}"}]], "Output",
 CellChangeTimes->{3.67757272715056*^9}]
}, Open  ]],

Cell[TextData[{
 "Als N\[ADoubleDot]chstes \[UDoubleDot]berf\[UDoubleDot]hren wir die so \
gefilterte Kantenliste in einen ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Graphen (mit den bereits oben eingef\[UDoubleDot]hrten \
Datenprozessierungen) und w\[ADoubleDot]hlen dann \[UDoubleDot]ber den Befehl \
",
 StyleBox["ConnectedComponents",
  FontWeight->"Bold"],
 " die gr\[ODoubleDot]\[SZ]te zusammenh\[ADoubleDot]ngende Komponente aus."
}], "Text",
 CellChangeTimes->{{3.6761930245407925`*^9, 3.6761930359900146`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"network1c", " ", "=", " ", 
   RowBox[{
    RowBox[{"Union", "[", 
     RowBox[{"Map", "[", 
      RowBox[{"Sort", ",", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"StringReplace", "[", 
           RowBox[{"#", ",", 
            RowBox[{"\"\<511145.\>\"", "\[Rule]", " ", "\"\<\>\""}]}], "]"}], 
          "&"}], ",", 
         RowBox[{"network1b", "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], ",", "2"}], 
        "]"}]}], " ", "]"}], "]"}], "/.", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n1_", ",", "n2_"}], "}"}], "\[Rule]", " ", 
     RowBox[{"(", 
      RowBox[{"n1", "\[UndirectedEdge]", "n2"}], ")"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.621913441753315*^9, 3.6219134544921503`*^9}, {
  3.62191391295788*^9, 3.621913925024251*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"graph1", " ", "=", " ", 
   RowBox[{"Graph", "[", 
    RowBox[{"Union", "[", "network1c", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.621913399470746*^9, 3.621913407777136*^9}, {
   3.621913457945271*^9, 3.621913458018309*^9}, {3.621913530617638*^9, 
   3.621913535775432*^9}, {3.621913604316576*^9, 3.6219136108256817`*^9}, {
   3.621913664528404*^9, 3.621913670751471*^9}, {3.6219139428687572`*^9, 
   3.621913943453412*^9}, 3.622973175731049*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"graph1b", " ", "=", " ", 
  RowBox[{"Subgraph", "[", 
   RowBox[{"graph1", ",", " ", 
    RowBox[{
     RowBox[{"ConnectedComponents", "[", " ", "graph1", "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.621913543788374*^9, 3.621913551960824*^9}, {
   3.621994997025436*^9, 3.6219949997900543`*^9}, {3.6219961906681967`*^9, 
   3.621996231339135*^9}, 3.6229731847547483`*^9, 3.623828282727331*^9}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "b0724", "b0429", "b0430", "b0431", "b0432", "b0720", "b0721", "b0722", 
       "b0723", "b0726", "b0727", "b0728", "b0729", "b1611", "b1612", "b4154",
        "b0428", "b2277", "b2279", "b2278", "b2281", "b2282", "b2283", 
       "b2284", "b2285", "b2286", "b0463", "b2276", "b0115", "b0116", "b0118",
        "b0771", "b0929", "b1136", "b1276", "b2296", "b2976", "b3236", 
       "b3255", "b3403", "b3956", "b4014", "b4153", "b3850", "b4151", "b4152",
        "b2280", "b2287", "b2288", "b2484", "b1094", "b2488", "b2720", 
       "b0462", "b0464", "b2470", "b3035", "b3266", "b0114", "b2297", "b1676",
        "b2903", "b3781", "b0334", "b0411", "b0957", "b1237", "b1531", 
       "b3405", "b4036", "b0928", "b4016", "b0871", "b2416", "b2458", "b4069",
        "b1101", "b2977", "b2979", "b4015", "b4467", "b4468", "b1479", 
       "b2463", "b3061", "b4122", "b4139", "b4143", "b0185", "b1091", "b1092",
        "b2316", "b3256", "b1702", "b1854", "b0475", "b2436", "b2481", 
       "b2482", "b2483", "b2485", "b2486", "b2487", "b2489", "b2490", "b1093",
        "b1095", "b1288", "b2323", "b2563", "b2717", "b2718", "b2719", 
       "b2721", "b2722", "b2723", "b2724", "b4079", "b0407", "b3513", "b0878",
        "b0879", "b2074", "b2075", "b2076", "b2685", "b2686", "b3514", 
       "b3265", "b0113", "b0351", "b1241", "b2455", "b3115", "b0474", "b1779",
        "b2518", "b2779", "b2925", "b2926", "b4025", "b0529", "b2551", 
       "b2904", "b2905", "b0888", "b3783", "b0331", "b0333", "b0335", "b0098",
        "b0178", "b0344", "b0740", "b0741", "b2215", "b3234", "b3609", 
       "b4172", "b0460", "b0889", "b1625", "b2741", "b3860", "b4312", "b1530",
        "b1532", "b1888", "b3404", "b0053", "b3417", "b3418", "b4032", 
       "b4033", "b4034", "b4035", "b4037", "b0903", "b2464", "b2465", "b2169",
        "b2415", "b2417", "b3723", "b2459", "b2460", "b2462", "b1415", 
       "b3845", "b3846", "b4067", "b4068", "b1594", "b3062", "b4123", "b1131",
        "b2957", "b0014", "b0436", "b0473", "b0607", "b1084", "b1719", 
       "b2096", "b2592", "b2614", "b2942", "b3461", "b4142", "b0180", "b1090",
        "b1089", "b3973", "b3997", "b0954", "b0404", "b2564", "b2726", 
       "b1475", "b0406", "b0408", "b0409", "b2077", "b2078", "b2079", "b0348",
        "b0349", "b0350", "b0352", "b3114", "b2452", "b2453", "b2454", 
       "b2456", "b2457", "b3113", "b3116", "b3117", "b0168", "b0469", "b2234",
        "b3734", "b3736", "b3919", "b0171", "b1098", "b2580", "b2780", 
       "b3648", "b0755", "b3612", "b4395", "b0008", "b2935", "b4232", "b2927",
        "b0394", "b0688", "b1613", "b1852", "b3729", "b3916", "b1232", 
       "b2500", "b3288", "b3941", "b4006", "b0048", "b0870", "b2315", "b2827",
        "b3828", "b4019", "b4388", "b4386", "b0605", "b3961", "b0189", 
       "b3982", "b2919", "b0093", "b0383", "b2610", "b3175", "b3300", "b3705",
        "b3981", "b0177", "b0179", "b0241", "b0342", "b0343", "b0345", 
       "b0757", "b3357", "b4043", "b0737", "b0738", "b0739", "b0742", "b3006",
        "b1209", "b1677", "b0161", "b3608", "b3610", "b3611", "b0143", 
       "b4171", "b4313", "b0145", "b1040", "b1235", "b1732", "b1914", "b2742",
        "b3202", "b3261", "b3806", "b1185", "b2195", "b3859", "b1071", 
       "b1076", "b1078", "b1082", "b1083", "b1421", "b1881", "b1882", "b1883",
        "b1884", "b1885", "b1886", "b1887", "b1889", "b1890", "b1891", 
       "b1892", "b1921", "b1922", "b1923", "b1924", "b1925", "b1926", "b1939",
        "b1945", "b1946", "b3072", "b3868", "b4355", "b0399", "b0049", 
       "b0051", "b0052", "b3347", "b0403", "b3416", "b3429", "b3430", "b3431",
        "b3432", "b0476", "b1622", "b0902", "b0904", "b0897", "b1004", 
       "b1051", "b1482", "b1783", "b1896", "b1897", "b2097", "b3012", "b4376",
        "b2914", "b3386", "b2167", "b2168", "b3749", "b1736", "b1817", 
       "b1819", "b2383", "b2829", "b3599", "b0239", "b0679", "b1511", "b1621",
        "b2429", "b2715", "b3926", "b4240", "b3721", "b3722", "b3988", 
       "b2439", "b2440", "b2451", "b2461", "b2150", "b2799", "b3605", "b0221",
        "b2341", "b1395", "b1695", "b2224", "b2342", "b2844", "b1976", 
       "b0523", "b1132", "b2312", "b2476", "b2507", "b2557", "b4005", "b4177",
        "b0015", "b0437", "b1000", "b3687", "b3931", "b3932", "b0169", 
       "b0170", "b0911", "b2607", "b3065", "b3185", "b3186", "b3230", "b3231",
        "b3294", "b3303", "b3305", "b3307", "b3308", "b3309", "b3312", 
       "b3313", "b3314", "b3315", "b3316", "b3317", "b3318", "b3319", "b3320",
        "b3321", "b3340", "b3341", "b3637", "b3980", "b3983", "b3984", 
       "b3985", "b4200", "b4202", "b4203", "b3164", "b3780", "b1718", "b2091",
        "b2092", "b2093", "b2094", "b2095", "b3132", "b2069", "b3178", 
       "b0261", "b3829", "b3938", "b2573", "b3702", "b0096", "b0181", "b0182",
        "b1088", "b3018", "b3059", "b4041", "b1716", "b1717", "b2185", 
       "b2606", "b3299", "b3301", "b3302", "b3304", "b3310", "b3636", "b3703",
        "b3936", "b3986", "b0775", "b0369", "b2197", "b2199", "b3368", 
       "b3804", "b3805", "b3867", "b1187", "b1638", "b2418", "b2565", "b2727",
        "b2728", "b2729", "b2730", "b1474", "b1476", "b3894", "b0405", 
       "b0346", "b0347", "b2541", "b4471", "b0004", "b0073", "b0077", "b2366",
        "b3118", "b3616", "b3671", "b0104", "b0477", "b3665", "b4384", 
       "b2235", "b2675", "b2676", "b3731", "b3732", "b3733", "b3735", "b3737",
        "b3738", "b3306", "b0910", "b1281", "b2066", "b2498", "b1096", 
       "b1097", "b1099", "b1238", "b3640", "b2159", "b3635", "b2781", "b3987",
        "b3649", "b3650", "b4090", "b0758", "b1236", "b3428", "b2048", 
       "b1851", "b2029", "b4062", "b0677", "b3176", "b3730", "b1233", "b1849",
        "b0522", "b2499", "b2114", "b3287", "b3939", "b4013", "b2508", 
       "b3177", "b2828", "b2687", "b3008", "b0907", "b0628", "b0606", "b1656",
        "b3908", "b3942", "b0416", "b3295", "b2917", "b2920", "b0083", 
       "b0084", "b0086", "b0088", "b0089", "b0090", "b0092", "b0094", "b0095",
        "b0890", "b2748", "b3933", "b2609", "b3464", "b2608", "b3296", 
       "b3297", "b3298", "b3311", "b3342", "b4201", "b3704", "b4557", "b0176",
        "b2477", "b2512", "b2595", "b0524", "b0915", "b3633", "b0756", 
       "b0759", "b0064", "b3067", "b3934", "b4118", "b0231", "b0779", "b0958",
        "b2699", "b0736", "b3005", "b0150", "b0151", "b0152", "b0153", 
       "b0584", "b0590", "b0592", "b1102", "b1252", "b1711", "b3966", "b4290",
        "b4291", "b4367", "b0891", "b1208", "b0192", "b3235", "b3911", 
       "b0142", "b4169", "b4170", "b4173", "b0385", "b1037", "b1038", "b1039",
        "b1041", "b1646", "b1913", "b1916", "b2786", "b3289", "b1303", 
       "b0023", "b1274", "b3260", "b2153", "b4238", "b2194", "b2196", "b2200",
        "b2201", "b4136", "b1070", "b1072", "b1073", "b1074", "b1075", 
       "b1077", "b1079", "b1080", "b1081", "b1879", "b1880", "b1938", "b1940",
        "b1941", "b1942", "b1943", "b1944", "b1948", "b1937", "b1949", 
       "b3210", "b3525", "b1194", "b1947", "b1950", "b0451", "b2553", "b3869",
        "b3870", "b0400", "b4399", "b0050", "b2696", "b3571", "b4119", 
       "b2080", "b2266", "b2665", "b3555", "b1003", "b3098", "b1050", "b1188",
        "b1724", "b1480", "b1739", "b1678", "b1784", "b2672", "b4239", 
       "b1197", "b3519", "b0453", "b3384", "b3385", "b3748", "b3750", "b3751",
        "b1733", "b1737", "b1738", "b1818", "b2386", "b3206", "b3600", 
       "b3601", "b2428", "b1512", "b1513", "b1514", "b1515", "b1516", "b1517",
        "b1518", "b1620", "b2430", "b2716", "b2239", "b2240", "b2241", 
       "b3426", "b3927", "b3945", "b4241", "b2438", "b2441", "b2148", "b2149",
        "b2800", "b3902", "b2133", "b3603", "b3604", "b1701", "b1805", 
       "b1387", "b1393", "b1394", "b1397", "b1698", "b2221", "b2222", "b2223",
        "b1133", "b0032", "b0033", "b1207", "b2313", "b0125", "b0238", 
       "b2708", "b3197", "b2954", "b2526", "b0438", "b0439", "b0882", "b0999",
        "b3686", "b0421", "b0172", "b3165", "b3168", "b3339", "b3066", 
       "b4147", "b0884", "b4565", "b4304", "b3133", "b3137", "b3141", "b3179",
        "b0260", "b2570", "b2571", "b2572", "b0687", "b3149", "b3262", 
       "b3699", "b3700", "b3701", "b3741", "b3742", "b4052", "b3831", "b0183",
        "b1054", "b0175", "b2891", "b2938", "b0774", "b0776", "b0777", 
       "b0778", "b1593", "b0154", "b1210", "b2198", "b4074", "b2750", "b2752",
        "b2762", "b2763", "b3367", "b3803", "b4018", "b1636", "b1637", 
       "b0472", "b2566", "b4059", "b2990", "b2994", "b2712", "b1224", "b3891",
        "b3893", "b3892", "b2538", "b2539", "b2540", "b2542", "b0002", 
       "b0003", "b3772", "b0071", "b0072", "b0074", "b0078", "b3670", "b3774",
        "b3771", "b2365", "b2797", "b3617", "b1623", "b4374", "b2143", 
       "b2407", "b4382", "b4383", "b2236", "b2673", "b2674", "b3739", "b4226",
        "b0908", "b0945", "b1282", "b3642", "b4245", "b0337", "b2497", 
       "b1812", "b3360", "b0470", "b0640", "b4259", "b4372", "b3639", "b3641",
        "b1633", "b1749", "b2961", "b2782", "b2783", "b2784", "b1114", 
       "b3169", "b3651", "b4084", "b4085", "b2042", "b2049", "b1850", "b3437",
        "b4268", "b4063", "b0676", "b0678", "b3223", "b3189", "b0194", 
       "b0680", "b0930", "b1876", "b2400", "b3940", "b3058", "b0159", "b2414",
        "b2421", "b2521", "b2320", "b2913", "b0630", "b0415", "b0417", 
       "b1275", "b2918", "b0081", "b0082", "b0085", "b0087", "b0149", "b0634",
        "b2519", "b3251", "b3396", "b0091", "b0381", "b4053", "b3967", 
       "b3972", "b0635", "b2412", "b2910", "b0924", "b1176", "b3463", "b3019",
        "b3030", "b2817", "b3462", "b0467", "b4362", "b0174", "b2513", 
       "b2617", "b0914", "b0918", "b2378", "b3621", "b3632", "b2837", "b0063",
        "b0650", "b2213", "b3905", "b3906", "b3995", "b1183", "b3813", 
       "b4058", "b2616", "b0060", "b1061", "b1184", "b2698", "b3822", "b0589",
        "b4288", "b4289", "b0588", "b0583", "b0585", "b0586", "b0593", 
       "b0594", "b0595", "b0596", "b0981", "b2155", "b4287", "b0158", "b1246",
        "b1709", "b1270", "b4292", "b4293", "b1116", "b0173", "b2746", 
       "b2747", "b3912", "b4484", "b1960", "b2733", "b2831", "b4174", "b4175",
        "b1042", "b1043", "b4371", "b1304", "b1305", "b0693", "b2765", 
       "b4237", "b4075", "b2202", "b0604", "b2893", "b4135", "b4137", "b1878",
        "b4401", "b0450", "b0167", "b3053", "b0674", "b1014", "b1761", 
       "b3212", "b3213", "b1130", "b3724", "b3725", "b4398", "b4400", "b4120",
        "b1836", "b3097", "b3099", "b3100", "b3362", "b0812", "b0953", 
       "b1734", "b2384", "b2385", "b2387", "b3204", "b2705", "b2933", "b1640",
        "b2243", "b3449", "b2242", "b3423", "b2151", "b2803", "b3901", 
       "b3903", "b3904", "b1390", "b1388", "b1389", "b1391", "b1392", "b1396",
        "b1398", "b0041", "b1697", "b1699", "b2770", "b0969", "b0273", 
       "b1062", "b3958", "b3959", "b4244", "b4254", "b3752", "b1215", "b3198",
        "b3199", "b3200", "b2955", "b3643", "b2524", "b2525", "b2527", 
       "b2528", "b2529", "b2530", "b3228", "b0881", "b0420", "b0422", "b2889",
        "b3166", "b3167", "b3170", "b4361", "b4146", "b4155", "b4302", 
       "b4303", "b4305", "b3139", "b3140", "b3138", "b3147", "b3148", "b3150",
        "b0101", "b2009", "b2231", "b0184", "b0215", "b3706", "b3740", 
       "b1610", "b0214", "b1855", "b0789", "b1249", "b1912", "b2585", "b4042",
        "b2890", "b2937", "b3412", "b1211", "b4070", "b4072", "b4073", 
       "b4076", "b2422", "b2423", "b2751", "b2764", "b2425", "b3366", "b3802",
        "b0471", "b2567", "b3935", "b2991", "b2992", "b2993", "b2995", 
       "b2996", "b2997", "b0827", "b1223", "b1225", "b1226", "b1227", "b1465",
        "b1466", "b1467", "b3365", "b3856", "b3857", "b3895", "b2319", 
       "b2478", "b3433", "b3769", "b3770", "b3773", "b2796", "b2291", "b2405",
        "b2883", "b4381", "b0388", "b1693", "b2329", "b3281", "b3389", 
       "b3390", "b0336", "b1263", "b1264", "b0639", "b0641", "b4258", "b4373",
        "b0103", "b3634", "b3974", "b1630", "b1631", "b1632", "b2798", 
       "b4224", "b4225", "b3652", "b4086", "b4087", "b2052", "b2053", "b3526",
        "b3438", "b4476", "b4266", "b3221", "b3222", "b3225", "b3190", 
       "b0026", "b0642", "b0121", "b3607", "b0414", "b1277", "b1662", "b3041",
        "b0418", "b1106", "b3993", "b3809", "b1105", "b1782", "b3250", 
       "b2520", "b2516", "b3249", "b0633", "b0921", "b0922", "b0923", "b1174",
        "b1175", "b1575", "b3187", "b2514", "b3052", "b3619", "b3620", 
       "b3622", "b3630", "b3631", "b3625", "b3628", "b4000", "b0061", "b0062",
        "b3583", "b0646", "b0649", "b2068", "b2212", "b0962", "b1763", 
       "b4511", "b3475", "b0597", "b2264", "b2265", "b0982", "b0983", "b0985",
        "b1243", "b1244", "b1245", "b1247", "b1329", "b1710", "b1993", 
       "b1117", "b1118", "b0029", "b2515", "b2745", "b1961", "b1306", "b1307",
        "b0692", "b0444", "b2777", "b2203", "b2204", "b2205", "b2206", 
       "b2207", "b2208", "b2892", "b0386", "b1015", "b1129", "b1642", "b2259",
        "b4114", "b3726", "b3727", "b3728", "b1953", "b3361", "b2702", 
       "b2703", "b2704", "b2706", "b2934", "b3450", "b3451", "b3452", "b3424",
        "b2801", "b2802", "b2805", "b1399", "b0042", "b0043", "b0044", 
       "b2769", "b1700", "b3345", "b0323", "b0521", "b2818", "b2874", "b3172",
        "b3237", "b3957", "b0860", "b3359", "b3960", "b3753", "b3201", 
       "b3196", "b2531", "b0423", "b0826", "b3470", "b3992", "b3229", "b2509",
        "b0058", "b2183", "b2318", "b2594", "b4300", "b3146", "b0102", 
       "b1842", "b0788", "b0790", "b4160", "b2965", "b1212", "b1213", "b4071",
        "b2424", "b3917", "b1287", "b0973", "b0009", "b0781", "b0782", 
       "b0783", "b0785", "b1468", "b4024", "b0031", "b3572", "b2867", "b2868",
        "b1692", "b2599", "b2600", "b3280", "b3282", "b0754", "b2601", 
       "b3388", "b1260", "b1261", "b1262", "b0109", "b0637", "b0931", "b1740",
        "b0054", "b1627", "b1628", "b1629", "b4088", "b2050", "b2051", 
       "b2842", "b3091", "b4322", "b4267", "b3786", "b3224", "b3226", "b0025",
        "b0027", "b0120", "b0413", "b2103", "b2104", "b3990", "b3991", 
       "b3994", "b4407", "b2472", "b2838", "b3810", "b1103", "b1104", "b1576",
        "b4040", "b0200", "b0222", "b3627", "b3626", "b3624", "b3629", 
       "b3623", "b0440", "b3582", "b3575", "b3577", "b3578", "b3579", "b3580",
        "b3581", "b0645", "b0648", "b2260", "b2261", "b2262", "b2263", 
       "b0984", "b0986", "b2061", "b0987", "b3020", "b3478", "b3477", "b1991",
        "b1992", "b0028", "b2744", "b2794", "b2011", "b0242", "b0243", 
       "b1500", "b1182", "b4113", "b4112", "b1955", "b3453", "b3425", "b2804",
        "b1400", "b3343", "b3344", "b0861", "b0862", "b0864", "b0166", 
       "b4261", "b4262", "b0784", "b1757", "b1269", "b2593", "b1214", "b0972",
        "b0974", "b0975", "b0976", "b0977", "b0286", "b2866", "b2881", 
       "b1691", "b2021", "b4054", "b3283", "b1323", "b0750", "b2574", "b0636",
        "b1768", "b2615", "b1626", "b2054", "b2843", "b1521", "b3092", 
       "b4323", "b4324", "b4264", "b3784", "b3787", "b3788", "b3791", "b3794",
        "b4481", "b2839", "b3811", "b2311", "b3843", "b4039", "b4192", 
       "b4196", "b3574", "b3576", "b2060", "b2062", "b1293", "b3476", "b3479",
        "b3480", "b3481", "b1292", "b1485", "b0638", "b2743", "b2370", 
       "b0863", "b1086", "b0283", "b0284", "b0285", "b2878", "b2879", "b2880",
        "b1689", "b2019", "b2020", "b2022", "b2023", "b2024", "b2025", 
       "b2026", "b0751", "b4390", "b1767", "b1617", "b3093", "b3785", "b3789",
        "b3790", "b2038", "b2039", "b3792", "b3793", "b2894", "b3835", 
       "b4191", "b4193", "b4194", "b4195", "b4197", "b4198", "b1290", "b1291",
        "b1294", "b1486", "b1483", "b1484", "b1487", "b2369", "b1135", 
       "b1690", "b1616", "b3094", "b2041", "b2032", "b2033", "b2034", "b2035",
        "b2036", "b2037", "b2040", "b2232", "b3834", "b1488", "b3512", 
       "b0662", "b2907", "b3833", "b1492", "b1493", "b1499", "b3506", "b3509",
        "b3510", "b3511", "b3515", "b3516", "b3517", "b0485", "b1302", 
       "b2662", "b3507", "b3508", "b0486", "b1298", "b1300", "b1301", "b2661",
        "b2659", "b2660", "b1297", "b1299", "b1201", "b1199", "b1200", 
       "b1198"}, {Null, CompressedData["
1:eJxNnXd8VFUWxzPz3osUUcBCMyAoihJXsAKrroIUAYEgISEBAyQI2LuurgWx
rAKuva9lxYZKSJ1kkkwyk14AsW/RVdcCpIJrbzu/Pd/3yfxxPt97yr333PPe
zLy5eW8yeuUVCy8PJiUlrTk8KUmUBKCD+LqL7iK+3cPuYfcQ+ZMT4g4g7gDi
DiDuAMSP60NcH+L6ENeHuD6IH9+X+L7E9yW+L/F9ie+L+Hn1w98Pfz/8/Yjp
R1x/4voT15+4/sT1J9aPO5C4A4k7kLgDiTuQ2AOJH0D8AOIHED+A+AHED6DP
APodRPxBxB+E/WDGOxj/wfgPJsbXBzLeQMYciF8cRG0HUdtB1HZQwvEeTHsw
+iG0DyH2UPRDEd9+GPbDsB+G7zD8h+M/HP/h+A8n5nDihhA3hLghxA0hbgix
Q5CB9BtKv6H0G0q/ofQbSr+h9BuK+P2H0X8Y/YfRfxj9h9F/GP2H0X8Y/YdT
t+GMM5xxhjPOcMYZzjjDGWc44wxnrOHIQMYbAY9ABsND4SHwMHg4HAKHwmFQ
Y6ck2WtA7AdHIsmwH+wPD4Q6p0YRJzkSjsY/Bv8Y7GMYawxjjWGsMfT1448i
/ihsvn40Yx+NPhYeQ5x4EDwYjoWKOxaOwzYO/TjijsN+HPbj0Y8nVtTrbTx5
j6cG45l3PLUdT23HIzp+qfAEbCck6L9DxsOBHJ8TOcYncoxP5BifiBwGD4dD
4FA4DA5nvAmMN4HxJjDeBOImMOYExpzAmBMYcwJjTmDMCYw7kXEnMu5Exp3I
uBMZdyLjTmTciYw7kXEnMu5ExvbjT8IunpzU+7o4hbhT8J2C/dS4nJZkrxfJ
6XAS9snok7H5+hTa4u+T7LUgjqR9RpKdf+LRUHI8MWci4+Bx2M+Cf0iy8/vs
uJzDWJKpcBo8F5mMPp34Gegz6CPOTLJzX/RfB7PISTyPXCWz4Rzsc9Hnsg5x
LBwHj4fn45PMg/Npz0dfQPwCZBb2NOLSiE3DvhB9ITbxAmp3AetRexFyDNQc
6eiSxTADZsZlSZK93sUs5GTo27PRsxHfvhT7UuxLEd+/DP8y/MvwLyNmGflf
SP4XIovgOJiDjIM6X5Yn2XvFCrgyyc5t8RSYi5wEfXseeh5yEvT9q/Cvwr6K
mFWIH3cRcRcRdxFxFxF3EeLHryZ+NfGriV9N/GriVyN+vzX0W0O/NfRbQ781
9FtDvzX0XUP/tfRfS/+19F9L/7X0X0v/tfRfyxhrOY4XcxwvRvzz5BLsl2C/
BJ/PS2lfSvxlxF9G/GXEXUaMr18elyuS7H1KvBLx9avQr0JOZT1X478a/9X4
rybGt1+D/Rrs1+Dz7ddivxb7tfiuZfzrGOc64q8j/jriryP+Ovr4cdcTdz1x
1+MTb0iy917JjUn23ib+kbZ4EyL95gT+CfH1W9BvQWS/NYG3IZOR25lLXJdk
7+93JNl7+/oke+8T58I7Ef/9/S5kDvrdcbknyV7bYg7tPyM52O/Ffi82X7+P
uPuw34d9A/YN2Dfg24B/I/6N+Dfi30jMRuI2EbeJuE3EbSJuE7Hi/Un2+ST+
BTkLeQD9QfQHsYkPJdnnmeThuDySZJ9r4qPI2XAufAzbY4jq+HiSfZaJM6De
v5/A/iR8KoFPI1ORZ5Dp0P98/CvjPYvu8zlyFp9Pss/dF6Dkb/BF5Dn0zfCl
uLyc1Ps5/UpcXk2Y/zVE+hbyeR2+Ad9M4FbEj8snLh9/Pv58xI/bRtw24rYR
t424bYg/TwH+AvwF+AuIEXVdUIjcCXOwFyEb4CbsxehiSZJdZ+h6oRTx9RB6
CJuvl6GLeo2VwzDtMHoFegU2sTLJzq+qBEYQ6dUJrEH865lokl1HxJLsGqI2
yV63dYiuJ+phQ5Kdl43EiM/CTPxNiPTmBHsLch/MhDqvWtHbEuK3M852xLfv
wL4D+w5E/p0JcW9hfwvx7bvovwv/LkT+t5PsM0zMhhfDS+ClUJ9j7xD/DvHv
JvVeC73HfO8n2fWMuAJ+wDgfMM6HSfZ5KPl7kn1u/CMu/0yyz41/Jdlnh17H
H6F/hO0j7B+jf4ztY0THR58X/06yzwvxFij7J7Q/Qf+UuE+J+xT/p8SInyXZ
Z4T4H8TXP0f/HPHtX2D/AvsX+ES9xr5E9H74VZJ91oi7EV/fg74H8e17se/F
vhffXqSCuHbi2olrJ66duHYkDNWvg9w6yE/SCbtoi91J9rroSWAd7X1wP/ya
tqjPqf8m2WtD3AA3QoneZ75JsteaqM/Rbxn3W3TJd/B75v8BXfyROX5kbPEn
bD9h+wn7z9h/xi7+kmTvb7+Q4y/kJf6aZO9/v+Lz+RsxvzGONuUCAbMFA/Ye
HkR3oF43bsBkO23ZPZgcsJokB3o/vw8IGPsETP6CvS/2ftj6ofcP2LHpT3x/
/OKBtAdA6Qchvn5wwOp+MDafAwMm/nyDAva+NAjbIOyDA3YdcUichwbsWkI8
jLZ4eMA+oyVDAna9MDTOYQF7zUuGB0w2o4/Ad0TAXv9HEJ+CXfwIfgyPwK+4
kcSNJG4kPt8+Cvso+o+i/yjiRiHKV5/7RwZMnqD9NhyNbTRt2aWPibePCtg1
j3g0Il0MwbHYfB4Djw3Y9cqx6OPiPC5g10zi0/B4xLePRx+PyC6m0k6lbypx
J2A/Afvv4IlxTgjYNZA+FyYGTPQ+LDmJ9slxnhKwz79T4QtxOS3ePp01iPrs
moQ+GU6Bvw/0Xp+dQftMeFbAxK/HH2iLZ3O+nAOnwmkBu4YTz0V8fTr6dMS3
z8A+A/sMxPfPxD8T/0z8MxHFzUqIPw//efjPQ+TXOLPxz8Y/G/9sRHHyzwnY
uHPwz8E/B/HnnYt/Lv65+OciipP/fPzn4z8f//mIP+88xptH/Dzi5xE/j/h5
iN9vPvnOp/98+s+n/3z6z6f/fPrPR/z6LKA+C6jPAsZbwHgLGG8B4y1gvAWM
t4DxFjDmAo5fGscvjfHTGD+N8dMYP43x0xg/jXHTGDeNcdOYw9cXoi/EthD7
BdgvwH4BPlHnyyLyW0R+i8hvEfktYv5FjLeIfun0S6dfOv3S6ZfOetLpl04e
6eSRTh7p5JLOHOmMv5jxFzPuYsZdzLiLyWsxdVnMPIuZZzHzLGbcxYy9mPEz
GD+D/DOYJ4N5MjguGcyXwXHOYN4M5s1g3gzmzWDeDObNYN4M5s5g/kzmz2T+
TObPZP5M5s9k/kzmz2T+TObPZP5M5s9k3kzmzWTeTObOZP4lzLeE+ZYw3xLG
W8I4SxhnCf2XMMYS8s8i/yzGy2K8LPLOYrws8suiPlmMm0V+WYyfxfhZzJHF
PNnMk8082cyTTd7ZzCfOgXPhfKg8sskjmzyyySObPLLJI5s8sskjm1yyyWcp
+Swln6Xks5Q8ljL/UuZdyrxLmXcp8y5lvqXMt5R5ljKXP94y1rWMcZexrmWM
7/PCgH2GXUhdcuifQ/8c+ufQP4d+oq6DliPae1gRsGsQcSXi67nouYjsor5/
qZ0XsM9xcVXArlPFixDpktUBu35dg01cja64tdjXYl+Lz7dfjP1i7BfjEy8J
2N7GpfCyQO++xOXx9hUBu+YWr0R8/Sr0qxDZr07wX4P9GkT2axPirsMuXguv
w399AvV9QHE3YBPV/0b63Ui/G/HfSJ8/Bkz0PUH6Teg3YRNvDtheivgnRLrk
lnj71oDtndyWwNsR6esCvfsvd9BeH+edAbuOvAveDe8JWK3vQZf8mfa98D64
Ic6NAduvETch0vXd637aoq6Fxb8E7DulWA7DsAI+gMj/QIL/QewPIvou+yBx
DxL3YMI4DxEn6nvuQ8z9EH0eos9DxPj7SA8HjI/AR+N8LGB7SmIEPo7I/jj2
J7A9gf4k+pMJ/Z5CHoe+/WlsTyO+/RnGewb/M4j80bj8Nd5+NmDf5cQ+6P73
u+fQn0d/nnYf2B//C/hfwP4C0gcqTt+n/0ac+LeE/i9if5H+L9LvRcZ4EfHj
NxO/mfjNxG8mfjPxmxF/PS/RFvU9+eWASRNtF307+g6o7xGKfyVgsh391YDJ
DvTX8L3G+FsYewv2LcRuwf86472OX9yC/kbA9ivENxHtXbyZYN+KfSu2rbRb
aKcwTj5x+cTlE5ePjIB+/DbifBYEbH+uAF8BcYX4CxmvkLhCxitk7EL6FdK3
kP5F5FXEOEX0LyK+iPgi+hTRr5h+xfQrZv5i+hczfzHzFzNeMeMVM14xYxYj
/vpLGL+E8UsYv4TxSxi/hPFKGK+E8UoYrwTxxy1l3FLGLWXcUsYrJc9Sxitl
vFLGK2W8UsYsRYbA+5knxDwh5gkxT4j8Q8wXoj4h1hFi3hDzhpg3xLwh5g0x
X4j5ypinjHnKGL+M9ZQxbhnjljFuGeOWMW4Z45Yxdhnjl7OecuYpZ55y1lPO
fOWsp5z1lDNvOfOWM28585YzbznzljNvOXOXM3+YecOMH2b8MOOHGT/M+GHG
DzN+mPHDjB9m/DBzhJmngnkqWFcF81UwXwXzVTBfBfNVMF8F81UwXwXzVTBf
BfNVMGcF81ZS30rmr2T+SupaSR6V5FFJHpXkUUkeleRRSR6V5FFJHpXkUUke
leRRSS6VyBDon89V5FdFflUc/yryE7fBAlgIi2AxLIEpsBSGYBksh2FYASuh
8oqQV4S8IuQVoX4R8otQvwj5RcgvQn4R8ouQX4T8IuQXIb8I+UXIL0J+EfKL
kF+EHCPI13xeVJNvNflWk1819asmn2ryqSafavKpJp9q8qkmn2ryqSafavKp
Jp9q8qkmn2rqV0M+NeRTQ/1qqF8N+dVQvxrqV0P9asi3hnxryLeGfGvIt4Z8
a8i3hnxryLeGfGvIt4Z8a8i3hpxrEP+8jJJ/lPyj5B8l/yj5R8k/Sv5R8o+S
f5T8o+QfJf8o+UfJP0r+UfKPkn+U/KPkHyX/KPlHyT9K/lHEPy9irCPGOmKs
I8Y6YqwjxjpirCPGOmKsI8Y6YqwjxjpirCPGOmKsI8Y6YqwjxjpirCPGOmKs
I8Y6YqwjxjpiHI9a1lHLOmpZRy3rqGUdtayjlnXUso5a1lHLOmpZRy3rqGUd
tayjlnXUso5a1lHLOmpZRy3rqGUdtayjlnXUso5a1lKL+OdZHeuqY111rKuO
9YjbYAEshEWwGJbAFFgKQ7AMlsMwrICVsApGYDWsgVEYg7VQMoR11bOuetZV
z7rqWVc966lnPfWsp5711LOeetZTz3rqWU8966lnPfWsp5711LOeetZTz3rq
WU8966lnPfWsp5711LOeetbTwHoaWE8D62lgPQ0cpwbW1cC6GlhXA+tqYF0N
rKuBdTWwrgbW1cC6GlhXA+tqYF0NrKuBdTWwrgbW1cC6GlhXA+tqYF0NrK0B
GcK6GgP2empkXY2sq5F1NbKuRtbVyLoaWVcj62lkPY2sp5H1NLKeRtbTyHoa
WU8j62lkPY2sp5H1NLKeRtbTyHoa/WPD8WrieDWxribybaLuTeTZRH5N5NdE
Hk3M38T8TczbxHxN1K+JeZuYt5l5m5m3mXo2U09xBCyAhbAIFsMSmAJLYQiW
wXIYhhWwElbBCKyGNTAKY7AW1sF62OCvCzbBIVDrb2H9Laxf3Ir+Lno+egEs
hEWwGJbAFFgKQ7AMlsMwrICVsApGYDWsgVEYg7WwDtbDBn9dcD/raUIfApuh
6tFKHVqpQyt1aKUOrdShlTq0UodW6tBKHVqpQyt1aKUOrdShlTq0UodW6tBK
HVqpQyt1aKUOrdShlTq0UodW6tBKHVqpQyt1aKUOray/lXW3svZWxP+cawvY
edFGPdqoRxt1ELfBQlgEi2EJTIGlMATLYDmsgJWwCkZgNayBURiDtbAO1sMG
fx2wCQ6BzbAFtkLVYTt12E4dtlOH7dRhO3UQC2AhLILFsASmwFIYgmWwHIZh
JayCEVgNa2AUxmAtrIP1sMFfD2yCzbAFtsK2hDrsoA7iu7AAeyEsgsWwBJbC
ECyHYVgBK2EVjMBqWAOjMAZrYR2s9/OFzbAFtsI2uB3qfoadHGdRe3g+38Im
6vzYhejev12scRfHchc57yKnXeS0i2PwdsDuFRTfQXz9XfR3Ed/+Hvb3sL+H
+P738b+P/3387yOKk3wQb38Y6L3v8O/x9j8Cdo+P5J8Bu//nn0g/6N8H9C/8
/0Lk/yjQe5/ix/H2vwN2T4yo+2LET7B9gu0T/J9i/xT7p8SInwXsXBPfgfnY
C2AhLIalMATLYBWMwCiMwTrYABuZ8z/w84C1P0cmYv8C+xfYv8An3ge1hi8D
JrtgASyERbAYlsAQLIdhWAErYRWMwBoYhTFYC+thI2yGLbAV+q/3r9C/QnbB
AlgIi2EJDMFyGIYVsBJGYA2MwhishfWwETbDFuh/bu8m393YdyMFsBAWwWJY
AkOwHIZhBayEVTACa2AUxmAtrIP1sBE2wxbYCtvgdqjjoffjPQF7n9rDevew
3j2sdw/xe5B8OAIWwEJYBIthCSyFIVgOw7ACVsIqGIE1MApjsBbWwXrYCJth
C2yFbXA79M/Pvax/L/a9rG0va9rLmvYiKbAUhmAZLIdhWAErYRWMwBoYhTFY
C+tgPWyEzbAFtkKtS58z7Rxn8TOo9baz3naOdzvHu531t3PM2znm7RzzdurS
zjFvpz7t1Ked+dupUTtSCkOwDJbDMKyAlbAKRmA1rIFRGIO1sA7WwwbYCJth
C2yFbXA79OvYQR07qGMHdeygjh3UsYM6dlDHDurYQR07qGMHdeygjh3UsYM6
dlDHDurYQT4dSCkMwTJYDsOwAlbCKhiB1bAGRmEM1sI6WA8bYCNshi2wFbbB
7dCvZ2fA3oc6qWsnde2krp3UtZO6dlLXTuraSV07qWsnde2krp3UtZO6dlLX
TuraSV07qWsn+XVS204kBMtgOQzDClgJq2AEVsMaGIUxWAvrYD1sgI2wGbbA
VtgGt0O/vl3Us4t6dlHPLurZRT27qGcX9eyinl3Us4t6dlHPLurZRT27qGcX
9eyinl3Us4t6dpFfFzXtoqZd1LSLmnYhFbASVsEIrIY1MApjsBbWwXrYABth
M2yBrbANboc7qGc39eymnt3Us5t6dlNPcRssgIWwCBbDErgXtsMOWAo7YQiW
wXIYhl2wAlbCKhiBNTAKY7AW1sF62AC7qV839eumft3Ur5v6dVO/7kDv52wP
deuhbj3UrYe69VC3HurWQ916qFcP9eqhTj3UqYf69FCfHurSQ116qEsPdemh
Lj3Uo4d69FCPHurRQz16qEcP6+mhBj3ISNgMW6C/7n2sex/r3se697Hufax3
H+vdx3r3sd59rHcf693Hevex3n2sbx/r28f69rG+faxrH+vax7r2sZ59rGcf
ee9DmmEL9N9f9gfs/Xs/69vP+vazvv2sbz/r28/69rM+sQgWwxK4F6bAdtgB
S2EnDMEyWA7DsAtWwEpYBSOwGtbAKIzBWlgH62ED7IaNsAcOgc2wBbZCyf2w
DW6HqvfXAXue7r8Be35Ozy18g/j6t+jfIrJ/l8DvkfcZ54eA2X/A/gMi/4+B
3uf0foq3fw7YfaHiL4h0ya8Be1bvN6gfFFJblB5AD/DDUwHsQexB7EF8ohO0
Z/9El7ZPL87koD0DeEDQnq0T/wP7ILL3wS5+DvW8nXx9g/Y8W784+wft+bUD
EzgAkX4QlBxMe2DQ4gahi4ODdo+cqHvjxP5Q96vJdwgxh8LDgmYT9Szb4UET
//mqIdiHYPf1obTFYUHboxa/hsMR2Ycn2EdgH4HIPyLBfwT+I/AfQcwRtP24
FOJSiEshLoW4FGJTyG8k8SOJH0n8SOJHEj+SvqLeZ0YF7X1G3Ao/g7vgbpgP
t8FCWASLYQncC1NgO+yApbAThqCkjHY5DMMuWAErYRWMwGpYA6MwBmthHayH
DbAbNkLVTmxCHwKbYQtshfthG9T7je5NPDJoshV9NLoofQztMehHoR+FTTw6
aOfu2AQeQ9vnsUET/zwfR1s8LmjPcUqOD9r9xOPJKRVd3IleDEtgO+yApbAT
hqDWncqxTOVYpnIMUzl2qRy7VI5dKsculWOXyrFL5dilcuxSOXapHLtUjl0q
xyaVY5PKsUnl2KRybFLJTZ8Lenb1hKBJKvTtvwvafeMnBu2+cVH3408I2jOB
E9AnwpOCJqtpr4Froe6713OoJ8fbpwTtflrxVNqn0v4jbd2nLvtp8fbpQbun
XNSzqpMSOJm2qGdVp8DfB0360H4RboZ6/zwjaPcMi8/DF2Af+CLcDP1+Z9L3
TPqeSd8z8fWh/SLcDNX/rKA9P/sHqH3ss4Mm/WgPgudgO4d2Du/7U4P2WTCV
dn/a+jzQ62Ra0J6rncb5f26c04M213TGn4E+A12fVzOD9rzGTNp6nnZWsPd5
2vOCxtlBkynY59AWJafhn4t9Lva5iJ7DPZ9z+fxg730f84L2vjyP16WYD3fC
IlgMS6BkL+0U2A47YCnshCE4iv5l6OUwDLtgBayEVTACq2ENjMIYrIV1sB42
wGPhCeQzBL0ZtsBWuB+mEn8/ehvU++/8oD3fLC6gLaYF7dlkcSHi6xegX4DI
Ln0R+iLEj08nPh1/Ov50xO+/GP9i/IvxL0b8uAziMojLIC6DuAzEnz+T+TPp
l0m/TPpl0i+Tfpn0zaT9b+ZdQvwS4pcQv4T4JcQvQfx+WfizsGeRTzb2bPSl
jL8U+1LGE3X+Lwva+S9uhZ/B3XAPzIeSEbS3wQJYCItgMSyB8+jfjt4BS2En
DMFRxJehl8Mw7IIVsBJWwQishjUwCmOwFtbBetgAu2EjbILNsAW2wv2wDep1
oZpdGLT3igupdw71zqHOOdRZzGHtOdQ1h3rmUM8c6pnDmDnUNYe65lDXHOqa
Q11zqGsOdc2hrjnUNYe65lDPHOqZQz1zqGcO9cyhnjnUM4d65lDPHOqZQz1z
qGMO9cuhfjnUL4e65VA3nafLOU+XU7fl1E3cBffAfKj+y6nhcs7V5Zyry6np
cs7V5dR2ObVdTm2XI3uxpcB22AFLYScMwVH0L0Mvh2HYBStgJayCEVgNa2AU
xmAtrIP1sAE2wibYDFtgK9wPU8m7Dd0/Diuo/wrqv4L6r6D+K6j/Cuq/gvqv
oP4rqP8K6r+C+q+g/iuo/wrqv4I8ViB78aXAdtgBS2EnDMFR9C9DL4dh2AUr
YCWsghFYDWtgFMZgLayD9bABdsNG2ASbYQtshfthKvm3oW+H/j7WSl4fKzk+
Kzk+4ldwF9wD86GO00qO00qO00qOz0qOz0qOz0qOz0qOz0qOz0ryW4nsJSYF
tsMOWAo7YQiOon8ZejkMwy5YASthFYzAalgDozAGa2EdrIcNsBs2wn2wCTbD
FtgK98NU1tGG7r9+cqlzLnXNpa651DWXuuZS11zqmst4udQ0l5rmUtNcappL
TXOpaS41zaWmudQ0l5rmUtNcYipoV8IqGIHVsAZGYQzWwjpYDxtgE2yGLbAV
7odtcDv0z/M8zvM8zvM8zvM8zu88zus8zus86p3HeZ3HeZ1H/fOofx71z6P+
edQ/j/rnUf886p9H/fOofx71z6P+edQ/j/rnUf886p9H/fOofx71z+MY5HEM
8jgGeRyDPI5BHscgj2OQxzHI4xjkcQzyOAZ5HIM85uim3QibYDNsga1wP0yl
fxu6f16v4ris4ris4riIu+EemA91fFZxfMQC7IWwCBbDEjiP+OVwBVwJU4hr
hx2wFHbCEBxFvzL0ctgFc/FXoFfCKhiB1bAGRmEM1sI6WA8bYB7zdKM3wmbY
AlthG1zFcVjF60Tn+UVB27cXJSNpr6Ytrgn2/q7TWtoXB619Mfol6JdgE3Wf
2qVBuzftUvTLgna/2mXYL8N+OfbLsYvyiVcEbW9HnIB+JbYrsV2JaN/nqqB9
X9X6rg6azIPHYjsBPRXq+6l816BfS6x4XdB+V+p6qO9RNyB69vkG7OKNiPQ/
Bu23psTjA9a+KWhyQrx9M+2bE/Q/ITdB334L+i3ITdD334r/Vuy3IjdBxd2G
fhu64m9Hvx3x49ahr0Nugn6/O5jnDsa/A/HzWU8+64lbT9x65lvP+OsZdz39
1yM3QY0n3oncBH37Xeh34bsLn8+7Gece/PdgF+9OsP8Zu3hv0H7fSzwxzvvQ
9fsgG4LGjXCTzp2g3Qsral/rL0H7jS/xAUS65MF4+6Gg/cbXwwl8BPH1R9Ef
RXz7Y9gfw/4YPvHxoO1p6Tx9AtFvhkmepP0UfDrOZ4L22yt/Ddp7s6j3WHEb
egEsgsXwLLiC+JWwFPso9DL0XPQq9GpYBxtgHnGN6D2wDer961nmF/W6fg5d
vIjj8Tyi3z+TvBBv/y1ofzsUv4HfwhfxvUj7G9q+fzP+zfg3E7OZmM2M/xJx
LxH3EnEvEfcSff24l+N8JWi/cSSeC6fDGXAmXATT4WKYATPhEvgqY79K+1za
0+EMOBMugukwA2bCLJgNlzLPa8zzGvO8hpyLbTqcAWfCNLgIpsMMmAmzYDb0
593CvFuYdwvzbkHOxTcdzoAz4Vy4AKbBRTAdZsBMmAWzoZ/P6+TzOvm8Tj6v
k8/ryLnETIcz4Ey4CKbDDJgJs2A29Od/g/nfYP43mP8N5n+D+d8ghzdoT6c9
A86EaTAdZsBMmAWz4VLOizeZ903mfZN532TeN5n3TeZ+k/YM2jNhGkyHGTAT
ZsFs6M+/lfm3Mv9W5t/K/FuZfyvzb2X+rcgMbDPhApgG02EGzILZ0M8jnzzy
ySOfPPLJI5888skjnzzyySMfmYFvJsyEWTAbLuV83Mb42xh/G+NvY/xtjL8N
ycKXDZfyOisg7wLyLmDcAsYtYNwCxi1g3AJyLmD8AiQNWzrMgtnQr1shdStk
/kLmL2T+QuYvZP5C5i9k/kLqVkgeheRRSB6FHNNCcinkWBZSW3EJLCTPQvIs
TMiziDyLyLOIPIvIs4g8i8iziDyLyLOIPIvIs4g8i8iziLyKyKuIvIrIq4jc
imhn0/aPXzF5FZNXMXkVk1cxeRWTVzF5FZNXMfkUk08x9Somn2LyKCaPYvIo
RrKx+fUqoV4l5FVCXiXkVUI+JeRTQj4l5FNCnUrIq4S8xPOwp8MMmAmXwELi
s9CL0IthCXmXJORdSt6l5F1K3qXkXUo9S8m/lPxLyb+U/EvJX5wJC7Cno2fA
TLgEFhKXhV6EXgxLYCn5lybkHyL/EPmHyD9E/iHyD5F/iPxD5B+ivuIimA4z
YCZcAgvpl4VehF4MS2ApDJF3KNj7PlZGnmXkWUZ+ZeRXxnlQRh3LmLeMecuY
t4x5y5i3jHnLmLeMucuYW1TdyqlbOXUrJ59y6lVOPuXkU85xLiefcupUTn3K
sRXCLGxF6MWwBJbCbOKWwjLyCZNPmDzC5BGmLmHyCDNnmDnDzBlmzjBzhpkz
TF3CzB1m7jBzi/qdxgrWVxlnFWNX0UesJL8I+UTIJ8K6IuQVoW+EvCLkFSGv
CHlFyCvCHBHyimArg2HqU8281cxbzXzVzFfNfNXMU8341YxfzfjVjFvNHNXM
IdYE7fcrxSgiXYzRjmGvRa/FJ+r3K+tgfdB+r7IhaLKStu59aAz2/mZkU9B+
L7I5aL/v2BK033cUr4ayt6KL18Dr4PVQcW1B+/3INuLbiG8jXtSYYiuU6Pcd
1X878dvxb8e/HVHcDubYQa47iBV34tuJTXwr2Pt7lruCJtfQbqHf28S8Tfsa
2m3omvsd1vROsLce78b5XsJ479P2+QGxHyA7ocbT71x+SF1EyYZ4++/B3t/N
/Ee8/U/W/a+g3TckfoRI/zhov2sp/pu2KP0T9E/wiZ8G7TcwJZ/R/k/Q2qJ+
D/PzoIl+E1O/h/lF0H4L88ug/RbmV3B30Nqi7l/aE7R7mfbQ1u9g6ncy9wZN
dG+O9Hb0dvQO9A5sHdg7sXdi78TXib8Lfxf+LvxdxHQR101cN3HdxHUT101s
N/E9xPUQ10NcD3E9xIr7gvbbn1rvftYs6rc/v47zv0F7JlX8BvH1b9G/RWQX
v8D/HSL7dwn27+n3Pf7vifH5A+fSj3H+FLTf9hT1W6Bq/0xblOg3P38J2u94
ir8i0vWbnr8FjfpnpgHHft8zmEAH8X/303Xs9ztF6V6cyY79FucBjv02p/Q+
jul9EN/eF3tf7H3x9WXcfnH2d+y3QMVn4IGI7Acm2AdgH4DIr9/4PCjePtix
e9xEvY+KAxHZBzm9v/852LH70w5xENq6V02ciq771BR3qGMi/6FO731th2E7
3DHR/rR8QxwT9dfvbw517Hcyh8Hhjon2iKWPiLePcOy3OFMc+/3NkY7tJ///
PmCH+4Adky9p74FFsBj+/2+iDvfsOtyn63B/rsN9uQ735Trcj+twP67DfbgO
9+E63H/rcD+tw/20Tu8+3JGO5XkkOYnLsG9D3wklBbQLYREshiVwOWOsgCth
O/4OWAo7YQiOIr4MvRyGYRfMJa4CvRJWwQishjUwCmOwFtbBetgA85inG70R
NsFm2AJbYRtcRf/t6P7fN0dT39HUdzTSga0UdsIQVH1Gs87RrG806xvNukaT
j6i/j+g8HMOxGcMxGUOfMfQZQw3EMdRhDHUYQx3GsD6dH0c5Jvpbi6jfQdA5
cXS8PZa5xnIejGXOsaxrLOsYy3Eey/Eby7rGMu9Y5tXvPBzj2O87iPq9h2PR
RYns+q2HcfA4eLxjv/kwXrVw7LcfTnDsNxzE3yHS9XeyEx2zn4j9RER+8f9/
N2C9E+FJUHU4GZGuZ01OcezvSadgPwWRX3+XOtWxe8xPxX8q/lMRxUlOo326
Y+3Tqf8k7KLuGZzs2N/RxDHwKKi/z01x7O9zPn/v2N/pRIneD89wrBaifutB
f9c907H3B/H/fz9wTLS//wfHnvkRz6YtSj8H/Rx852Cfin0q9qn4puKfhl88
17FngMTptEXt189wbJ9e1D69KPmW9mZ82q9X/Ex84izHnikSz0N8fTb6bMS3
z8E+B/scRP658HzHnlHSs0jz4u35jj2LtACmOXZupHFupHHMZVvomOj5AekX
OPac0SLHnjVahJ7uWFtcjC/DsWeQJJmOiZ4/0rNIS9CXIB4xWcgSKHu2Y88b
iUsRX1+Gvgzx7RdivxD7hfjEHMfuAReXI9IlKxx7LkkcAAfBlfjEXMTX89Dz
sOXRHkBbY8i+CvsqfKtoD6Ltz3+RYzKItm9fTf/V9F9N/9XEr6bPavr48WuI
X4N/DbYVUHFrHXtWS3KxY89oXeLYtc2ljon/vNVljj1/crljr2tRMhkq7gqo
uCuxi0ehT0a/MiH+KvSrENn13NbV8fY1jj2zJQ6F1yKyX4tdzz9d59gzUKL0
6x27z/8Gx+RIru9udOz67kZEz+JI/oh+EzZR8TcTfzP+m/GLf2Jtst+C+M/z
3OoYb3OsLd7u2HuteCr6JLgOkX9dgv8O7HfguwPfHfjX41+Pfz0+8U7Hng/S
/QZ30RbvduyZIfEeRPqfHXt+SK/9ex3jfY6170PfEOdGp/e+h02Ofc5vQmTX
Mzb3x9t/cez5GvEBRLo+Hx507F4LUc/OPBTnw449OyN5xLHnZR7B9ii6qOct
HnPsWQzxcce+g4pP0H6Ctp6lkf6kY/fNP+XY/e+iRM/XPO3YsyvPJPCvyFn4
n0Wk673/OfTnsIl6f3nesfcXUc+5iPp78guOif6+/zfHvg+/6Nh7uTgbzoEz
8G9GZsHZcA5U3EtQ5/vLjvEVx55veTXO1xx7FkWyJd5+3bG/e+u5iTfi7Tcd
e9ZAXAgXwXSYAbciit9K/FbitybE5xOTT0w+tgtoL4LpcDHMgJnwKfpvo/82
xthGexHtdKhxFF9Av0LiC/EVYi+CxY69PkT5irGXEF/CvKWMU8q8pcxdytyl
xJfi85/zCNGvDJsoWxn9y2GYfmHWHGbcCsatIL8KpJgaVZJ/JXoVus+IY9eL
EfRqWOOY6PkA+aOOPdsRJTaKnIw9hi7WOvZcRx1j1DFOvcP9ZnE20BYbHbuW
E3VdJ+q7qu7zanLsXq/mOFscuxaUtDomuh5sg9vhDqj3kZ3x9luO3bO1y7H3
pLed3vu23qH9LnzPseve9x0TXf/ofpcPHLvfRZQ8gP1Dx97vPsT/IX0+JE7U
d/K/OyY30tb11D8ce2/9B3ZR793/RNf8/0Kkf+T03v/1sWP3P/3bsfudRMnt
tHXPk/yfOCZ3074H+6fYP0Xuxia/7qf6jHHFzxj7M8b/jPHF9fAT/J9Cjfcf
xpB87pisw/4Fvi+w+/qXtL8kVlT8V/i/wv8VMV/h341/N+PtJm43cbuJ3U38
HuL3ELeHuD3E7SHWj9sL24lrpyYd1KSD9ifwU3g3PtW1k3qJd0LdR9aVoHcj
0rvx90CNtY+xfO53rC3qfrKv4/yvY/eUid/Q/gb7t+jf4hN1j9l38HvH2uIP
jp3nOi9/RP4MP4Dyiz8h0nUP2s+O8RfH2qLuL/vVsfvLxEfhYwn6b+iibKLu
JUty7X6yAAy61hb1fc9x7X4sN07Ptfux9L0r2bXvUqK+Yx0QZx/X7ovqC/tB
Sf94+0DX/qYj6m86+hvUgHj7INf+BiPG4P/3BfGJUfQY9P0D8Q2kLfsgOBge
ksBDEV8/DP0wRHb9Tedw1zgEDnWtLQ5z7e894nDaov6mMyLOI1z7G4QkxTXZ
SXskbZ+jsIn6e8aRcY527W8eY6D+fnBUvH20a38XEMci0iXHxNvHuvb3gnGu
/Y3gOHi8a3vl2sce79o+tvgtlD3VtX3tVPwn4BclivsdMdqnPtG1PeoJcU50
bZ9achLtk11ri9pfPsU16UNb+8qnYjsVu3gacgr07aejn47vdET+0xPGm0Tc
JOImETcJUfykhPjJxE8mfjLxk4mfTJ/JtP1+U+g3hX5T6DeFflOIn0If8feu
7aOfkcAzafs8K84/uL375Ge79j1IlH6Oa997RMnNxE11LWYqcdPQp2Gbhv1c
xjuX/uci/jjT8U+nn6j9+BmuXRfMdE0Oo629dNlnYZ+Fzed52M5Dn40+G5uo
/fc5cK5r3wHF813bjxfnIb4+H30+tvnEL8C+APsCYhbgT8Ofhj8NfxoxacQt
JG4hcQuJW0jcQmJF/a3gAtdet4uQEXwupLsmI2nrs0HtxdgyXNsHznRNRtNe
gvj7w1mufc8Ttf+X7dp3WFGi672lru3Distoixe6tlcqar80B11cTlvUHuoK
10T7p9JXoq9EZM/FlostF3uea3ujYglchcguXkRbXO3ade6aBK5FdL27Fruo
67eLXfvufXGCfgki/VLX9kgvg5dTI+15XuGaKFb7nVe6Jm20dY2ra+WrXOPV
8Bp4rWs28Roo+3WufQe93jXRPqk+M29AtFeqfc4bXdvnFPU99o+u7dvd5JrM
pH0z4ut/Qv8TIrvkFtc+e0V9X73Vte+lomQW7fPgbDgH3oYo7jbibiPuNrf3
+/DtjHs7495Ov9vpezvt82jPhn7/dfRfR/919FtHv3X0XUffdfRdx7ruoN8d
zHsHcjs8j5jZcA5U//Wu7c3e6dre7F2u7blqn/XuePse1/ZZtZ/6Z9fE31+9
F/1exLffh/0+7Pch6YyxAfsG7Bvw+faN2Ddi30jMRsbdRNwm4jYRt4m4TcSK
93MO/SWBD9AWpT+I/iC+B7E/hP0h7A/h8+0PY38Y/RH0R7A9gv1R7I/S/1H8
jxLzKPM9RvxjxD+GrGcdj+N/HP0J9Cfwidq3ftK1/Z6nXBPt80h/GvszrrWf
QeT/q2v7r6K/T/usa/qzyBpsK6DinoPPu7ZP+4Jr+7F/c20PVfJivL3Ztb1U
UXupL7m9+58v037Ftf1IUXIbca/iF19GfwXK/xr+1/C/hv81Ynz/FvQt2MTX
XdsrFbVH+gY5iG8iymOr27sPmh9vb3N79zILXHufLkS0tykWIdLFYtpiiWt7
nGIp4ush9BDi74WWubbfWe7anmfYtbaoPc0K1/YzK13bz6xEr3KtLWovMwKr
XWuL2t+scW1PMwpjcda6tq9Z59o+pViPSBcbaIvaH2qMs8m1vUlJs2s1E1tc
22MU9d6v969W197/xDbX9gTF7bS3Y9+BvgPfDuw7se/EvhOfqD3Ft1yTa9B3
wbdda4vaR3vHtb25d+F7ru1rve/avpYo0f6W9ug+iLc/xPYh9r+j/x39H/T9
p2t7V+K/EF//CP0jRPaPXdsPE/+NSJd84to+1aeu7VF9Fud/XPt8Fj9HfP0L
9C8Q2cUvaX+J/Sv0r2jvIG439t3YdyPy78G2J0Hfi+yGsmsvrD3e7nBtT0zs
RKRLuuLtbtf2ynrgPtf2zPbDr13bf/ov1H7LN67to4i7E/RvXdsv+c61fZXv
8It7oPzfY//BtbaoPZcf4U+utX9C/5m2+Itreyjir4iv/4b+G+Lbkzyzi79B
+Xx7AHsAuyifqH2ZoGf7Mo5ney4u9Dxri8meXVuL38Bvoa6nxQOIEXXdLX4G
JR/S/oYY9e+Drv2Zvp7tg/TzbC+kH3p/dFE28UDPrvkGeLZPIh5EW9TeyMFw
oGftgeiD0AdhG4R9MPbB2AfjG4w8RoyuERV/CPGHEH8I8YcQfwjjHkrcocQd
iv9QYsTDPNvDOdyzPRTJkHh7qGf7IpJhtIfDEZ7tjxzh2R7JEegp6KJsvj4S
fSS2/+tx+yjPRPsgR8LRnu1piGMQXz8K/SjEtx+N/WjsR+MTtS8y1rO9jmPg
sZ61j0Ufhz4Om6j9j+PiPN6zfQ9xPCJdkurZd/0TPPu+/zvP5Aza+n4v+4nY
TyRuAvoEbBOwT6SvOJH+0k/ybM9A1H7ByZ593z/FM9H3dumneia+fppnMpX2
NOj7T/dMfH0S8ZOQqdimQT9uMvNPIX4K8VOQqfimQfX7fUIeZyBToOxnJOR3
JuOdie9MfKL2Js7ybF/hD57tK4iz4dnYzsYmyq7v8+d49n1eTIML4VTa0zy7
Jp2GLjmX9nTPRJ+z2gOY4dl3+5nKx7Pv8uJ5iK/PRqTPgXM9+05+vmfflXXd
Nc8z0TWXvu/O9+w7rLjAs++rkjTPvpMu9Oz64wLPrkFEfddcBNM9a4t671js
mdxMW98x9X0rw7PvW6LkDtr+98BM/Jn4xSWefe/K8uz7STZ1W5rAJ+Ay5H7i
LvTMfiH2CxHfn4M/B38O/hxkGlS8vl8s9+z7iPgwfAQ+CvX9YYVn3xPElZ59
d8j17DtAnmfX9+IqRLquyy/yTF6m/RrUdbeur1d7dn0tvgJlX4N9DXZRPnGt
Z9fw4sW0xUsYXzGXItIvg5cz9uWMLV6ByH5Fgv1K7Fci8l+J/yrPvgtcDaVf
Q9vntXFe59k17/WeXdOLpTAEb0DkvwH/DQn+G/HfiCjuRuJuJE7X9X/07Npe
vMmza/qbE6jr+z95dn0v3oL4+q3ot2ITdd1/m2fX97frnPXs+l5yR7y93rNr
fMmd8fZdnr2m7vbsmvwez17v4p8R6eK9yHTo2+9Dvw+ZDv1xNuDfgH0DMRuI
8f0b8W/EvxH/RmLFTZ69d4q67r8/gSto/yXOBzz7PiA+iEjXNfhDnl2DPxzn
I55da4uPItJ1PfyYZ7KX9ldwN/7HPZPH4F5s8j/hWcwT+J7ALz6J70l8TzLG
k8SIT9HnKWKewvcUcU97vdflz3gmug7/K+2/oj+bwOcQX38e/XnkGeiP8wLy
DJRd/BvyDJT9Rc++A2z27DvAS55dk4svI9LFH7C/gv0VRP5X8Mv+KvZXEfl1
/f6aZ+Jfz29B34JNlP119DfwibpOf9Oz6/Q30bei53sm0rd5dp0uFiDSCz27
Bi/y7Jpa18PFnl0LiyWeXWOWenaNKYYQ6brOLItLuWfXmbrGDCO6zqygXYGu
68VKz67Xqjy7XhPHQV2zRTy7Tqv27NqsJi5Rz66bxBgiXdcltbCOdh16PXo9
NlGfGw3IJqjXn64xGmETbVGfY82efY6JF0JJDpyGtMSl1bNrhDaoz+7tcdnh
2WetuJP2TvS30N/C9hb2Xdh3Yd+Fbxf+t/G/jf9t/G8TI77j2Wei+C6SB1dh
fw+b+L5nn40fePZZJ65BPvTs8+7vnn3Wifq8+4dnnz//hP+iLX7k2WeUPpM+
9uwz6d9x+cSzzxZ9Tnzq2fv/Z3H5j2efAeLntD9HboVf0Pb5ZVy+8uxzYrdn
nxOSPXAv7b3o7ejt2Nrp14G/A38HPt/eib0Teyc+Ue/XXZ69V3fHpcez92Nx
HyJ9P9R7zdfwv7TFbzx7r5J8G5fvPHvdi9/TFn/w7HX9o2ev8R8T9J+w/YTt
J+w/Y/8Z+8/4fsb/C/5f8P+CX/yVOX8l5jeYlGzvKaLeUwLJ9l6i94Rgsr3+
nGR7/YkSvQ7dZHuteMl2DorJiK8fgH4AInufZDtPxb6Ir/dDpPdPtnP5wGQ7
h8UBiK8fhH4QNlH2g7EfjP1gYg7GPxD/QPwD8Q8kZiBxg4gbRNwg4gYRN4jY
QcQPJn4w8YOJH0z8YOIH00fU6+yQZJNDk+01Jx6WbK+3w5N7Xz9Dku08H5ps
5/GwZDv/RUk77Q7on+/DiRtO3HCkHVsHVPwIYsUjkL3MmUL/FPqnIOqfQn/F
jcQ/Ev9IRHEjiRuVbK+zI5PttTU62V5DkjHJJv7r6ij0oxDffjT2o7Efjfj+
sfjH4h+Lfywxvv8Y/MfgPwb/McSKxybba0f8AY5DZB+XYD8O+3H4jsPn68fj
E39DH097fHKvnorInppgPwH7CfhOwCf+Ltlet3p9nphsr6MJcZmYbOeSzqGT
ku34nszxPRnRsT0F3yn4xFOREdC3n4Z+GjIC+v7T8Z+O/XTEH38S/kn4J+Gf
hIyA/niTiZ9M/GTiJxM3GRkBj4Anwyn4puCbgsj/+2Q7F8+AquWZ1POsuPyB
GMnZcTmH2Kn4xWmI9HPh9AT/DPwzsM9AfP9M/DPxz8Q/E/HjZhE3i7hZxM0i
bhZyFnIenE17NuPMYZw5jDOHceYwzhzGmUP/OfQV5zLGXMaYi/189PMTxp+H
+PPMRxYgs+ifFpeF9BUvQHx9Efoi5HwkHdEci2kvTtAzkHQoeyZjZjKWuASb
mMVc2bTFpYj0ZdiWYfsfgfTdpA==
       "]}]]}, 
    TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJwUmnc81f8XxyWrklQapJDs7Ovu8br3miVFoUQDoRIRpZCQkbaKVCKprCQS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       "], {
        {Hue[0.6, 0.7, 0.5], Opacity[0.5], 
         {Arrowheads[0.], ArrowBox[{1, 2}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1, 3}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1, 4}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1, 5}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1, 6}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1, 7}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1, 8}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1, 9}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1, 10}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1, 11}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1, 12}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1, 13}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1, 14}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1, 15}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1, 16}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{2, 3}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{2, 4}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{2, 5}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{2, 7}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{2, 8}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{2, 9}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{2, 17}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{3, 4}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{3, 5}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{3, 7}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{3, 8}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{3, 9}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{3, 17}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{3, 18}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{3, 19}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{4, 5}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{4, 7}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{4, 8}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{4, 9}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{4, 17}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{4, 20}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{4, 21}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{4, 22}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{4, 23}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{4, 24}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{4, 25}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{4, 26}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{5, 7}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{5, 8}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{5, 9}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{5, 17}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{5, 18}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{5, 26}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{5, 27}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{5, 28}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{6, 10}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{6, 11}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{6, 29}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{6, 30}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{6, 31}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{6, 32}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{6, 33}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{6, 34}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{6, 35}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{6, 36}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{6, 37}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{6, 38}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{6, 39}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{6, 40}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{6, 41}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{6, 42}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{7, 8}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{7, 9}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{7, 10}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{7, 11}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{7, 12}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{7, 13}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{7, 14}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{7, 15}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{8, 9}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{8, 10}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{8, 11}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{8, 12}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{8, 13}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{8, 15}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{9, 10}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{9, 11}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{9, 12}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{9, 13}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{9, 14}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{9, 15}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{9, 43}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{10, 11}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{10, 12}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{10, 13}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{10, 29}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{10, 30}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{10, 34}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{11, 12}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{11, 13}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{11, 30}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{11, 34}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{12, 13}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{12, 16}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{12, 30}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{12, 34}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{12, 43}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{13, 16}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{13, 30}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{13, 43}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{14, 15}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{14, 16}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{14, 38}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{14, 43}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{15, 38}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{16, 23}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{16, 24}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{16, 26}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{16, 43}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{16, 44}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{16, 45}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{16, 46}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{18, 19}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{18, 20}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{18, 21}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{18, 22}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{18, 23}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{18, 24}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{18, 25}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{18, 26}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{18, 28}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{18, 47}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{18, 48}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{18, 49}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{19, 20}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{19, 21}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{19, 22}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{19, 23}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{19, 24}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{19, 25}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{19, 26}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{19, 28}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{19, 47}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{19, 48}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{19, 49}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{20, 21}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{20, 22}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{20, 23}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{20, 24}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{20, 25}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{20, 26}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{20, 28}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{20, 47}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{20, 48}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{20, 49}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{21, 22}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{21, 23}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{21, 24}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{21, 25}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{21, 26}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{21, 28}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{21, 47}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{21, 48}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{21, 49}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{22, 23}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{22, 24}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{22, 25}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{22, 26}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{22, 28}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{22, 47}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{22, 48}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{22, 49}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{22, 50}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{23, 24}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{23, 25}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{23, 26}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{23, 28}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{23, 47}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{23, 48}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{23, 49}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{24, 25}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{24, 26}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{24, 28}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{24, 47}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{24, 48}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{24, 49}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{25, 26}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{25, 28}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{25, 43}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{25, 47}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{25, 48}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{25, 49}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{26, 28}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{26, 43}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{26, 47}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{26, 48}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{26, 49}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{26, 50}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{26, 51}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{26, 52}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{26, 53}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{27, 54}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{27, 55}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{27, 56}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{27, 57}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{27, 58}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{28, 47}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{28, 48}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{28, 49}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{29, 30}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{29, 59}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{29, 60}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{30, 34}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{30, 59}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{30, 61}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{30, 62}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{30, 63}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{31, 34}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{31, 35}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{31, 64}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{32, 34}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{33, 36}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{33, 60}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{33, 65}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{33, 66}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{33, 67}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{33, 68}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{33, 69}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{33, 70}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{34, 35}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{34, 38}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{34, 71}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{34, 72}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{36, 60}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{36, 73}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{36, 74}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{36, 75}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{36, 76}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{37, 38}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{37, 41}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{37, 76}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{37, 77}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{37, 78}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{37, 79}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{37, 80}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{37, 81}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{37, 82}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{38, 40}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{38, 41}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{38, 42}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{38, 71}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{38, 83}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{38, 84}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{38, 85}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{38, 86}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{38, 87}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{38, 88}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{39, 89}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{39, 90}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{39, 91}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{39, 92}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{39, 93}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{40, 42}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{40, 61}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{40, 76}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{40, 94}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{40, 95}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{41, 61}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{41, 95}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{42, 60}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{42, 72}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{42, 76}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{42, 80}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{42, 84}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{43, 45}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{43, 46}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{44, 96}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{44, 97}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{45, 46}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{47, 48}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{47, 49}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{48, 49}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{48, 52}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{50, 52}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{50, 98}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{50, 99}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{50, 100}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{50, 101}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{50, 102}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{50, 103}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{50, 104}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{50, 105}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{51, 90}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{51, 106}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{51, 107}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{51, 108}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{51, 109}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{51, 110}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{52, 98}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{52, 99}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{52, 100}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{52, 101}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{52, 102}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{52, 103}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{52, 104}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{52, 105}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{53, 111}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{53, 112}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{53, 113}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{53, 114}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{53, 115}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{53, 116}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{53, 117}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{53, 118}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{54, 57}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{54, 119}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{54, 120}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{56, 57}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{57, 58}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{57, 68}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{57, 120}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{57, 121}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{57, 122}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{57, 123}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{57, 124}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{57, 125}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{57, 126}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{57, 127}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{57, 128}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{58, 129}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{59, 130}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{60, 76}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{60, 131}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{60, 132}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{60, 133}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{60, 134}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{61, 83}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{61, 84}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{61, 94}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{61, 135}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{61, 136}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{61, 137}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{61, 138}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{61, 139}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{61, 140}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{61, 141}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{62, 142}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{62, 143}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{62, 144}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{62, 145}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{63, 146}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{63, 147}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{64, 148}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{64, 149}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{64, 150}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{65, 70}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{66, 70}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{66, 151}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{66, 152}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{66, 153}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{66, 154}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{66, 155}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{66, 156}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{66, 157}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{66, 158}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{66, 159}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{67, 160}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{67, 161}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{67, 162}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{67, 163}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{67, 164}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{67, 165}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{68, 166}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{68, 167}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{69, 156}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{69, 168}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{69, 169}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{70, 151}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{70, 156}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{70, 170}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{70, 171}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{70, 172}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{70, 173}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{70, 174}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{70, 175}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{70, 176}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{70, 177}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{72, 80}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{73, 76}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{73, 178}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{73, 179}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{73, 180}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{74, 181}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{74, 182}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{74, 183}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{74, 184}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{75, 133}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{75, 185}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{75, 186}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{75, 187}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{76, 131}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{76, 149}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{76, 188}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{76, 189}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{76, 190}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{76, 191}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{76, 192}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{77, 182}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{77, 183}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{77, 193}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{78, 79}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{78, 81}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{79, 81}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{79, 82}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{81, 82}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{83, 94}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{84, 94}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{85, 194}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{86, 195}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{87, 196}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{87, 197}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{88, 151}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{88, 198}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{88, 199}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{88, 200}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{88, 201}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{88, 202}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{88, 203}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{88, 204}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{88, 205}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{88, 206}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{88, 207}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{88, 208}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{88, 209}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{89, 90}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{89, 91}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{89, 92}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{89, 93}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{90, 91}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{90, 92}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{90, 93}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{90, 106}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{90, 107}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{90, 109}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{90, 210}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{90, 211}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{91, 92}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{91, 93}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{91, 106}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{91, 107}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{91, 109}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{91, 210}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{91, 211}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{91, 212}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{92, 93}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{93, 213}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{94, 95}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{95, 135}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{95, 136}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{95, 137}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{95, 138}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{95, 139}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{95, 140}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{95, 141}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{95, 178}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{96, 214}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{97, 214}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{98, 99}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{98, 100}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{98, 101}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{98, 102}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{98, 103}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{98, 104}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{98, 105}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{99, 100}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{99, 101}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{99, 102}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{99, 103}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{99, 104}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{99, 105}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{100, 101}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{100, 102}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{100, 103}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{100, 104}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{100, 105}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{101, 102}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{101, 103}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{101, 104}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{101, 105}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{101, 114}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{102, 103}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{102, 104}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{102, 105}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{103, 104}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{103, 105}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{104, 105}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{106, 107}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{106, 109}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{106, 210}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{107, 108}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{107, 210}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{108, 109}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{108, 210}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{108, 215}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{109, 210}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{109, 215}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{110, 216}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{110, 217}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{111, 112}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{111, 113}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{111, 114}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{111, 117}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{112, 113}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{112, 114}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{112, 115}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{112, 117}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{113, 114}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{113, 115}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{113, 116}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{113, 117}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{113, 118}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{114, 115}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{114, 116}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{114, 117}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{114, 118}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{114, 218}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{115, 116}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{115, 117}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{116, 117}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{117, 118}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{118, 219}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{119, 220}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{119, 221}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{119, 222}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{120, 128}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{121, 122}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{123, 124}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{123, 125}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{123, 223}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{123, 224}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{123, 225}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{124, 125}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{124, 223}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{124, 225}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{125, 223}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{125, 225}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{126, 127}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{131, 132}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{131, 226}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{131, 227}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{131, 228}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{131, 229}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{132, 178}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{132, 230}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{133, 231}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{133, 232}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{133, 233}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{133, 234}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{133, 235}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{134, 150}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{134, 230}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{134, 236}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{134, 237}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{134, 238}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{135, 137}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{135, 196}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{135, 199}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{135, 239}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{135, 240}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{135, 241}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{135, 242}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{135, 243}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{136, 138}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{136, 139}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{136, 140}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{136, 141}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{136, 244}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{137, 245}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{137, 246}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{137, 247}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{137, 248}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{137, 249}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{138, 139}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{138, 140}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{138, 141}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{138, 202}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{138, 244}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{138, 250}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{138, 251}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{138, 252}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{139, 140}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{139, 141}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{139, 179}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{139, 244}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{139, 253}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{139, 254}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{139, 255}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{140, 141}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{140, 244}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{140, 250}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{140, 251}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{140, 252}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{140, 256}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{141, 179}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{141, 244}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{141, 253}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{141, 255}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{141, 257}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{141, 258}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{141, 259}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{141, 260}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{141, 261}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{141, 262}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{142, 143}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{142, 263}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{142, 264}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{142, 265}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{142, 266}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{142, 267}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{143, 145}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{143, 264}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{143, 266}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{143, 267}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{143, 268}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{143, 269}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{143, 270}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{143, 271}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{143, 272}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{143, 273}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{143, 274}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{144, 145}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{144, 275}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{146, 276}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{146, 277}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{147, 159}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{147, 278}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{147, 279}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{148, 149}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{149, 150}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{150, 280}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{151, 158}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{151, 221}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{151, 222}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{151, 281}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{151, 282}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{151, 283}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{151, 284}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{151, 285}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{151, 286}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{151, 287}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{152, 288}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{152, 289}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{152, 290}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{153, 291}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{153, 292}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{153, 293}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{153, 294}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{153, 295}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{153, 296}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{154, 155}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{154, 297}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{154, 298}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{154, 299}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{154, 300}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{154, 301}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{155, 297}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{155, 300}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{155, 302}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{155, 303}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{156, 169}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{156, 304}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{158, 199}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{158, 222}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{158, 305}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{158, 306}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{158, 307}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{159, 163}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{159, 202}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{159, 308}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{159, 309}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{161, 310}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{163, 295}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{163, 311}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{163, 312}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{163, 313}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{163, 314}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{163, 315}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{163, 316}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{163, 317}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{163, 318}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{163, 319}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{164, 282}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{164, 320}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{164, 321}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{164, 322}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 323}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 324}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 325}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 326}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 327}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 328}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 329}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 330}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 331}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 332}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 333}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 334}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 335}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 336}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 337}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 338}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 339}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 340}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 341}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 342}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 343}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 344}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 345}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 346}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 347}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 348}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 349}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 350}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{168, 351}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{169, 352}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{170, 288}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{170, 353}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{170, 354}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{170, 355}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{170, 356}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{171, 175}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{171, 176}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{171, 258}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{171, 357}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{171, 358}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{171, 359}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{171, 360}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{171, 361}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{171, 362}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{172, 175}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{172, 176}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{172, 363}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{172, 364}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{173, 174}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{173, 175}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{173, 176}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{173, 177}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{174, 175}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{174, 176}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{174, 177}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{175, 176}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{175, 177}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{176, 177}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{178, 365}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{178, 366}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{179, 180}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{179, 254}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{179, 367}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{179, 368}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{179, 369}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{179, 370}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{179, 371}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{179, 372}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{179, 373}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{179, 374}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{179, 375}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{179, 376}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{180, 253}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{180, 374}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{180, 377}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{180, 378}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{181, 379}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{181, 380}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{181, 381}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{182, 183}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{182, 184}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{182, 382}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{182, 383}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{182, 384}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{182, 385}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{182, 386}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{182, 387}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{183, 292}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{183, 388}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{183, 389}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{183, 390}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{183, 391}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{183, 392}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{183, 393}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{183, 394}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{183, 395}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{184, 396}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{184, 397}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{184, 398}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{185, 186}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{185, 187}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{185, 399}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{185, 400}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{185, 401}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{185, 402}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{186, 187}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{186, 235}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{186, 399}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{186, 400}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{186, 401}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{186, 402}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{187, 234}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{187, 235}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{187, 399}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{187, 401}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{187, 402}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{188, 403}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{188, 404}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{188, 405}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{189, 190}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{189, 406}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{189, 407}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{190, 406}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{190, 407}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{190, 408}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{190, 409}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{190, 410}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{190, 411}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{190, 412}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{191, 192}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{193, 413}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{196, 240}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{196, 267}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{196, 414}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{196, 415}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{196, 416}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{196, 417}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{196, 418}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{196, 419}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{196, 420}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{196, 421}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{198, 200}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{198, 202}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{198, 205}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{198, 206}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{198, 208}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{198, 209}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{198, 214}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{198, 260}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{198, 422}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{198, 423}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{198, 424}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{198, 425}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{198, 426}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{198, 427}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 245}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 428}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 429}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 430}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 431}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 432}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 433}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 434}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 435}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 436}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 437}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 438}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 439}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 440}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 441}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 442}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 443}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 444}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 445}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 447}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 456}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{199, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{200, 205}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{200, 206}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{200, 209}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{200, 422}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{200, 426}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{202, 430}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{202, 463}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{202, 464}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{203, 465}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{204, 466}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{204, 467}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{204, 468}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{204, 469}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{204, 470}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{204, 471}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{205, 206}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{205, 260}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{205, 422}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{205, 423}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{205, 425}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{205, 426}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{205, 427}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{206, 208}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{206, 209}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{206, 422}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{206, 424}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{206, 426}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{206, 472}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{206, 473}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{207, 273}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{207, 474}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{207, 475}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{207, 476}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{208, 311}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{208, 422}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{208, 477}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{208, 478}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{210, 288}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{210, 289}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{210, 479}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{210, 480}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{210, 481}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{211, 305}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{211, 482}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{211, 483}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{211, 484}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{211, 485}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 433}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 434}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 435}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 436}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 437}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 439}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 441}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 443}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 444}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 482}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{212, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{213, 499}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{214, 500}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{214, 501}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{214, 502}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{214, 503}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{214, 504}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{214, 505}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{214, 506}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{215, 507}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{217, 355}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{217, 508}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{217, 509}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{217, 510}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{218, 511}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{218, 512}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{218, 513}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{218, 514}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{219, 515}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{219, 516}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{219, 517}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{220, 221}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{220, 518}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{221, 222}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{221, 285}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{221, 286}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{221, 287}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{222, 284}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{222, 285}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{222, 287}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{223, 224}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{223, 225}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{224, 225}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{226, 227}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{226, 228}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{226, 229}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{226, 519}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{226, 520}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{226, 521}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{227, 228}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{227, 229}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{227, 519}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{227, 520}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{228, 229}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{228, 520}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{229, 520}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{230, 236}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{231, 232}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{231, 233}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{231, 234}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{231, 235}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{231, 401}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{232, 233}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{232, 234}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{232, 235}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{233, 234}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{233, 235}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{233, 402}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{234, 235}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{235, 399}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{235, 402}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{236, 522}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{237, 238}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{238, 523}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{238, 524}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{238, 525}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{238, 526}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{238, 527}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{238, 528}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{238, 529}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{240, 249}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{240, 418}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{240, 530}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{240, 531}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{240, 532}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{240, 533}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{241, 246}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{241, 534}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{241, 535}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{241, 536}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{242, 243}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{242, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{242, 537}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{242, 538}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{242, 539}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{242, 540}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{242, 541}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{242, 542}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{243, 446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{243, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{243, 537}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{243, 538}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{243, 539}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{243, 540}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{243, 541}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{243, 542}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{243, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{244, 262}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{245, 429}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{245, 544}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{245, 545}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{245, 546}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{245, 547}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{246, 271}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{246, 535}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{246, 548}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{246, 549}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{246, 550}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{246, 551}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{246, 552}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{247, 553}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{247, 554}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{248, 398}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{248, 555}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{248, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{249, 557}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{249, 558}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{250, 251}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{250, 252}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{253, 254}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{254, 377}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{254, 378}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{254, 559}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{258, 360}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{258, 560}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{258, 561}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{258, 562}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{259, 563}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{260, 422}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{260, 564}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{260, 565}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{260, 566}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{261, 567}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{261, 568}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{261, 569}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{263, 570}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{263, 571}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{264, 267}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{264, 414}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{264, 416}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{264, 417}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{264, 419}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{264, 420}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{264, 571}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{264, 572}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{264, 573}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{265, 574}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{265, 575}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{266, 272}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{266, 273}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{266, 475}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{266, 476}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{266, 576}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{266, 577}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{267, 414}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{267, 416}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{267, 417}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{267, 418}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{267, 419}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{267, 420}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{267, 421}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{267, 530}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{267, 571}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{267, 572}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{267, 573}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{267, 578}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{268, 270}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{268, 271}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{270, 579}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{271, 534}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{271, 551}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{271, 552}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{271, 580}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{272, 475}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{272, 476}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{273, 475}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{273, 576}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{273, 581}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{273, 582}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{274, 583}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{275, 584}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{276, 277}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{276, 585}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{276, 586}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{276, 587}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{277, 588}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{279, 287}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{279, 398}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{279, 438}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{279, 444}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{279, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{279, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{279, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{279, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{279, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{279, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{279, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{279, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{279, 589}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{279, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{280, 591}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{280, 592}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{281, 285}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{281, 286}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{281, 593}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{281, 594}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{281, 595}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{281, 596}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{281, 597}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{281, 598}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{281, 599}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{281, 600}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{281, 601}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{281, 602}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{281, 603}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{281, 604}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{282, 352}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{283, 431}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{283, 434}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{283, 436}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{283, 439}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{283, 441}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{283, 442}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{283, 443}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{283, 444}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{283, 446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{283, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{283, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{283, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{283, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{283, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{283, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{283, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{283, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{283, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{283, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{283, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{283, 606}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{284, 285}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{284, 287}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 286}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 287}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 430}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 431}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 436}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 437}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 438}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 439}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 440}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 441}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 442}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 443}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 444}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 445}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 447}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 456}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 606}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{285, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{286, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{286, 614}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{286, 615}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{288, 289}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{288, 616}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{288, 617}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{288, 618}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{288, 619}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{289, 479}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{289, 480}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{289, 481}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{289, 620}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{289, 621}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{289, 622}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{291, 292}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{292, 293}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{294, 560}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{294, 623}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{294, 624}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{295, 318}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{295, 319}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{295, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{295, 625}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{295, 626}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{295, 627}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{295, 628}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{296, 629}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{296, 630}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{296, 631}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{296, 632}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{297, 298}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{297, 299}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{297, 633}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{297, 634}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{298, 299}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{298, 301}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{298, 633}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{299, 300}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{301, 634}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{301, 635}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{301, 636}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{301, 637}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{301, 638}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{301, 639}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{301, 640}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{301, 641}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{301, 642}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{301, 643}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{301, 644}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{301, 645}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{301, 646}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{301, 647}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{301, 648}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{302, 649}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{302, 650}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{303, 649}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{304, 356}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{304, 651}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{304, 652}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{304, 653}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{305, 484}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{305, 485}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{308, 463}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{308, 654}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{309, 655}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{309, 656}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{309, 657}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{312, 658}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{312, 659}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{312, 660}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{312, 661}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{312, 662}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{314, 586}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{314, 587}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{314, 588}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{314, 663}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{315, 664}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{315, 665}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{315, 666}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{315, 667}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{317, 350}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{317, 668}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{318, 669}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{318, 670}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{318, 671}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{319, 672}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{319, 673}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{321, 501}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{321, 502}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{321, 674}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{321, 675}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{321, 676}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{321, 677}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{321, 678}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{323, 324}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{323, 325}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{323, 326}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{323, 327}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{323, 329}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{323, 340}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{323, 341}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{323, 342}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{323, 343}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{323, 344}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{323, 345}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{323, 679}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{323, 680}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{323, 681}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{323, 682}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{323, 683}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{323, 684}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 325}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 326}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 327}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 330}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 336}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 337}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 340}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 341}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 342}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 343}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 344}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 346}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 347}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 348}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 679}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 680}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 681}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 682}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 683}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 684}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 685}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 686}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 687}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 688}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 689}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 690}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 691}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 692}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 693}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 695}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{324, 696}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 326}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 327}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 337}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 340}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 341}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 343}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 344}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 346}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 347}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 348}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 679}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 680}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 681}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 682}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 683}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 684}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 685}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 686}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 687}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 688}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 689}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 690}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 691}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 692}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 693}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 695}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 696}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 697}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{325, 698}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 327}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 329}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 330}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 331}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 334}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 335}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 336}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 337}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 340}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 341}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 342}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 343}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 344}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 345}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 346}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 347}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 348}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 679}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 680}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 681}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 682}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 683}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 684}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 685}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 686}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 687}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 689}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 690}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 691}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 693}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{326, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{327, 329}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{327, 330}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{327, 336}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{327, 337}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{327, 340}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{327, 341}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{327, 342}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{327, 343}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{327, 344}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{327, 345}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{327, 346}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{327, 347}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{327, 348}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{327, 679}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{327, 680}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{327, 681}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{327, 682}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{327, 683}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{327, 684}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{327, 685}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{327, 686}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{327, 687}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{327, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{328, 331}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{328, 332}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{328, 335}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{329, 330}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{329, 331}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{329, 332}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{329, 333}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{329, 334}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{329, 335}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{329, 336}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{329, 337}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{329, 343}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{329, 344}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{329, 345}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{329, 347}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{329, 351}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{329, 693}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{329, 695}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{330, 331}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{330, 332}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{330, 333}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{330, 334}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{330, 335}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{330, 336}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{330, 337}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{330, 341}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{330, 342}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{330, 343}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{330, 344}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{330, 346}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{330, 347}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{330, 348}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{330, 349}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{330, 351}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{330, 699}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{331, 332}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{331, 333}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{331, 334}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{331, 335}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{331, 336}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{331, 337}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{331, 347}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{331, 349}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{331, 351}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{332, 333}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{332, 334}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{332, 335}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{332, 336}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{332, 337}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{332, 347}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{332, 348}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{332, 349}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{332, 351}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{332, 682}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{333, 334}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{333, 335}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{333, 336}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{333, 343}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{333, 344}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{334, 335}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{334, 336}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{334, 337}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{334, 340}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{334, 342}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{334, 343}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{334, 344}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{335, 336}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{335, 337}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{335, 342}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{335, 343}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{335, 344}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{335, 347}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{335, 349}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{335, 351}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{336, 337}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{336, 338}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{336, 339}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{336, 341}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{336, 342}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{336, 343}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{336, 344}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{336, 346}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{336, 347}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{336, 348}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{336, 682}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{336, 686}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{336, 690}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{337, 338}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{337, 339}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{337, 341}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{337, 342}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{337, 343}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{337, 346}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{337, 347}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{337, 348}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{337, 681}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{337, 682}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{337, 684}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{337, 685}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{337, 686}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{337, 689}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{338, 339}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{338, 341}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{339, 341}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{340, 341}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{340, 342}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{340, 343}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{340, 344}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{340, 345}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{340, 679}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{340, 680}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{340, 681}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{340, 682}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{340, 683}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{340, 695}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{341, 342}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{341, 343}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{341, 344}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{341, 345}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{341, 346}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{341, 347}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{341, 348}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{341, 679}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{341, 680}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{341, 681}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{341, 682}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{341, 683}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{341, 684}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{341, 685}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{341, 686}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{341, 689}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{341, 690}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{341, 692}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{341, 693}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{341, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{341, 695}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{341, 697}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{341, 700}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{342, 343}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{342, 344}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{342, 346}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{342, 347}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{342, 679}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{343, 344}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{343, 345}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{343, 346}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{343, 347}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{343, 348}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{343, 679}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{343, 680}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{343, 681}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{343, 682}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{343, 683}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{343, 684}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{343, 685}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{343, 686}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{343, 690}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{343, 691}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{343, 693}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{343, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{343, 695}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{344, 345}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{344, 346}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{344, 347}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{344, 348}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{344, 679}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{344, 680}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{344, 681}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{344, 682}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{344, 683}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{344, 684}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{344, 685}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{344, 687}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{344, 690}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{344, 691}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{344, 692}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{344, 693}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{344, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{344, 695}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{344, 697}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{345, 346}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{345, 347}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{345, 679}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{345, 690}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{345, 691}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{345, 693}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{345, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{345, 695}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 347}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 348}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 680}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 681}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 682}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 683}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 684}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 685}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 686}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 687}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 688}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 689}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 690}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 691}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 692}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 693}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 695}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 696}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 697}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 698}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 701}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 702}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{346, 703}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{347, 348}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{347, 680}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{347, 681}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{347, 682}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{347, 683}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{347, 684}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{347, 685}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{347, 686}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{347, 687}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{347, 688}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{347, 689}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{347, 690}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{347, 691}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{347, 692}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{347, 693}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{347, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{347, 695}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{347, 696}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{347, 697}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{347, 698}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{347, 701}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{347, 702}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{347, 703}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{348, 680}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{348, 681}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{348, 682}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{348, 683}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{348, 684}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{348, 685}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{348, 686}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{348, 687}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{348, 688}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{348, 689}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{348, 690}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{348, 691}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{348, 692}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{348, 693}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{348, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{348, 695}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{348, 696}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{348, 697}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{348, 698}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{348, 702}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{348, 703}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{350, 704}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{350, 705}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{350, 706}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{350, 707}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{351, 577}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{352, 708}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{352, 709}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{353, 354}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{353, 355}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{353, 710}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{354, 355}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{354, 710}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{355, 583}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{355, 710}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{357, 358}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{358, 361}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{359, 360}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{359, 361}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{359, 362}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{359, 562}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{360, 361}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{360, 362}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{360, 562}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{360, 711}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{361, 362}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{361, 562}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{362, 562}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{362, 712}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{363, 713}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{364, 391}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{367, 368}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{367, 369}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{367, 371}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{367, 714}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{367, 715}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{367, 716}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{367, 717}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{368, 369}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{368, 716}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{368, 718}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{368, 719}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{369, 371}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{369, 714}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{369, 718}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{369, 720}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{369, 721}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{369, 722}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{370, 373}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{370, 376}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{370, 714}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{370, 715}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{370, 716}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{370, 723}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{370, 724}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{371, 373}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{371, 375}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{371, 715}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{371, 716}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{371, 717}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{371, 721}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{371, 722}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{371, 725}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{371, 726}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{371, 727}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{372, 373}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{372, 376}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{372, 728}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{373, 376}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{373, 715}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{373, 716}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{373, 728}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{373, 729}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{373, 730}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{374, 715}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{376, 716}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{376, 717}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{376, 731}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{377, 378}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{377, 559}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{377, 565}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{378, 565}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{378, 732}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{378, 733}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{379, 380}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{381, 734}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{381, 735}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{381, 736}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{382, 737}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{382, 738}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{382, 739}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{383, 384}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{383, 740}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{384, 740}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{385, 741}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{386, 742}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{387, 743}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{387, 744}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{389, 567}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{389, 745}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{390, 746}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{390, 747}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{390, 748}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{390, 749}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{390, 750}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{390, 751}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{390, 752}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{391, 753}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{392, 745}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{392, 754}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{393, 755}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{394, 485}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{394, 756}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{394, 757}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{394, 758}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{394, 759}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{394, 760}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{394, 761}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{395, 728}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{395, 762}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{396, 397}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{398, 438}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{398, 444}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{398, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{398, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{398, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{398, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{398, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{398, 557}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{398, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{398, 626}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{399, 400}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{399, 401}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{399, 402}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{399, 763}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{399, 764}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{400, 401}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{400, 763}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{400, 764}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{401, 402}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{401, 764}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{403, 765}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{403, 766}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{404, 767}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{404, 768}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{405, 769}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{405, 770}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{405, 771}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{406, 407}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{406, 410}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{406, 411}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{406, 412}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{406, 772}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{406, 773}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{407, 408}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{407, 409}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{407, 410}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{407, 411}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{407, 412}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{407, 774}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{408, 412}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{408, 775}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{408, 776}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{408, 777}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{409, 772}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{409, 778}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{410, 779}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{410, 780}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{410, 781}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{412, 779}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{412, 780}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{414, 416}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{414, 417}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{414, 419}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{414, 420}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{414, 572}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{414, 573}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{415, 782}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{416, 417}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{416, 419}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{416, 420}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{416, 572}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{416, 573}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{416, 783}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{416, 784}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{416, 785}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{416, 786}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{417, 419}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{417, 420}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{417, 572}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{417, 573}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{418, 530}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{418, 578}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{418, 787}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{418, 788}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{418, 789}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{418, 790}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{419, 420}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{419, 571}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{419, 572}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{419, 573}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{420, 571}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{420, 572}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{420, 573}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{421, 530}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{421, 578}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{421, 787}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{421, 791}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{422, 792}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{423, 427}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{423, 793}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{423, 794}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{423, 795}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{424, 796}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{425, 797}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{426, 427}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{426, 631}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{426, 798}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 429}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 430}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 431}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 432}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 434}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 435}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 436}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 437}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 438}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 439}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 440}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 441}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 442}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 443}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 444}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 445}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 447}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 456}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 465}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 669}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 799}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{428, 801}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 430}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 431}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 435}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 436}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 437}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 438}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 439}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 441}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 444}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 445}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 447}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 456}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 799}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{429, 802}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 431}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 434}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 436}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 437}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 438}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 439}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 440}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 441}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 445}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 463}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 544}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{430, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 434}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 436}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 437}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 438}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 439}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 440}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 441}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 444}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 445}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 447}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 482}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{431, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 433}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 434}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 435}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 436}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 438}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 440}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 445}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 447}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 614}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 626}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 669}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{432, 803}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 434}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 435}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 436}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 437}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 439}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 441}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 442}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 443}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 444}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 445}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 482}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 669}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{433, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 435}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 436}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 437}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 438}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 439}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 440}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 441}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 442}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 443}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 444}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 445}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 482}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{434, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 436}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 437}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 438}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 439}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 440}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 441}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 442}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 443}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 444}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 445}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 447}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 456}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 669}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 799}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{435, 804}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 437}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 438}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 439}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 440}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 441}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 442}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 443}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 444}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 445}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 447}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 482}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 669}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 799}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{436, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 438}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 439}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 440}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 441}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 442}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 443}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 444}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 445}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 447}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{437, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 439}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 440}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 441}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 442}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 443}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 444}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 445}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 447}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 456}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 465}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 482}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 669}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 801}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{438, 805}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 440}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 441}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 442}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 443}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 444}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 445}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 447}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 482}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 799}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{439, 801}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 441}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 442}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 443}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 444}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 445}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 447}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 456}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 465}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 482}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 669}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{440, 805}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 442}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 443}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 444}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 445}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 447}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 456}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 799}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{441, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 443}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 444}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 445}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 447}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{442, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 444}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 445}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 447}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{443, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 445}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 447}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 799}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{444, 805}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 447}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 456}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 482}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 669}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 799}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 801}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{445, 805}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 447}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 482}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{446, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 456}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 465}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 669}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 799}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{447, 801}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 456}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 799}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 801}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{448, 802}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 482}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{449, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 456}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 482}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 799}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 801}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{450, 802}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 799}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{451, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 456}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 465}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 482}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 589}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 669}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{452, 802}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 456}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 465}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 799}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{453, 802}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 456}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 465}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 482}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 669}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 802}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{454, 805}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 482}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 669}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{455, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{456, 457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{456, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{456, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{456, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{456, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{456, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{456, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{456, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{456, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{456, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{456, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{456, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{456, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 799}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{457, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 799}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{458, 801}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{459, 802}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{460, 461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{460, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{460, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{460, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{460, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{460, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{460, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{460, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{460, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{460, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{460, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{460, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{460, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{460, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{460, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{460, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{460, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{460, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{460, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{460, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{460, 669}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{460, 799}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{460, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{461, 462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{461, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{461, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{461, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{461, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{461, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{461, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{461, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{461, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{461, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{461, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{461, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{461, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{461, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{461, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{461, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{461, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{461, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{461, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{461, 669}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{461, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{462, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{462, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{462, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{462, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{462, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{462, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{462, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{462, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{462, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{462, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{462, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{462, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{462, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{462, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{462, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{462, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{463, 464}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{463, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{463, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{463, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{463, 801}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{465, 486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{465, 487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{465, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{465, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{465, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{465, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{465, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{466, 467}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{466, 468}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{466, 469}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{466, 470}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{467, 468}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{467, 469}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{467, 470}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{467, 806}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{468, 469}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{468, 470}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{468, 807}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{469, 470}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{469, 806}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{469, 807}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{471, 808}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{471, 809}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{471, 810}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{473, 811}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{474, 812}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{475, 576}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{475, 581}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{475, 582}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{477, 813}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{477, 814}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{477, 815}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{478, 803}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{478, 816}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{478, 817}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{478, 818}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{478, 819}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{478, 820}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{478, 821}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{478, 822}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{478, 823}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{478, 824}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{479, 480}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{479, 481}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{479, 600}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{479, 601}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{479, 825}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{480, 481}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{480, 621}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{480, 622}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{480, 826}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{481, 620}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{481, 621}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{481, 622}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{481, 826}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{481, 827}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{482, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{482, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{482, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{482, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{482, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{482, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{482, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{482, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{482, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{482, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{482, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{482, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{482, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{483, 484}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{483, 485}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{483, 828}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{484, 485}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{485, 758}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{485, 759}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{486, 487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{486, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{486, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{486, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{486, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{486, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{486, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{486, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{486, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{486, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{486, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{486, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{486, 799}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{487, 488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{487, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{487, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{487, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{487, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{487, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{487, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{487, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{487, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{487, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{487, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{488, 489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{488, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{488, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{488, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{488, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{488, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{488, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{488, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{488, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{488, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{488, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{488, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{488, 829}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{489, 490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{489, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{489, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{489, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{489, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{489, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{489, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{489, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{489, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{489, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{489, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{489, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{489, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{489, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{489, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{489, 799}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{489, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{490, 491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{490, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{490, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{490, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{490, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{490, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{490, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{490, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{490, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{490, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{490, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{491, 492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{491, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{491, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{491, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{491, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{491, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{491, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{491, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{491, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{491, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{491, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{491, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{491, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{491, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{491, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{491, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{491, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{491, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{491, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{492, 493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{492, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{492, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{492, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{492, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{492, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{492, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{492, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{492, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{492, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{492, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{492, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{492, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{492, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{492, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{492, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{492, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{492, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{492, 801}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{493, 494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{493, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{493, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{493, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{493, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{493, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{493, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{493, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{493, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{493, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{493, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{493, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{493, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{493, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{493, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{493, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{493, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{493, 801}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{494, 495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{494, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{494, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{494, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{494, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{494, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{494, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{494, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{494, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{494, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{494, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{494, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{494, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{494, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{494, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{494, 799}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{494, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{495, 496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{495, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{495, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{495, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{495, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{495, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{495, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{495, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{495, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{495, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{496, 497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{496, 498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{496, 614}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{496, 669}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{496, 830}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{497, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{498, 543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{498, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{498, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{498, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{498, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{498, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{498, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{498, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{498, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{499, 831}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{499, 832}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{499, 833}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{499, 834}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{499, 835}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{500, 505}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{500, 836}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{500, 837}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{501, 502}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{501, 674}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{501, 675}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{501, 676}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{501, 677}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{501, 838}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{502, 674}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{502, 675}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{502, 676}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{502, 677}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{502, 838}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{502, 839}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{503, 504}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{503, 505}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{503, 840}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{503, 841}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{503, 842}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{503, 843}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{503, 844}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{504, 505}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{504, 845}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{507, 846}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{508, 509}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{508, 847}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{508, 848}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{510, 820}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{510, 849}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{510, 850}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{510, 851}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{511, 512}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{511, 513}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{511, 514}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{512, 513}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{512, 514}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{513, 514}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{513, 852}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{513, 853}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{514, 852}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{514, 854}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{515, 516}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{515, 855}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{515, 856}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{516, 857}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{517, 856}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{517, 857}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{517, 858}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{519, 520}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{521, 859}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{521, 860}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{521, 861}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{521, 862}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{523, 583}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{523, 863}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{523, 864}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{523, 865}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{524, 525}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{524, 529}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{524, 865}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{524, 866}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{524, 867}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{524, 868}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{524, 869}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{524, 870}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{524, 871}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{525, 865}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{525, 868}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{525, 869}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{525, 871}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{525, 872}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{526, 873}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{526, 874}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{528, 875}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{529, 865}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{529, 868}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{529, 869}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{529, 870}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{529, 871}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{529, 872}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{530, 578}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{530, 787}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{530, 788}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{531, 533}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{531, 787}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{531, 876}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{531, 877}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{533, 876}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{533, 878}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{533, 879}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{533, 880}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{533, 881}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{534, 535}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{534, 882}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{535, 536}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{535, 883}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{535, 884}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{536, 883}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{536, 884}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{537, 538}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{537, 539}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{537, 540}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{537, 541}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{537, 542}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{538, 539}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{538, 540}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{538, 541}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{538, 542}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{539, 540}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{539, 541}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{539, 542}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{540, 541}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{540, 542}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{541, 542}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{541, 885}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{541, 886}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{542, 885}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{543, 556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{543, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{543, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{543, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{543, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{543, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{543, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{543, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{543, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{543, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{543, 669}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{543, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{543, 801}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{543, 805}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{544, 545}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{544, 887}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{545, 546}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{545, 547}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{545, 888}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{545, 889}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{545, 890}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{545, 891}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{546, 547}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{546, 825}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{546, 878}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{547, 825}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{547, 880}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{547, 892}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{547, 893}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{548, 579}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{548, 894}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{548, 895}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{549, 550}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{550, 821}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{550, 896}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{550, 897}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{550, 898}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{550, 899}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{551, 878}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{551, 880}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{552, 900}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{552, 901}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{553, 902}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{553, 903}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{554, 904}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{555, 850}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{555, 905}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{555, 906}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{555, 907}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{556, 557}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{556, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{556, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{556, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{556, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{556, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{556, 626}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{556, 801}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{556, 908}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{556, 909}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{557, 590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{557, 626}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{558, 910}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{559, 911}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{559, 912}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{560, 623}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{560, 624}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{561, 624}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{561, 913}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{563, 914}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{564, 565}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{564, 915}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{564, 916}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{564, 917}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{565, 916}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{565, 917}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{566, 587}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{566, 918}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{567, 745}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{567, 919}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{567, 920}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{567, 921}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{568, 569}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{568, 920}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{569, 922}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{572, 573}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{574, 923}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{574, 924}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{574, 925}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{574, 926}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{574, 927}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{576, 577}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{576, 928}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{578, 787}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{578, 788}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{578, 791}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{579, 654}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{579, 929}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{581, 746}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{581, 930}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{582, 931}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{582, 932}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{582, 933}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{583, 887}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{583, 934}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{583, 935}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{584, 936}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{586, 588}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{587, 588}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{587, 918}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{589, 937}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{589, 938}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{590, 605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{590, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{590, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{590, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{590, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{590, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{590, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{590, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{590, 626}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{590, 670}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{590, 939}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{591, 592}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{591, 940}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{593, 594}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{593, 595}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{593, 597}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{593, 600}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{593, 941}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{593, 942}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{593, 943}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{594, 595}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{594, 596}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{594, 597}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{594, 598}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{594, 599}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{594, 600}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{594, 601}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{594, 602}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{594, 603}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{594, 604}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{594, 941}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{594, 942}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{594, 943}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{594, 944}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{594, 945}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{594, 946}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{594, 947}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{594, 948}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{594, 949}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{595, 596}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{595, 597}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{595, 598}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{595, 599}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{595, 600}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{595, 943}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{595, 944}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{595, 946}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{595, 950}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{595, 951}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{595, 952}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{596, 597}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{596, 598}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{596, 599}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{596, 600}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{596, 922}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{596, 941}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{596, 942}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{596, 943}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{596, 944}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{596, 950}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{596, 953}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{596, 954}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{597, 598}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{597, 599}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{597, 600}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{597, 601}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{597, 604}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{597, 941}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{597, 942}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{597, 943}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{597, 944}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{597, 950}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{597, 955}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{598, 599}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{598, 600}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{598, 601}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{598, 922}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{598, 943}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{598, 944}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{598, 946}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{598, 949}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{598, 950}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{598, 955}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{599, 600}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{599, 601}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{599, 941}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{599, 943}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{599, 950}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{599, 952}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{600, 601}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{600, 604}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{600, 943}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{600, 956}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{600, 957}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{601, 602}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{601, 631}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{601, 901}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{601, 948}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{601, 956}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{601, 957}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{601, 958}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{601, 959}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{601, 960}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{602, 961}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{602, 962}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{604, 963}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{605, 607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{605, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{605, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{605, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{605, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{605, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{605, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{605, 669}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{605, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{605, 829}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{606, 960}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{606, 964}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{607, 608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{607, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{607, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{607, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{607, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{608, 609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{608, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{608, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{608, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{608, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{608, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{608, 802}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{608, 805}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{609, 610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{609, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{609, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{609, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{609, 669}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{609, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{609, 805}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{610, 611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{610, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{610, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{610, 669}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{610, 799}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{610, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{610, 802}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{610, 805}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{611, 612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{611, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{611, 669}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{611, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{612, 613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{612, 669}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{612, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{612, 802}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{612, 805}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{613, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{613, 965}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{613, 966}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{614, 615}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{614, 671}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{616, 815}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{616, 828}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{616, 967}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{617, 618}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{617, 619}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{618, 619}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{618, 968}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{619, 969}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{621, 622}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{621, 827}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{621, 970}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{621, 971}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{622, 790}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{622, 827}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{622, 971}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{622, 972}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{622, 973}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{622, 974}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{623, 624}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{624, 825}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{624, 913}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{624, 975}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{625, 976}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{626, 628}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{626, 803}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{626, 909}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{626, 977}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{626, 978}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{626, 979}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{626, 980}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{626, 981}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{629, 821}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{629, 982}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{630, 664}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{630, 983}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{630, 984}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{631, 632}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{631, 794}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{631, 985}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{632, 820}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{632, 849}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{632, 982}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{632, 984}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{632, 985}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{632, 986}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{632, 987}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{632, 988}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{632, 989}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{632, 990}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{634, 635}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{634, 636}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{634, 637}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{634, 638}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{634, 639}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{634, 641}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{634, 643}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{634, 644}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{634, 645}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{634, 647}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{634, 648}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{635, 636}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{635, 637}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{635, 638}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{635, 643}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{636, 637}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{636, 638}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{636, 640}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{636, 642}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{636, 643}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{636, 991}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{636, 992}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{636, 993}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{637, 638}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{637, 642}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{637, 643}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{637, 994}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{638, 642}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{638, 643}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{639, 640}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{639, 641}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{639, 643}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{639, 991}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{639, 994}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{639, 995}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{639, 996}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{639, 997}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{639, 998}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{639, 999}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{639, 1000}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{639, 1001}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{639, 1002}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{639, 1003}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{640, 641}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{640, 643}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{640, 991}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{640, 994}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{640, 1004}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{641, 643}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{641, 991}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{641, 994}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{641, 996}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{641, 998}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{642, 643}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{643, 644}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{643, 645}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{643, 647}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{643, 994}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{643, 1005}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{644, 645}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{644, 1005}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{644, 1006}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{644, 1007}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{645, 1005}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{645, 1007}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{645, 1008}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{646, 647}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{646, 992}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{646, 993}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{646, 994}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{646, 1004}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{646, 1009}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{647, 992}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{647, 993}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{647, 1004}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{647, 1009}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{647, 1010}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{649, 1011}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{650, 1012}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{650, 1013}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{650, 1014}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{652, 815}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{653, 1015}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{653, 1016}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{654, 672}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{654, 929}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{655, 656}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{656, 983}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{656, 1017}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{656, 1018}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{656, 1019}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{657, 1020}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{657, 1021}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{659, 660}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{659, 661}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{659, 662}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{659, 1022}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{660, 661}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{660, 662}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{660, 1022}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{661, 662}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{661, 1022}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{661, 1023}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{662, 1022}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{662, 1023}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{664, 983}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{664, 984}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{667, 1024}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{668, 1025}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{668, 1026}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{669, 800}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{669, 830}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{669, 1027}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{672, 1028}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{673, 1029}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{674, 675}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{674, 676}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{674, 677}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{674, 838}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{674, 839}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{675, 676}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{675, 677}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{675, 838}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{675, 1030}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{676, 677}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{676, 838}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{677, 838}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{677, 1031}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{678, 1032}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{678, 1033}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{678, 1034}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{678, 1035}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{679, 680}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{679, 681}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{679, 682}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{679, 683}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{679, 684}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{680, 681}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{680, 682}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{680, 683}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{680, 684}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{680, 685}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{680, 686}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{680, 687}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{680, 690}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{680, 691}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{680, 693}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{680, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{680, 695}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{680, 697}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{681, 682}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{681, 683}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{681, 684}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{681, 685}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{681, 686}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{681, 687}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{681, 689}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{681, 690}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{681, 691}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{681, 692}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{681, 693}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{681, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{681, 695}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{681, 697}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{682, 683}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{682, 684}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{682, 685}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{682, 686}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{682, 687}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{682, 688}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{682, 689}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{682, 690}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{682, 691}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{682, 692}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{682, 693}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{682, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{682, 695}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{682, 696}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{682, 697}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{682, 698}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{682, 703}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{683, 684}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{683, 685}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{683, 686}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{683, 687}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{683, 689}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{683, 690}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{683, 691}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{683, 692}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{683, 693}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{683, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{683, 695}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{683, 696}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{683, 697}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{683, 698}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{683, 702}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{684, 685}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{684, 686}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{684, 687}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{684, 688}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{684, 689}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{684, 690}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{684, 691}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{684, 692}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{684, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{684, 695}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{684, 697}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{685, 686}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{685, 687}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{685, 688}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{685, 689}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{685, 690}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{685, 691}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{685, 692}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{685, 693}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{685, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{685, 695}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{685, 696}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{685, 697}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{685, 698}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{686, 687}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{686, 688}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{686, 689}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{686, 690}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{686, 691}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{686, 692}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{686, 693}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{686, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{686, 695}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{687, 690}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{687, 691}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{687, 692}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{687, 693}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{687, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{687, 697}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{688, 689}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{688, 690}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{688, 691}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{688, 692}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{688, 693}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{688, 696}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{688, 698}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{688, 702}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{688, 703}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{688, 1036}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{689, 690}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{689, 691}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{689, 692}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{689, 693}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{689, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{689, 696}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{689, 697}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{689, 698}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{689, 702}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{689, 703}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{689, 1036}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{690, 691}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{690, 692}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{690, 693}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{690, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{690, 695}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{690, 696}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{690, 697}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{690, 698}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{690, 702}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{690, 703}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{691, 692}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{691, 693}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{691, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{691, 695}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{691, 696}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{691, 697}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{691, 698}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{691, 702}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{691, 703}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{692, 693}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{692, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{692, 695}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{692, 696}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{692, 697}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{692, 698}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{692, 702}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{693, 694}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{693, 695}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{693, 696}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{693, 697}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{693, 698}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{693, 702}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{693, 703}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{694, 695}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{694, 696}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{694, 697}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{694, 698}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{694, 702}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{695, 696}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{695, 698}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{695, 702}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{695, 703}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{696, 697}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{696, 698}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{696, 702}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{696, 703}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{697, 702}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{698, 702}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{698, 703}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{699, 1037}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{700, 701}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{702, 703}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{704, 705}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{704, 1038}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{705, 706}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{705, 707}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{705, 1039}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{705, 1040}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{706, 707}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{706, 1038}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{706, 1039}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{707, 783}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{707, 1038}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{707, 1039}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{707, 1040}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{707, 1041}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{707, 1042}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{707, 1043}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{707, 1044}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{707, 1045}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{708, 1046}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{708, 1047}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{708, 1048}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{709, 1049}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{709, 1050}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{713, 1051}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{714, 716}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{714, 721}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{715, 716}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{715, 717}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{715, 718}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{715, 719}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{715, 723}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{715, 727}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{715, 1052}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{715, 1053}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{716, 717}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{716, 722}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{717, 722}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{717, 727}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{718, 719}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{718, 722}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{719, 727}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{719, 1053}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{719, 1054}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{719, 1055}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{721, 726}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{721, 1056}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{723, 1057}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{723, 1058}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{732, 733}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{734, 735}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{734, 736}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{735, 736}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{737, 1059}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{738, 739}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{741, 1060}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{741, 1061}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{741, 1062}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{742, 1063}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{743, 744}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{743, 1064}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{743, 1065}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{745, 754}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{745, 1066}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{746, 747}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{746, 748}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{746, 749}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{746, 750}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{746, 751}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{747, 748}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{747, 749}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{747, 750}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{747, 751}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{747, 752}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{748, 749}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{748, 750}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{748, 751}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{748, 752}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{749, 750}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{749, 751}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{749, 752}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{750, 751}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{750, 752}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{751, 752}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{756, 757}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{756, 758}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{756, 759}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{756, 760}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{756, 1067}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{756, 1068}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{757, 758}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{757, 760}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{757, 1067}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{757, 1069}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{758, 1067}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{758, 1069}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{759, 760}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{759, 1068}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{759, 1070}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{765, 766}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{766, 1071}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{767, 1072}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{768, 1073}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{768, 1074}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{768, 1075}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{770, 771}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{774, 776}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{774, 777}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{774, 1076}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{775, 776}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{775, 777}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{776, 777}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{776, 1076}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{776, 1077}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{776, 1078}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{776, 1079}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{776, 1080}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{776, 1081}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{777, 1076}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{777, 1079}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{777, 1080}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{777, 1081}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{777, 1082}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{778, 1083}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{778, 1084}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{778, 1085}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{778, 1086}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{779, 780}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{779, 781}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{780, 781}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{782, 1087}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{783, 784}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{783, 888}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{783, 891}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{783, 1088}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{783, 1089}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{783, 1090}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{783, 1091}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{783, 1092}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{783, 1093}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{784, 888}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{784, 891}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{784, 1088}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{784, 1092}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{784, 1093}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{785, 1094}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{789, 1095}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{790, 1095}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{790, 1096}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{790, 1097}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{790, 1098}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{791, 1099}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{791, 1100}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{792, 1101}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{792, 1102}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{792, 1103}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{792, 1104}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{792, 1105}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{792, 1106}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{793, 1107}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{795, 1108}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{798, 967}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{798, 1109}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{798, 1110}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{798, 1111}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{800, 801}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{800, 1112}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{801, 909}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{801, 1112}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{801, 1113}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{801, 1114}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{803, 819}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{803, 824}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{803, 1115}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{804, 1116}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{804, 1117}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{806, 807}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{806, 1118}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{807, 1118}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{807, 1119}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{807, 1120}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{808, 1121}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{808, 1122}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{810, 1121}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{810, 1122}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{810, 1123}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{813, 814}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{813, 815}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{814, 815}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{816, 958}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{816, 961}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{817, 1124}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{817, 1125}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{817, 1126}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{819, 820}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{819, 821}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{819, 961}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{819, 1127}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{819, 1128}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{819, 1129}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{820, 821}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{820, 849}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{820, 985}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{821, 896}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{821, 897}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{821, 898}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{821, 986}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{821, 1129}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{821, 1130}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{821, 1131}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{822, 823}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{822, 1132}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{822, 1133}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{824, 896}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{824, 1115}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{824, 1134}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{825, 878}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{825, 880}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{826, 1135}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{827, 1136}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{828, 967}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{828, 1137}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{828, 1138}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{828, 1139}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{828, 1140}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{828, 1141}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{829, 1142}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{830, 1143}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{831, 832}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{831, 833}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{831, 834}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{831, 835}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{832, 833}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{832, 834}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{832, 1144}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{833, 834}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{833, 1144}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{836, 837}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{837, 927}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{837, 1145}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{839, 1030}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{839, 1146}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{839, 1147}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{839, 1148}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{839, 1149}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{840, 841}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{840, 842}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{840, 843}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{840, 932}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{840, 1150}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{840, 1151}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{840, 1152}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{840, 1153}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{841, 842}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{841, 843}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{841, 931}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{841, 1150}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{841, 1151}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{841, 1152}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{841, 1153}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{841, 1154}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{842, 843}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{842, 931}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{842, 932}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{842, 1150}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{842, 1151}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{842, 1152}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{842, 1153}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{842, 1154}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{843, 931}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{843, 932}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{843, 1150}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{843, 1151}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{843, 1152}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{843, 1153}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{843, 1154}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{844, 1155}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{845, 1156}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{849, 1157}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{850, 1158}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{851, 1159}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{852, 853}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{852, 1160}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{852, 1161}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{852, 1162}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{853, 1160}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{853, 1161}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{853, 1162}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{853, 1163}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{853, 1164}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{853, 1165}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{855, 1146}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{855, 1166}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{855, 1167}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{855, 1168}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{855, 1169}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{855, 1170}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{855, 1171}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{855, 1172}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{855, 1173}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{855, 1174}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{855, 1175}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{855, 1176}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{856, 857}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{856, 858}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{856, 1177}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{857, 858}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{859, 860}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{859, 861}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{859, 862}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{860, 861}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{860, 862}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{861, 862}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{863, 864}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{863, 928}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{863, 1178}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{863, 1179}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{863, 1180}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{864, 928}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{865, 869}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{865, 870}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{865, 871}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{865, 872}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{865, 1181}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{865, 1182}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{866, 867}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{866, 868}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{867, 868}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{868, 869}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{868, 871}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{868, 872}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{868, 1182}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{869, 871}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{870, 871}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{871, 872}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{871, 1181}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{871, 1182}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{871, 1183}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{872, 1182}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{874, 1184}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{877, 1185}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{878, 880}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{879, 881}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{879, 1186}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{879, 1187}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{880, 881}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{880, 1188}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{881, 1188}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{883, 884}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{887, 1189}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{887, 1190}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{887, 1191}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{887, 1192}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{887, 1193}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{887, 1194}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{888, 890}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{888, 891}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{888, 893}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{888, 1089}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{890, 1100}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{891, 1089}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{891, 1092}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{892, 1195}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{893, 1195}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{894, 895}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{894, 1191}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{894, 1196}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{895, 1191}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{895, 1197}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{896, 897}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{896, 898}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{896, 899}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{896, 1130}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{897, 898}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{897, 899}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{897, 1198}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{897, 1199}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{898, 899}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{898, 1200}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{899, 1201}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{900, 1202}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{900, 1203}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{900, 1204}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{902, 903}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{902, 1205}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{902, 1206}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{902, 1207}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{903, 986}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{903, 1208}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{904, 1018}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{905, 906}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{905, 1209}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{906, 1210}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{908, 984}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{909, 1114}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{910, 1211}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{911, 912}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{911, 1212}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{911, 1213}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{912, 1212}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{914, 1214}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{914, 1215}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{915, 1216}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{916, 1217}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{916, 1218}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{917, 1219}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{919, 920}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{921, 1220}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{921, 1221}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{921, 1222}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{922, 943}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{922, 954}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{922, 1223}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{923, 926}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{923, 1224}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{923, 1225}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{924, 925}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{926, 927}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{927, 1142}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{928, 1178}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{928, 1180}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{930, 1226}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{931, 932}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{931, 1150}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{931, 1152}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{931, 1153}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{931, 1154}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{931, 1227}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{932, 1150}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{932, 1152}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{932, 1153}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{932, 1227}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{937, 1228}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{937, 1229}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{937, 1230}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{937, 1231}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{938, 1232}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{938, 1233}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{938, 1234}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{941, 942}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{941, 943}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{943, 944}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{943, 950}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{943, 1235}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{944, 950}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{945, 1236}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{945, 1237}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{946, 948}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{946, 955}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{946, 1238}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{947, 1239}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{948, 955}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{948, 1238}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{948, 1240}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{948, 1241}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{949, 1124}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{950, 954}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{951, 952}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{955, 1238}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{955, 1242}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{958, 961}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{958, 1243}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{958, 1244}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{958, 1245}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{959, 1246}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{959, 1247}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{959, 1248}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{960, 964}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{961, 962}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{962, 1129}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{965, 966}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{966, 1115}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{967, 1249}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{968, 1250}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{971, 1095}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{971, 1096}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{972, 1136}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{973, 1136}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{973, 1251}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{973, 1252}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{973, 1253}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{973, 1254}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{973, 1255}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{973, 1256}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{974, 1255}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{974, 1256}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{974, 1257}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{974, 1258}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{975, 1259}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{976, 1260}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{976, 1261}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{976, 1262}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{977, 1263}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{977, 1264}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{978, 1265}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{978, 1266}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{982, 988}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{983, 984}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{983, 1018}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{986, 1018}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{990, 1267}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{990, 1268}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{991, 994}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{991, 1004}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{992, 993}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{992, 994}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{992, 1004}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{993, 994}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{993, 1004}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{995, 997}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{995, 999}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{995, 1000}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{995, 1001}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{996, 997}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{996, 1000}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{996, 1269}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{997, 998}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{997, 999}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{997, 1000}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{997, 1001}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{997, 1269}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{997, 1270}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{998, 999}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{998, 1000}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{998, 1001}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{998, 1003}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{998, 1271}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{998, 1272}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{999, 1000}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{999, 1001}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{999, 1271}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1000, 1001}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1000, 1269}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1000, 1271}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1000, 1273}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1001, 1271}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1002, 1274}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1002, 1275}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1002, 1276}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1005, 1007}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1006, 1277}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1006, 1278}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1006, 1279}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1006, 1280}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1006, 1281}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1007, 1282}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1008, 1283}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1009, 1010}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1011, 1284}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1011, 1285}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1012, 1013}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1012, 1014}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1012, 1109}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1012, 1286}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1012, 1287}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1013, 1014}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1013, 1109}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1013, 1286}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1013, 1287}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1013, 1288}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1014, 1286}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1014, 1287}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1015, 1016}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1017, 1289}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1018, 1019}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1020, 1021}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1022, 1023}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1025, 1026}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1025, 1290}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1025, 1291}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1026, 1290}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1026, 1291}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1027, 1143}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1027, 1292}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1028, 1293}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1028, 1294}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1030, 1149}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1031, 1295}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1031, 1296}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1031, 1297}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1031, 1298}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1031, 1299}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1031, 1300}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1033, 1301}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1038, 1039}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1039, 1040}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1042, 1302}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1042, 1303}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1043, 1044}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1043, 1045}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1044, 1045}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1046, 1304}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1046, 1305}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1046, 1306}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1046, 1307}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1047, 1048}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1047, 1308}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1047, 1309}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1048, 1308}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1048, 1309}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1048, 1310}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1049, 1050}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1052, 1311}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1053, 1054}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1054, 1055}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1056, 1311}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1056, 1312}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1057, 1108}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1060, 1061}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1064, 1313}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1064, 1314}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1064, 1315}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1064, 1316}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1065, 1317}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1067, 1069}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1068, 1318}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1068, 1319}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1068, 1320}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1070, 1321}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1072, 1322}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1072, 1323}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1072, 1324}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1074, 1075}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1076, 1077}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1076, 1078}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1076, 1079}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1076, 1080}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1076, 1081}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1076, 1082}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1077, 1078}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1077, 1079}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1077, 1080}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1077, 1081}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1077, 1082}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1078, 1079}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1078, 1080}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1078, 1081}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1078, 1082}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1079, 1080}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1079, 1081}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1079, 1082}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1080, 1081}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1080, 1082}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1081, 1082}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1082, 1325}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1083, 1326}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1083, 1327}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1083, 1328}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1083, 1329}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1084, 1085}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1084, 1326}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1084, 1329}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1084, 1330}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1085, 1330}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1086, 1326}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1086, 1329}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1087, 1331}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1088, 1090}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1088, 1091}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1088, 1332}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1088, 1333}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1088, 1334}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1088, 1335}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1088, 1336}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1088, 1337}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1088, 1338}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1089, 1092}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1090, 1091}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1090, 1093}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1090, 1334}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1090, 1336}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1090, 1338}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1090, 1339}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1090, 1340}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1090, 1341}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1091, 1334}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1091, 1336}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1091, 1338}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1091, 1340}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1091, 1341}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1093, 1332}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1093, 1333}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1093, 1334}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1093, 1335}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1093, 1336}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1093, 1338}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1094, 1342}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1095, 1096}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1096, 1097}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1096, 1098}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1096, 1343}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1097, 1098}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1097, 1343}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1097, 1344}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1098, 1343}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1098, 1344}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1101, 1102}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1101, 1103}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1101, 1104}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1101, 1105}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1101, 1106}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1102, 1103}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1102, 1104}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1102, 1105}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1102, 1106}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1103, 1104}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1103, 1105}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1103, 1106}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1103, 1345}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1104, 1105}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1104, 1106}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1104, 1345}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1105, 1106}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1105, 1345}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1106, 1345}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1106, 1346}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1106, 1347}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1106, 1348}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1106, 1349}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1107, 1350}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1109, 1287}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1110, 1351}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1111, 1286}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1112, 1113}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1112, 1352}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1112, 1353}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1112, 1354}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1112, 1355}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1116, 1117}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1119, 1120}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1119, 1356}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1121, 1122}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1121, 1123}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1122, 1123}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1124, 1125}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1125, 1126}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1125, 1357}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1127, 1202}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1127, 1358}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1128, 1129}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1130, 1131}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1130, 1359}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1131, 1135}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1131, 1359}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1137, 1360}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1137, 1361}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1138, 1140}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1139, 1140}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1139, 1232}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1140, 1362}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1143, 1226}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1143, 1363}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1145, 1364}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1145, 1365}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1146, 1147}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1146, 1148}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1146, 1298}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1146, 1366}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1147, 1148}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1147, 1366}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1148, 1366}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1150, 1151}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1150, 1152}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1150, 1153}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1150, 1154}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1150, 1367}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1150, 1368}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1151, 1152}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1151, 1154}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1151, 1367}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1151, 1368}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1152, 1153}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1152, 1154}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1152, 1367}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1153, 1154}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1153, 1369}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1154, 1367}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1155, 1174}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1160, 1161}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1160, 1162}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1160, 1163}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1160, 1165}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1161, 1162}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1161, 1163}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1161, 1164}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1161, 1165}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1162, 1163}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1162, 1164}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1162, 1165}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1163, 1164}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1163, 1165}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1164, 1165}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1165, 1370}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1166, 1175}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1166, 1176}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1166, 1347}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1166, 1371}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1166, 1372}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1166, 1373}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1166, 1374}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1166, 1375}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1167, 1168}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1167, 1169}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1167, 1170}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1167, 1174}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1168, 1169}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1168, 1170}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1168, 1171}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1168, 1172}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1168, 1173}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1168, 1174}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1168, 1376}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1169, 1170}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1169, 1173}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1169, 1376}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1171, 1172}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1171, 1173}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1171, 1376}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1172, 1173}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1172, 1376}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1173, 1376}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1174, 1298}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1175, 1176}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1176, 1372}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1178, 1377}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1179, 1180}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1179, 1378}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1180, 1377}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1181, 1182}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1182, 1379}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1187, 1380}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1187, 1381}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1189, 1192}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1189, 1193}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1189, 1382}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1190, 1192}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1190, 1193}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1190, 1382}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1191, 1192}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1191, 1193}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1191, 1383}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1191, 1384}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1192, 1193}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1192, 1194}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1192, 1385}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1192, 1386}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1193, 1194}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1193, 1382}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1193, 1387}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1193, 1388}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1193, 1389}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1194, 1382}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1196, 1197}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1196, 1383}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1196, 1384}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1196, 1390}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1196, 1391}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1196, 1392}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1197, 1383}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1197, 1384}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1197, 1390}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1197, 1391}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1197, 1392}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1198, 1393}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1198, 1394}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1198, 1395}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1198, 1396}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1199, 1225}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1199, 1397}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1202, 1203}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1202, 1358}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1203, 1204}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1205, 1206}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1205, 1207}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1205, 1398}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1205, 1399}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1205, 1400}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1206, 1207}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1206, 1398}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1206, 1399}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1206, 1400}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1207, 1398}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1207, 1399}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1207, 1400}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1209, 1210}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1212, 1213}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1212, 1401}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1213, 1401}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1214, 1215}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1214, 1402}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1214, 1403}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1215, 1403}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1216, 1404}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1216, 1405}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1216, 1406}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1219, 1407}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1220, 1221}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1221, 1222}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1221, 1408}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1222, 1409}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1222, 1410}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1224, 1411}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1224, 1412}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1226, 1363}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1226, 1413}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1228, 1229}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1228, 1230}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1228, 1231}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1228, 1414}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1229, 1230}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1229, 1231}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1230, 1231}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1233, 1234}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1234, 1349}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1234, 1415}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1234, 1416}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1234, 1417}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1234, 1418}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1234, 1419}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1234, 1420}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1235, 1421}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1235, 1422}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1235, 1423}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1236, 1424}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1236, 1425}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1238, 1240}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1238, 1241}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1240, 1287}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1243, 1244}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1243, 1245}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1244, 1245}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1246, 1247}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1248, 1426}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1249, 1427}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1250, 1287}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1251, 1252}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1251, 1253}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1251, 1428}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1251, 1429}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1252, 1253}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1253, 1254}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1253, 1255}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1253, 1256}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1255, 1256}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1255, 1257}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1255, 1430}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1256, 1258}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1256, 1430}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1256, 1431}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1257, 1258}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1257, 1430}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1257, 1431}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1257, 1432}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1257, 1433}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1258, 1430}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1258, 1431}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1258, 1432}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1258, 1433}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1258, 1434}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1259, 1435}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1260, 1261}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1260, 1436}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1262, 1436}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1262, 1437}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1262, 1438}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1262, 1439}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1262, 1440}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1262, 1441}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1262, 1442}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1263, 1443}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1264, 1444}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1272, 1273}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1272, 1445}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1272, 1446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1272, 1447}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1272, 1448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1273, 1446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1273, 1447}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1274, 1275}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1275, 1276}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1275, 1449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1275, 1450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1275, 1451}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1276, 1449}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1276, 1450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1276, 1452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1277, 1278}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1277, 1279}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1277, 1280}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1278, 1279}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1278, 1280}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1278, 1281}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1278, 1453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1278, 1454}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1279, 1280}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1279, 1281}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1279, 1453}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1279, 1455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1280, 1281}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1283, 1456}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1283, 1457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1284, 1285}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1286, 1287}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1286, 1458}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1288, 1459}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1290, 1291}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1293, 1294}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1293, 1460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1294, 1460}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1295, 1296}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1295, 1297}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1295, 1298}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1295, 1299}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1295, 1300}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1296, 1297}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1296, 1298}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1296, 1299}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1296, 1300}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1297, 1298}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1297, 1299}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1298, 1299}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1298, 1300}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1299, 1300}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1301, 1461}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1302, 1462}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1302, 1463}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1304, 1464}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1305, 1465}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1306, 1466}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1307, 1466}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1307, 1467}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1308, 1309}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1308, 1310}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1309, 1310}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1311, 1468}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1313, 1314}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1313, 1315}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1313, 1316}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1314, 1315}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1314, 1316}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1315, 1316}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1318, 1319}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1318, 1320}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1318, 1469}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1319, 1320}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1319, 1469}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1320, 1469}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1321, 1470}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1322, 1323}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1323, 1471}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1325, 1472}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1326, 1327}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1326, 1328}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1327, 1328}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1331, 1473}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1331, 1474}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1334, 1336}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1334, 1338}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1334, 1340}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1334, 1341}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1336, 1338}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1336, 1341}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1338, 1340}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1339, 1475}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1339, 1476}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1339, 1477}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1340, 1421}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1340, 1478}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1343, 1344}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1343, 1479}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1343, 1480}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1347, 1375}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1347, 1481}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1347, 1482}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1349, 1417}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1349, 1418}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1349, 1419}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1349, 1420}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1352, 1353}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1352, 1354}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1355, 1483}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1355, 1484}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1364, 1365}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1365, 1485}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1367, 1368}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1370, 1486}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1370, 1487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1370, 1488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1370, 1489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1370, 1490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1371, 1374}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1371, 1375}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1372, 1373}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1372, 1374}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1372, 1375}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1372, 1481}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1373, 1374}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1373, 1375}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1373, 1481}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1374, 1375}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1374, 1481}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1375, 1481}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1377, 1422}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1378, 1478}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1380, 1381}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1380, 1491}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1380, 1492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1380, 1493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1381, 1492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1382, 1494}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1383, 1384}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1383, 1495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1384, 1388}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1384, 1495}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1384, 1496}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1385, 1386}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1385, 1497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1386, 1497}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1387, 1498}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1390, 1391}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1390, 1392}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1391, 1392}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1393, 1395}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1393, 1499}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1393, 1500}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1394, 1501}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1395, 1502}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1396, 1503}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1398, 1399}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1398, 1400}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1398, 1504}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1399, 1400}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1402, 1505}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1404, 1405}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1404, 1406}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1404, 1506}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1405, 1406}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1405, 1507}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1405, 1508}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1406, 1508}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1406, 1509}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1406, 1510}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1407, 1511}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1408, 1512}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1408, 1513}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1408, 1514}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1408, 1515}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1408, 1516}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1408, 1517}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1415, 1416}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1415, 1419}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1416, 1417}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1416, 1418}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1417, 1418}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1417, 1419}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1417, 1420}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1418, 1419}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1418, 1420}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1419, 1420}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1421, 1478}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1422, 1518}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1423, 1519}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1424, 1425}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1427, 1520}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1427, 1521}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1427, 1522}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1428, 1429}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1430, 1431}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1430, 1433}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1431, 1432}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1431, 1433}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1431, 1434}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1432, 1433}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1432, 1434}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1433, 1434}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1436, 1437}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1436, 1440}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1436, 1441}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1436, 1442}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1436, 1523}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1436, 1524}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1437, 1441}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1437, 1525}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1437, 1526}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1438, 1439}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1438, 1440}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1439, 1440}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1441, 1442}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1445, 1446}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1445, 1447}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1446, 1447}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1446, 1448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1447, 1448}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1449, 1450}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1450, 1452}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1451, 1527}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1451, 1528}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1454, 1455}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1454, 1529}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1454, 1530}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1454, 1531}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1454, 1532}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1454, 1533}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1455, 1530}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1455, 1531}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1455, 1532}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1455, 1533}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1455, 1534}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1455, 1535}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1456, 1457}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1456, 1536}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1457, 1536}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1459, 1537}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1462, 1463}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1464, 1538}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1466, 1467}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1473, 1474}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1475, 1476}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1475, 1477}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1475, 1539}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1476, 1477}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1476, 1539}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1477, 1539}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1479, 1480}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1483, 1540}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1486, 1487}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1486, 1488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1486, 1489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1486, 1490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1487, 1488}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1487, 1489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1487, 1490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1488, 1489}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1488, 1490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1489, 1490}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1491, 1492}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1491, 1493}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1491, 1541}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1491, 1542}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1491, 1543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1493, 1544}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1493, 1545}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1493, 1546}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1494, 1547}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1495, 1548}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1495, 1549}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1495, 1550}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1495, 1551}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1495, 1552}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1495, 1553}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1495, 1554}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1499, 1500}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1499, 1555}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1500, 1556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1502, 1557}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1507, 1508}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1508, 1509}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1508, 1558}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1508, 1559}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1512, 1516}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1512, 1560}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1513, 1514}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1513, 1515}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1513, 1516}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1513, 1517}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1513, 1561}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1513, 1562}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1514, 1515}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1514, 1561}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1514, 1562}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1514, 1563}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1514, 1564}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1515, 1516}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1515, 1517}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1515, 1561}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1515, 1562}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1516, 1517}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1516, 1561}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1516, 1562}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1516, 1565}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1516, 1566}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1517, 1561}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1517, 1562}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1517, 1565}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1517, 1566}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1519, 1567}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1520, 1521}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1521, 1568}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1523, 1524}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1523, 1569}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1523, 1570}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1523, 1571}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1523, 1572}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1523, 1573}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1524, 1570}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1524, 1571}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1524, 1572}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1524, 1573}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1524, 1574}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1527, 1528}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1529, 1534}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1529, 1575}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1529, 1576}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1529, 1577}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1530, 1531}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1530, 1532}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1530, 1533}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1531, 1532}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1531, 1533}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1534, 1575}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1534, 1576}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1534, 1577}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1534, 1578}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1535, 1578}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1535, 1579}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1535, 1580}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1535, 1581}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1538, 1582}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1540, 1583}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1541, 1542}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1541, 1543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1542, 1543}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1544, 1545}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1544, 1546}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1547, 1584}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1548, 1549}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1548, 1550}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1548, 1551}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1548, 1552}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1548, 1553}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1548, 1554}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1549, 1550}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1549, 1551}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1549, 1552}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1549, 1553}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1549, 1554}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1550, 1551}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1550, 1552}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1550, 1553}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1550, 1554}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1551, 1552}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1551, 1553}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1551, 1554}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1552, 1553}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1552, 1554}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1553, 1554}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1555, 1556}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1558, 1585}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1559, 1586}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1560, 1565}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1560, 1566}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1561, 1562}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1561, 1565}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1561, 1587}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1562, 1565}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1562, 1566}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1563, 1564}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1563, 1587}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1563, 1588}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1563, 1589}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1563, 1590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1563, 1591}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1563, 1592}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1563, 1593}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1563, 1594}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1564, 1587}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1564, 1588}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1564, 1589}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1564, 1590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1564, 1592}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1564, 1593}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1564, 1594}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1565, 1566}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1568, 1595}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1568, 1596}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1570, 1571}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1570, 1572}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1570, 1573}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1570, 1574}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1571, 1572}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1571, 1573}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1571, 1574}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1572, 1573}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1572, 1574}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1573, 1574}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1575, 1576}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1575, 1577}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1576, 1577}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1577, 1578}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1578, 1579}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1578, 1580}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1578, 1581}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1579, 1580}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1579, 1581}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1580, 1581}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1581, 1597}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1582, 1598}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1587, 1593}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1587, 1594}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1588, 1589}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1588, 1590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1588, 1591}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1588, 1592}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1588, 1593}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1589, 1590}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1589, 1591}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1589, 1592}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1589, 1593}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1590, 1591}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1590, 1592}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1590, 1593}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1591, 1592}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1591, 1593}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1592, 1593}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1593, 1594}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1595, 1599}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1595, 1600}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1596, 1601}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1598, 1602}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1598, 1603}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1598, 1604}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1598, 1605}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1598, 1606}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1598, 1607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1598, 1608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1598, 1609}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1598, 1610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1598, 1611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1602, 1603}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1602, 1606}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1602, 1607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1602, 1608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1602, 1611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1602, 1612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1603, 1606}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1603, 1607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1603, 1608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1603, 1611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1603, 1612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1603, 1613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1603, 1614}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1605, 1606}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1605, 1607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1605, 1608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1605, 1611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1605, 1615}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1606, 1607}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1606, 1608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1606, 1611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1607, 1608}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1607, 1611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1608, 1611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1608, 1616}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1609, 1610}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1610, 1611}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1611, 1612}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1611, 1613}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1611, 1614}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1612, 1617}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1613, 1618}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1613, 1619}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1613, 1620}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1613, 1621}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1614, 1621}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1614, 1622}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1614, 1623}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1615, 1616}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1618, 1619}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1618, 1620}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1618, 1624}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1618, 1625}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1619, 1620}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1619, 1626}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1620, 1624}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1621, 1622}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1621, 1623}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1622, 1623}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1624, 1625}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1626, 1627}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1626, 1628}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1627, 1628}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1627, 1629}, 0.1182291273323746]}, 
         {Arrowheads[0.], ArrowBox[{1628, 1629}, 0.1182291273323746]}}, 
        {Hue[0.625, 0.5, 0.7], PointBox[CompressedData["
1:eJwl2VMMIMoOANC1bdu2bdu2bd7VvWvbtm3btm3b+87mfZxM0s8mnem0CRu1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          "]]}}]],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{3.677572729428164*^9}]
}, Open  ]],

Cell["\<\
Diese Operation f\[UDoubleDot]hrt auf das Netzwerk aus Abb. 5.37a. Mit den \
folgenden Befehlen kann man sehr schnell einen \[CapitalUDoubleDot]berblick \
\[UDoubleDot]ber einige (auch in Tab. 5.4 protokollierten) \
Netzwerkeigenschaften erlangen.\
\>", "Text",
 CellChangeTimes->{{3.6761930958273273`*^9, 3.676193161547251*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<PPI E.coli\>\"", ",", 
   RowBox[{"VertexCount", "[", "graph1b", "]"}], ",", 
   RowBox[{"EdgeCount", "[", "graph1b", "]"}], ",", 
   RowBox[{"Max", "[", 
    RowBox[{"VertexDegree", "[", "graph1b", "]"}], "]"}], ",", 
   RowBox[{"N", "[", 
    RowBox[{"2", " ", 
     RowBox[{
      RowBox[{"EdgeCount", "[", "graph1b", "]"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"VertexCount", "[", "graph1b", "]"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"VertexCount", "[", "graph1b", "]"}], "-", "1"}], ")"}]}], 
       ")"}]}]}], "]"}], ",", 
   RowBox[{"N", "[", 
    RowBox[{"Mean", "[", 
     RowBox[{"Flatten", "[", 
      RowBox[{"GraphDistanceMatrix", "[", "graph1b", "]"}], "]"}], "]"}], 
    "]"}], ",", 
   RowBox[{"N", "[", 
    RowBox[{"Log", "[", 
     RowBox[{"VertexCount", "[", "graph1b", "]"}], "]"}], "]"}], ",", 
   RowBox[{"N", "[", 
    RowBox[{"MeanClusteringCoefficient", "[", "graph1b", "]"}], "]"}]}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.622004540666333*^9, 3.622004543929796*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"PPI E.coli\"\>", ",", "1629", ",", "5736", ",", "66", ",", 
   "0.004325772281573386`", ",", "8.735575008073813`", ",", 
   "7.395721608602045`", ",", "0.4792176380908227`"}], "}"}]], "Output",
 CellChangeTimes->{3.677572729911765*^9}]
}, Open  ]],

Cell[TextData[{
 "Die Gradverteilung erh\[ADoubleDot]lt man \[UDoubleDot]ber das Anwenden des \
Befehls ",
 StyleBox["Tally",
  FontWeight->"Bold"],
 " auf das Resultat von ",
 StyleBox["VertexDegree",
  FontWeight->"Bold"],
 ". Das Resultat haben wir bereits in Abb. 5.38a gesehen."
}], "Text",
 CellChangeTimes->{{3.676193188881702*^9, 3.6761932188117576`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLogLogPlot", "[", 
  RowBox[{
   RowBox[{"Sort", "[", 
    RowBox[{"Tally", "[", 
     RowBox[{"VertexDegree", "[", "graph1b", "]"}], "]"}], "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.622026284003418*^9, 3.622026349918977*^9}, {
   3.622092112345079*^9, 3.6220921211589527`*^9}, 3.622973747815856*^9, 
   3.6238282529716988`*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {GrayLevel[0], PointSize[0.011000000000000001`], AbsoluteThickness[1.6], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCwBmIQDQNa0RZH9/mLOry3/PXPSe+Z/aJGnk1LAsUcuJnX
Vr2a/NF+1imhXQvWweS/2QfPmSJdZSjqYNz79rvjgZ/2TgeD5bTlRRyYFLR+
ca/+Y++9+aNXoLmwQ3iU0boipf/2mirsT767CzsUr7a237SIwWG1jVKGxmF+
qPmMDqW7A2wsfvA5iIVu3b0xm8lB/t/Z0xYfuBx8zOu3P9ZjhvNr513eI/aQ
GU4H9hhqs7SyOOhsZmEz62N3WL77utgpGVa4uLyHr6XYKla4eoj72eDuqqr/
dTB7FRvcH20Ts62q5dnh/oSZCwuXiY+Lq52+s8PDZeO6/Cl60Rxw/omjtuUl
uzjg6n/qTKpZnsPpAAtniD2ccPmzUh9eTRHggts3oYV5x/1YLri8ste0a1Er
EPKwcIC5d/Y17p/LTLnh6qO0J3qcq0DwL+64+uXGDwT/G+/Oxj+mPHD3Hv3M
HxxVyAM3DxJ/PHD37j1u9U7jMQ9c/wrHw0ePSfLC5a/xdmT89EPweYuMrC83
Ifh+a/pcU7fywu3TtdUL2f+MF26ec8gfM1Y3Prj6JScXl3GX8MHlc5wm7OVb
iJBfL71m+yVvfrh5/xkC/yeU8MPVw9IVjM8jfKi84CWC//nfrsgmdgF4eAbk
aJ3+KikA93/krLULRXUE4Op93Y4dfWIrALe/UvP4z1R/BL/bKPXO7AQBeLrn
zRF63VGI0P/6jnqLfpMA3L3SEo9fTJyEsA+SHxDypZpTJk/ahOAvU/a6ZXII
YR8AIFmLPw==
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-0.1541116490393835, -0.4049803905957743},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{{{0., 
       FormBox["1", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
       FormBox["5", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {2.302585092994046, 
       FormBox["10", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {3.912023005428146, 
       FormBox["50", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {4.605170185988092, 
       FormBox["100", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.6931471805599453, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.791759469228055, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.995732273553991, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {4.0943445622221, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {4.248495242049359, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {4.382026634673881, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {4.499809670330265, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {5.298317366548036, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {5.703782474656201, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {5.991464547107982, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {6.214608098422191, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {6.396929655216146, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {6.551080335043404, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {6.684611727667927, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {6.802394763324311, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {6.907755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {7.600902459542082, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {8.006367567650246, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {8.294049640102028, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {8.517193191416238, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}}, Automatic}, {{{0., 
       FormBox["1", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.6931471805599453, 
       FormBox["2", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
       FormBox["5", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {2.302585092994046, 
       FormBox["10", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {2.995732273553991, 
       FormBox["20", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {3.912023005428146, 
       FormBox["50", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0.4054651081081644, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.791759469228055, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.70805020110221, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {4.0943445622221, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {4.248495242049359, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {4.382026634673881, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {4.499809670330265, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {4.605170185988092, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}}, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Log, Exp}, {Log, Exp}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Log, Exp}, {Log, Exp}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Log, Exp}, {Log, Exp}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Log, Exp}, {Log, Exp}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.0872844737922172, 
   4.189654742026425}, {-0.30998499033256793`, 5.579729825986222}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{{{0., 
      FormBox["1", TraditionalForm], {0.01, 0.}, {
       AbsoluteThickness[0.1]}}, {0.6931471805599453, 
      FormBox["2", TraditionalForm], {0.01, 0.}, {
       AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
      FormBox["5", TraditionalForm], {0.01, 0.}, {
       AbsoluteThickness[0.1]}}, {2.302585092994046, 
      FormBox["10", TraditionalForm], {0.01, 0.}, {
       AbsoluteThickness[0.1]}}, {2.995732273553991, 
      FormBox["20", TraditionalForm], {0.01, 0.}, {
       AbsoluteThickness[0.1]}}, {3.912023005428146, 
      FormBox["50", TraditionalForm], {0.01, 0.}, {
       AbsoluteThickness[0.1]}}, {0.4054651081081644, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {1.791759469228055, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {2.70805020110221, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {4.0943445622221, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {4.248495242049359, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {4.382026634673881, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {4.499809670330265, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {4.605170185988092, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}}, {{0., 
      FormBox["1", TraditionalForm], {0.01, 0.}, {
       AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
      FormBox["5", TraditionalForm], {0.01, 0.}, {
       AbsoluteThickness[0.1]}}, {2.302585092994046, 
      FormBox["10", TraditionalForm], {0.01, 0.}, {
       AbsoluteThickness[0.1]}}, {3.912023005428146, 
      FormBox["50", TraditionalForm], {0.01, 0.}, {
       AbsoluteThickness[0.1]}}, {4.605170185988092, 
      FormBox["100", TraditionalForm], {0.01, 0.}, {
       AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {0.6931471805599453, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {1.791759469228055, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {2.995732273553991, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {4.0943445622221, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {4.248495242049359, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {4.382026634673881, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {4.499809670330265, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {5.298317366548036, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {5.703782474656201, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {5.991464547107982, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {6.214608098422191, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {6.396929655216146, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {6.551080335043404, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {6.684611727667927, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {6.802394763324311, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {6.907755278982137, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {7.600902459542082, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {8.006367567650246, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {8.294049640102028, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}, {8.517193191416238, 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
       AbsoluteThickness[0.1]}}}}]], "Output",
 CellChangeTimes->{3.677572730098965*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{501, 900},
WindowMargins->{{717, Automatic}, {Automatic, 131}},
FrontEndVersion->"10.4 for Microsoft Windows (64-bit) (April 11, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 870, 36, 182, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1453, 60, 342, 10, 94, "Subtitle"],
Cell[1798, 72, 906, 21, 220, "Text"],
Cell[2707, 95, 187, 5, 47, "Input"],
Cell[2897, 102, 462, 9, 72, "Input"],
Cell[CellGroupData[{
Cell[3384, 115, 138, 2, 31, "Input"],
Cell[3525, 119, 122, 3, 31, "Output"]
}, Open  ]],
Cell[3662, 125, 417, 7, 87, "Text"],
Cell[CellGroupData[{
Cell[4104, 136, 204, 4, 31, "Input"],
Cell[4311, 142, 677, 18, 112, "Output"]
}, Open  ]],
Cell[5003, 163, 805, 13, 201, "Text"],
Cell[5811, 178, 911, 26, 92, "Input"],
Cell[CellGroupData[{
Cell[6747, 208, 135, 2, 31, "Input"],
Cell[6885, 212, 99, 2, 31, "Output"]
}, Open  ]],
Cell[6999, 217, 476, 9, 144, "Text"],
Cell[CellGroupData[{
Cell[7500, 230, 418, 9, 72, "Input"],
Cell[7921, 241, 43720, 886, 347, "Output"]
}, Open  ]],
Cell[51656, 1130, 1043, 21, 201, "Text"],
Cell[52702, 1153, 361, 8, 72, "Input"],
Cell[CellGroupData[{
Cell[53088, 1165, 133, 2, 31, "Input"],
Cell[53224, 1169, 99, 2, 31, "Output"]
}, Open  ]],
Cell[53338, 1174, 158, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[53521, 1180, 195, 4, 31, "Input"],
Cell[53719, 1186, 248, 6, 72, "Output"]
}, Open  ]],
Cell[53982, 1195, 621, 12, 144, "Text"],
Cell[CellGroupData[{
Cell[54628, 1211, 249, 6, 31, "Input"],
Cell[54880, 1219, 159, 2, 52, "Output"]
}, Open  ]],
Cell[55054, 1224, 710, 16, 112, "Input"],
Cell[CellGroupData[{
Cell[55789, 1244, 132, 2, 31, "Input"],
Cell[55924, 1248, 120, 3, 31, "Output"]
}, Open  ]],
Cell[56059, 1254, 323, 5, 87, "Text"],
Cell[56385, 1261, 536, 15, 52, "Input"],
Cell[CellGroupData[{
Cell[56946, 1280, 535, 11, 72, "Input"],
Cell[57484, 1293, 43522, 884, 347, "Output"]
}, Open  ]],
Cell[101021, 2180, 321, 5, 87, "Text"],
Cell[CellGroupData[{
Cell[101367, 2189, 280, 8, 31, "Input"],
Cell[101650, 2199, 11697, 330, 210, "Output"]
}, Open  ]],
Cell[113362, 2532, 312, 8, 49, "Text"],
Cell[113677, 2542, 656, 14, 52, "Input"],
Cell[CellGroupData[{
Cell[114358, 2560, 207, 4, 31, "Input"],
Cell[114568, 2566, 118, 3, 31, "Output"]
}, Open  ]],
Cell[114701, 2572, 531, 12, 106, "Text"],
Cell[115235, 2586, 936, 26, 132, "Input"],
Cell[116174, 2614, 495, 9, 31, "Input"],
Cell[CellGroupData[{
Cell[116694, 2627, 465, 9, 52, "Input"],
Cell[117162, 2638, 475427, 6882, 331, "Output"]
}, Open  ]],
Cell[592604, 9523, 339, 6, 87, "Text"],
Cell[CellGroupData[{
Cell[592968, 9533, 1091, 29, 192, "Input"],
Cell[594062, 9564, 279, 5, 52, "Output"]
}, Open  ]],
Cell[594356, 9572, 363, 10, 68, "Text"],
Cell[CellGroupData[{
Cell[594744, 9586, 573, 13, 88, "Input"],
Cell[595320, 9601, 31702, 751, 229, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

